@@ -13,48 +13,37 @@
 #include "wegbauer.h"
 
 #include "../simworld.h"
-#include "../simgraph.h"
-#include "../simwin.h"
 #include "../simhalt.h"
-#include "../besch/sound_besch.h"
+#include "../simdepot.h"
 #include "../player/simplay.h"
-#include "../simskin.h"
 #include "../simtypes.h"
 
 #include "../boden/boden.h"
 #include "../boden/brueckenboden.h"
-#include "../boden/wege/monorail.h"
-#include "../boden/wege/schiene.h"
-#include "../boden/wege/strasse.h"
-#include "../boden/wege/kanal.h"
 
 #include "../gui/messagebox.h"
 #include "../gui/werkzeug_waehler.h"
 #include "../gui/karte.h"
 
 #include "../besch/bruecke_besch.h"
-#include "../besch/skin_besch.h"
 
 #include "../dings/bruecke.h"
-#include "../dings/crossing.h"
 #include "../dings/leitung2.h"
 #include "../dings/pillar.h"
 #include "../dings/signal.h"
+#include "../dataobj/crossing_logic.h"
 
 #include "../tpl/stringhashtable_tpl.h"
 #include "../tpl/vector_tpl.h"
 
 
+/// All bridges hashed by name
 static stringhashtable_tpl<const bruecke_besch_t *> bruecken_by_name;
 
 
-/**
- * Registers a new bridge type
- * @author V. Meyer, Hj. Malthaner
- */
 void brueckenbauer_t::register_besch(bruecke_besch_t *besch)
 {
-	// avoid duplicates with same name	// avoid duplicates with same name
+	// avoid duplicates with same name
 	if( const bruecke_besch_t *old_besch = bruecken_by_name.get(besch->get_name()) ) {
 		dbg->warning( "brueckenbauer_t::register_besch()", "Object %s was overlaid by addon!", besch->get_name() );
 		bruecken_by_name.remove(besch->get_name());
@@ -74,47 +63,12 @@ void brueckenbauer_t::register_besch(bruecke_besch_t *besch)
 }
 
 
-
 const bruecke_besch_t *brueckenbauer_t::get_besch(const char *name)
 {
 	return bruecken_by_name.get(name);
 }
 
 
-
-bool brueckenbauer_t::laden_erfolgreich()
-{
-	bool strasse_da = false;
-	bool schiene_da = false;
-
-	FOR(stringhashtable_tpl<bruecke_besch_t const*>, const& i, bruecken_by_name) {
-		bruecke_besch_t const* const besch = i.value;
-
-		if(besch && besch->get_waytype() == track_wt) {
-			schiene_da = true;
-		}
-		if(besch && besch->get_waytype() == road_wt) {
-			strasse_da = true;
-		}
-	}
-
-	if(!schiene_da) {
-		DBG_MESSAGE("brueckenbauer_t", "No rail bridge found - feature disabled");
-	}
-
-	if(!strasse_da) {
-		DBG_MESSAGE("brueckenbauer_t", "No road bridge found - feature disabled");
-	}
-
-	return true;
-}
-
-
-
-/**
- * Find a matchin bridge
- * @author Hj. Malthaner
- */
 const bruecke_besch_t *brueckenbauer_t::find_bridge(const waytype_t wtyp, const sint32 min_speed, const uint16 time)
 {
 	const bruecke_besch_t *find_besch=NULL;
@@ -136,21 +90,20 @@ const bruecke_besch_t *brueckenbauer_t::find_bridge(const waytype_t wtyp, const
 }
 
 
+/**
+ * Compares the maximum speed of two bridges.
+ * @param a the first bridge.
+ * @param b the second bridge.
+ * @return true, if the speed of the second bridge is greater.
+ */
 static bool compare_bridges(const bruecke_besch_t* a, const bruecke_besch_t* b)
 {
 	return a->get_topspeed() < b->get_topspeed();
 }
 
 
-/**
- * Fill menu with icons of given waytype
- * @author Hj. Malthaner
- */
-
 void brueckenbauer_t::fill_menu(werkzeug_waehler_t *wzw, const waytype_t wtyp, sint16 /*sound_ok*/, const karte_t *welt)
 {
-	static stringhashtable_tpl<wkz_brueckenbau_t *> bruecken_tool;
-
 	const uint16 time = welt->get_timeline_year_month();
 	vector_tpl<const bruecke_besch_t*> matching(bruecken_by_name.get_count());
 
@@ -172,7 +125,6 @@ void brueckenbauer_t::fill_menu(werkzeug_waehler_t *wzw, const waytype_t wtyp, s
 }
 
 
-
 koord3d brueckenbauer_t::finde_ende(karte_t *welt, koord3d pos, koord zv, const bruecke_besch_t *besch, const char *&error_msg, bool ai_bridge, uint32 min_length )
 {
 	const grund_t *gr1; // on the level of the bridge
@@ -201,10 +153,10 @@ koord3d brueckenbauer_t::finde_ende(karte_t *welt, koord3d pos, koord zv, const
 			return koord3d::invalid;
 		}
 		// and if ground is above bridge / double slopes
-		if (height < -Z_TILE_STEP) {
+		if (height < -1) {
 			break; // to trigger the right error message
 		}
-		gr1 = welt->lookup(pos + koord3d(0, 0, Z_TILE_STEP));
+		gr1 = welt->lookup(pos + koord3d(0, 0, 1));
 		if(  gr1  &&  gr1->get_weg_hang()==hang_t::flach  &&  length>=min_length) {
 			if(  gr1->get_typ()==grund_t::boden  ) {
 				// on slope ok, but not on other bridges
@@ -302,6 +254,15 @@ koord3d brueckenbauer_t::finde_ende(karte_t *welt, koord3d pos, koord zv, const
 				}
 			}
 		}
+
+		// no bridges crossing runways
+		if(  grund_t *gr3 = welt->lookup_kartenboden( pos.get_2d() )  ) {
+			if(  gr3->hat_weg(air_wt)  &&  gr3->get_styp(air_wt)==1  ) {
+				// sytem_type==1 is runway
+				break;
+			}
+		}
+
 	} while(  !gr1  &&  // no bridge is crossing
 		(!gr2 || (gr2->get_grund_hang()==hang_t::flach  &&  gr2->get_weg_hang()==hang_t::flach)  ||  gr2->get_hoehe()<pos.z )  &&  // ground stays below bridge
 		(!ai_bridge || length <= welt->get_settings().way_max_bridge_len) // not too long in case of AI
@@ -312,7 +273,6 @@ koord3d brueckenbauer_t::finde_ende(karte_t *welt, koord3d pos, koord zv, const
 }
 
 
-
 bool brueckenbauer_t::ist_ende_ok(spieler_t *sp, const grund_t *gr)
 {
 	if(gr->get_typ()!=grund_t::boden  &&  gr->get_typ()!=grund_t::monorailboden) {
@@ -437,7 +397,7 @@ DBG_MESSAGE("brueckenbauer_t::baue()", "end not ok");
 	}
 
 
-	// Anfang und ende sind geprueft, wir konnen endlich bauen
+	// Start and end have been checked, we can start to build eventually
 	if(besch->get_waytype()==powerline_wt) {
 		baue_bruecke(welt, sp, gr->get_pos(), end, zv, besch, lt->get_besch() );
 	}
@@ -463,7 +423,7 @@ void brueckenbauer_t::baue_bruecke(karte_t *welt, spieler_t *sp, koord3d pos, ko
 	pos = pos + zv;
 
 	while(pos.get_2d()!=end.get_2d()) {
-		brueckenboden_t *bruecke = new brueckenboden_t(welt, pos + koord3d(0, 0, Z_TILE_STEP), 0, 0);
+		brueckenboden_t *bruecke = new brueckenboden_t(welt, pos + koord3d(0, 0, 1), 0, 0);
 		welt->access(pos.get_2d())->boden_hinzufuegen(bruecke);
 		if(besch->get_waytype() != powerline_wt) {
 			weg = weg_t::alloc(besch->get_waytype());
@@ -485,7 +445,7 @@ void brueckenbauer_t::baue_bruecke(karte_t *welt, spieler_t *sp, koord3d pos, ko
 			if(besch->get_pillar()==1  ||  (pos.x*zv.x+pos.y*zv.y)%besch->get_pillar()==0) {
 				grund_t *gr = welt->lookup_kartenboden(pos.get_2d());
 //DBG_MESSAGE("bool brueckenbauer_t::baue_bruecke()","h1=%i, h2=%i",pos.z,gr->get_pos().z);
-				sint16 height = (pos.z - gr->get_pos().z)/Z_TILE_STEP+1;
+				sint16 height = pos.z - gr->get_pos().z+1;
 				while(height-->0) {
 					if(height_scaling(TILE_HEIGHT_STEP*height)<=127) {
 						// eventual more than one part needed, if it is too high ...
@@ -538,6 +498,7 @@ void brueckenbauer_t::baue_bruecke(karte_t *welt, spieler_t *sp, koord3d pos, ko
 	}
 }
 
+
 void brueckenbauer_t::baue_auffahrt(karte_t* welt, spieler_t* sp, koord3d end, koord zv, const bruecke_besch_t* besch)
 {
 	grund_t *alter_boden = welt->lookup(end);
@@ -596,8 +557,6 @@ void brueckenbauer_t::baue_auffahrt(karte_t* welt, spieler_t* sp, koord3d end, k
 }
 
 
-
-
 const char *brueckenbauer_t::remove(karte_t *welt, spieler_t *sp, koord3d pos, waytype_t wegtyp)
 {
 	marker_t    marker(welt->get_groesse_x(),welt->get_groesse_y());
@@ -727,6 +686,12 @@ const char *brueckenbauer_t::remove(karte_t *welt, spieler_t *sp, koord3d pos, w
 				haltestelle_t::remove(welt, sp, gr->get_pos(), fail);
 			}
 
+			// depots at bridge ends needs to be deleted as well
+			if (depot_t *dep = gr->get_depot()) {
+				dep->entferne(sp);
+				delete dep;
+			}
+
 			// removes single signals, bridge head, pedestrians, stops, changes catenary etc
 			weg_t *weg=gr->get_weg_nr(1);
 			if(weg) {
