@@ -117,7 +117,7 @@ public:
 	/** true, when showing a grid
 	 * @author prissi
 	 */
-	static bool show_grid;
+	static volatile bool show_grid;
 
 	/* underground modes */
 	/* @author Dwachs    */
@@ -348,6 +348,12 @@ public:
 	// map rotation
 	virtual void rotate90();
 
+	// we must put the text back to thier proper location after roation ...
+	static void finish_rotate90();
+
+	// since enlargement will require new hases
+	static void enlarge_map( sint16 new_size_x, sint16 new_size_y );
+
 	void sort_trees();
 
 	/**
@@ -735,10 +741,10 @@ public:
 		// only on slope height may changes
 		if(  way_slope  ) {
 			if(ribi & ribi_t::nordost) {
-				h += corner3(way_slope)*Z_TILE_STEP;
+				h += corner3(way_slope);
 			}
 			else {
-				h += corner1(way_slope)*Z_TILE_STEP;
+				h += corner1(way_slope);
 			}
 		}
 
@@ -748,7 +754,7 @@ public:
 		 */
 		if(  way_slope != slope  ) {
 			if(  ist_bruecke()  &&  slope  ) {
-				h += Z_TILE_STEP;	// end or start of a bridge
+				h ++;	// end or start of a bridge
 			}
 		}
 
