@@ -1,6 +1,6 @@
 /* basic network functionality, borrowed from OpenTTD */
 
-#ifdef  __MINGW32__
+#if defined(__MINGW32__) ||  defined(__amiga__)
 // warning: IPv6 will only work on XP and up ...
 #define USE_IP4_ONLY
 #endif
@@ -8,11 +8,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
+#include <errno.h>
 
 #include <string>
 
 #include "network.h"
 #include "network_address.h"
+#include "network_packet.h"
 #include "network_socket_list.h"
 #include "network_cmd.h"
 #include "network_cmd_ingame.h"
@@ -74,7 +76,7 @@ uint32 network_get_client_id()
  * Initializes the network core (as that is needed for some platforms
  * @return true if the core has been initialized, false otherwise
  */
-bool network_initialize()
+static bool network_initialize()
 {
 	if(!network_active) {
 		socket_list_t::reset();
@@ -83,7 +85,7 @@ bool network_initialize()
 		/* Let's load the network in windows */
 		WSADATA wsa;
 		if(int err = WSAStartup( MAKEWORD(2, 2), &wsa)) {
-			dbg->error("NetworkInitialize()","failed loading windows socket library with %i", err);
+			dbg->warning("NetworkInitialize()","failed loading windows socket library with %i", err);
 			return false;
 		}
 #endif /* _WIN32 */
@@ -98,9 +100,15 @@ bool network_initialize()
  * In case of failure err is populated with a meaningful error
  * @return a valid socket or INVALID_SOCKET if the connection fails
  */
-SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err )
+SOCKET network_open_address(char const* cp, char const*& err)
 {
 	err = NULL;
+
+	if (!network_initialize()) {
+		err = "Cannot init network!";
+		return INVALID_SOCKET;
+	}
+
 #ifdef USE_IP4_ONLY
 	// Network load. Address format e.g.: "128.0.0.1:13353"
 	char address[32];
@@ -114,12 +122,6 @@ SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err
 		cp = address;
 	}
 
-	// now activate network
-	if(  !network_initialize()  ) {
-		err = "Cannot init network!";
-		return INVALID_SOCKET;
-	}
-
 	struct sockaddr_in server_name;
 	memset(&server_name,0,sizeof(server_name));
 	server_name.sin_family=AF_INET;
@@ -139,8 +141,8 @@ SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err
 #else // _WIN32
 	/* inet_anon does not work on BeOS; but since gethostbyname() can
 	 * do this job on all other systems too, we use it only:
-     * instead of if(inet_aton(cp,&server_name.sin_addr)==0) { // Bad address
-     */
+	 * instead of if(inet_aton(cp,&server_name.sin_addr)==0) { // Bad address
+	 */
 	struct hostent *theHost;
 	theHost = gethostbyname( cp );
 	if(theHost) {
@@ -159,78 +161,9 @@ SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err
 		return INVALID_SOCKET;
 	}
 
-#if !defined(__BEOS__)  &&  !defined(__HAIKU__)
-	if(  0 &&  timeout_ms>0  ) {
-		// use non-blocking sockets to have a shorter timeout
-		fd_set fds;
-		struct timeval timeout;
-#ifdef  _WIN32
-		unsigned long opt =1;
-		ioctlsocket(my_client_socket, FIONBIO, &opt);
-#else // _WIN32
-		int opt;
-		if(  (opt = fcntl(my_client_socket, F_GETFL, NULL)) < 0  ) {
-			err = "fcntl error";
-			return INVALID_SOCKET;
-		}
-		opt |= O_NONBLOCK;
-		if( fcntl(my_client_socket, F_SETFL, opt) < 0) {
-			err = "fcntl error";
-			return INVALID_SOCKET;
-		}
-#endif // _WIN32
-		if(  !connect(my_client_socket, (struct sockaddr*) &server_name, sizeof(server_name))   ) {
-#ifdef  _WIN32
-			// WSAEWOULDBLOCK indicate, that it may still succeed
-			if (WSAGetLastError() != WSAEWOULDBLOCK) {
-				FormatMessageA(FORMAT_MESSAGE_FROM_SYSTEM,NULL,WSAGetLastError(),MAKELANGID(LANG_NEUTRAL,SUBLANG_NEUTRAL),err_str,sizeof(err_str),NULL);
-#else // _WIN32
-			// EINPROGRESS indicate, that it may still succeed
-			if(  errno != EINPROGRESS  ) {
-				sprintf( err_str, "Could not connect to %s", cp );
-#endif // _WIN32
-				err = err_str;
-				return INVALID_SOCKET;
-			}
-		}
-
-		// no add only this socket to set
-		FD_ZERO(&fds);
-		FD_SET(my_client_socket, &fds);
-
-		// enter timeout
-		timeout.tv_sec = timeout_ms/1000;
-		timeout.tv_usec = ((timeout_ms%1000)*1000);
-
-		// and wait ...
-		if(  !select( FD_SETSIZE, NULL, &fds, NULL, &timeout)  ) {
-			// some other problem?
-			err = "Call to select failed";
-			return INVALID_SOCKET;
-		}
-
-		// is this socket ok?
-		if (FD_ISSET(my_client_socket, &fds) == 0) {
-			// not in set => timeout
-			err = "Server did not respond!";
-			return INVALID_SOCKET;
-		}
-
-		// make a blocking socket out of it
-#ifdef  _WIN32
-		opt = 0;
-		ioctlsocket(my_client_socket, FIONBIO, &opt);
-#else // _WIN32
-		opt &= (~O_NONBLOCK);
-		fcntl(my_client_socket, F_SETFL, opt);
-#endif // _WIN32
-	} else
-#endif //  !defined(__BEOS__)  &&  !defined(__HAIKU__)
-	{
-		if(connect(my_client_socket,(struct sockaddr *)&server_name,sizeof(server_name))==-1) {
-			sprintf( err_str, "Could not connect to %s", cp );
-			RET_ERR_STR;
-		}
+	if (connect(my_client_socket, (struct sockaddr*)&server_name, sizeof(server_name)) == -1) {
+		sprintf(err_str, "Could not connect to %s", cp);
+		RET_ERR_STR;
 	}
 
 #else // USE_IP4_ONLY
@@ -251,7 +184,7 @@ SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err
 		}
 		if (  cp1  ) {
 			// IPv6 addresse net:[....]:port
-			tstrncpy( address, cp + 1, cp1 - cp >= sizeof(address) ? sizeof(address) : cp1 - cp);
+			tstrncpy( address, cp + 1, (size_t)(cp1 - cp) >= sizeof(address) ? sizeof(address) : cp1 - cp);
 		}
 		else {
 			// Copy the address part
@@ -260,49 +193,22 @@ SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err
 		cp = address;
 	}
 
-	// Now activate network
-	if (  !network_initialize()  ) {
-		err = "Cannot init network!";
-		return INVALID_SOCKET;
-	}
-
 	SOCKET my_client_socket = INVALID_SOCKET;
 
 	bool connected = false;
 
 #ifdef NETTOOL
-
 	// Nettool doesn't have umgebung, so fake it
 	vector_tpl<std::string> ips;
 	ips.append_unique("::");
 	ips.append_unique("0.0.0.0");
-	for (  uint i = 0;  !connected  &&  i < ips.get_count();  i++  ) {
-		std::string ip = ips[i];
-
-#else // NETTOOL
-
+#else
+	vector_tpl<std::string> const& ips = umgebung_t::listen;
+#endif
 	// For each address in the list of listen addresses try and create a socket to transmit on
 	// Use the first one which works
-	for (  uint i = 0;  !connected  &&  i < umgebung_t::listen.get_count();  i++  ) {
-		std::string ip = umgebung_t::listen[i];
-
-#endif // NETTOOL
-
-		// Check address is valid
-		if (  ip.find(":") != std::string::npos  ) {
-			struct sockaddr_in6 sa;
-			if (  inet_pton( AF_INET6, ip.c_str(), &(sa.sin6_addr) ) <= 0  ) {
-				dbg->warning( "network_open_address()", "%s is not a valid IPv6 address, check listen directive in your simuconf.tab", ip.c_str() );
-				continue;
-			}
-		}
-		else {
-			struct sockaddr_in sa;
-			if (  inet_pton( AF_INET, ip.c_str(), &(sa.sin_addr) ) <= 0  ) {
-				dbg->warning( "network_open_address()", "%s is not a valid IPv4 address, check listen directive in your simuconf.tab", ip.c_str() );
-				continue;
-			}
-		}
+	for (uint i = 0; !connected && i != ips.get_count(); ++i) {
+		std::string const& ip = ips[i];
 
 		int ret;
 		char port_nr[8];
@@ -332,63 +238,72 @@ SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err
 		DBG_MESSAGE( "network_open_address()", "Preparing to bind address: %s", ip.c_str() );
 		local_hints.ai_family = PF_UNSPEC;
 		if (  (ret = getaddrinfo( ip.c_str(), 0, &local_hints, &local )) != 0  ) {
-			dbg->error( "network_open_address()", "Failed to getaddrinfo for %s, error was: %s", ip.c_str(), gai_strerror(ret) );
+			dbg->warning( "network_open_address()", "Failed to getaddrinfo for %s, error was: %s", ip.c_str(), gai_strerror(ret) );
+#ifndef NETTOOL
+			umgebung_t::listen.remove_at( i );
+#endif
+			i --;
 			continue;
 		}
 
 		// Now try and open a socket to communicate with our remote endpoint
 		struct addrinfo *walk_local;
 		for(  walk_local = local;  !connected  &&  walk_local != NULL;  walk_local = walk_local->ai_next  ) {
-			my_client_socket = socket( walk_local->ai_family, walk_local->ai_socktype, walk_local->ai_protocol );
-
 			char ipstr_local[INET6_ADDRSTRLEN];
-			switch( walk_local->ai_addr->sa_family ) {
-				case AF_INET:
-					inet_ntop( AF_INET, &(((struct sockaddr_in *)walk_local->ai_addr)->sin_addr), ipstr_local, sizeof ipstr_local );
-					break;
+			socklen_t socklen_local;
 
-				case AF_INET6:
-					inet_ntop( AF_INET6, &(((struct sockaddr_in6 *)walk_local->ai_addr)->sin6_addr), ipstr_local, sizeof ipstr_local );
-					break;
-
-				default:
-					continue;
+			// Correct size for salen parameter of getnameinfo call depends on address family
+			if (  walk_local->ai_family == AF_INET6  ) {
+				socklen_local = sizeof(struct sockaddr_in6);
+			} else {
+				socklen_local = sizeof(struct sockaddr_in);
 			}
+			// Validate address + get string representation for logging
+			if (  (ret = getnameinfo( (walk_local->ai_addr), socklen_local, ipstr_local, sizeof(ipstr_local), NULL, 0, NI_NUMERICHOST )) !=0  ) {
+				dbg->warning( "network_open_address()", "Call to getnameinfo() failed with error: \"%s\"", gai_strerror(ret) );
+				continue;
+			}
+
 			DBG_MESSAGE( "network_open_address()", "Potential local address: %s", ipstr_local );
 
+			my_client_socket = socket( walk_local->ai_family, walk_local->ai_socktype, walk_local->ai_protocol );
 
 			if (  my_client_socket == INVALID_SOCKET  ) {
-				DBG_MESSAGE( "network_open_address()", "Invalid socket, skipping..." );
+				DBG_MESSAGE( "network_open_address()", "Could not create socket! Error: \"%s\"", strerror(GET_LAST_ERROR()) );
 				continue;
 			}
 
 			// Bind socket to local IP
 			if (  bind( my_client_socket, local->ai_addr, local->ai_addrlen )  ) {
-				DBG_MESSAGE( "network_open_address()", "Unable to bind socket to local IP address!" );
+				DBG_MESSAGE( "network_open_address()", "Unable to bind socket to local IP address! Error: \"%s\"", strerror(GET_LAST_ERROR()) );
+				network_close_socket( my_client_socket );
+				my_client_socket = INVALID_SOCKET;
 				continue;
 			}
 
 			// For each address in remote, try and connect
 			struct addrinfo *walk_remote;
-			for(  walk_remote = remote;  !connected  &&  walk_remote != NULL;  walk_remote = walk_remote->ai_next  ) {
+			for (  walk_remote = remote;  !connected  &&  walk_remote != NULL;  walk_remote = walk_remote->ai_next  ) {
+  				char ipstr_remote[INET6_ADDRSTRLEN];
+				socklen_t socklen_remote;
 
-				char ipstr_remote[INET6_ADDRSTRLEN];
-				switch( walk_remote->ai_addr->sa_family ) {
-					case AF_INET:
-						inet_ntop( AF_INET, &(((struct sockaddr_in *)walk_remote->ai_addr)->sin_addr), ipstr_remote, sizeof ipstr_remote );
-						break;
-
-					case AF_INET6:
-						inet_ntop( AF_INET6, &(((struct sockaddr_in6 *)walk_remote->ai_addr)->sin6_addr), ipstr_remote, sizeof ipstr_remote );
-						break;
-
-					default:
-						continue;
+				// Correct size for salen parameter of getnameinfo call depends on address family
+				if (  walk_remote->ai_family == AF_INET6  ) {
+					socklen_remote = sizeof(struct sockaddr_in6);
+				} else {
+					socklen_remote = sizeof(struct sockaddr_in);
 				}
+
+				// Validate remote address + get string representation for logging
+				if (  (ret = getnameinfo( walk_remote->ai_addr, socklen_remote, ipstr_remote, sizeof(ipstr_remote), NULL, 0, NI_NUMERICHOST )) !=0  ) {
+					dbg->warning( "network_open_address()", "Call to getnameinfo() failed with error: \"%s\"", gai_strerror(ret) );
+					continue;
+				}
+
 				DBG_MESSAGE( "network_open_address()", "Potential remote address: %s", ipstr_remote );
 
 				if (  connect( my_client_socket, walk_remote->ai_addr, walk_remote->ai_addrlen ) != 0  ) {
-					DBG_MESSAGE( "network_open_address()", "Could not connect using this socket." );
+					DBG_MESSAGE( "network_open_address()", "Could not connect using this socket. Error: \"%s\"", strerror(GET_LAST_ERROR()) );
 					continue;
 				}
 				connected = true;
@@ -408,8 +323,6 @@ SOCKET network_open_address( const char *cp, long timeout_ms, const char * &err
 		sprintf( err_str, "Could not connect to %s", cp );
 		RET_ERR_STR;
 	}
-
-	(void) timeout_ms;
 #endif // USE_IP4_ONLY
 	return my_client_socket;
 }
@@ -456,38 +369,15 @@ bool network_init_server( int port )
 #else // USE_IP4_ONLY
 
 #ifdef NETTOOL
-
 	// Nettool doesn't have umgebung, so fake it
 	vector_tpl<std::string> ips;
 	ips.append_unique("::");
 	ips.append_unique("0.0.0.0");
-	for (  uint i = 0;  i < ips.get_count();  i++  ) {
-		std::string ip = ips[i];
-
-#else // NETTOOL
-
+#else
+	vector_tpl<std::string> const& ips = umgebung_t::listen;
+#endif
 	// For each address in the list of listen addresses try and create a socket to listen on
-	for (  uint i = 0;  i < umgebung_t::listen.get_count();  i++  ) {
-		std::string ip = umgebung_t::listen[i];
-
-#endif // NETTOOL
-
-		// Check address is valid
-		if (  ip.find(":") != std::string::npos  ) {
-			struct sockaddr_in6 sa;
-			if (  inet_pton( AF_INET6, ip.c_str(), &(sa.sin6_addr) ) <= 0  ) {
-				dbg->warning( "network_init_server()", "%s is not a valid IPv6 address, check listen directive in your simuconf.tab", ip.c_str() );
-				continue;
-			}
-		}
-		else {
-			struct sockaddr_in sa;
-			if (  inet_pton( AF_INET, ip.c_str(), &(sa.sin_addr) ) <= 0  ) {
-				dbg->warning( "network_init_server()", "%s is not a valid IPv4 address, check listen directive in your simuconf.tab", ip.c_str() );
-				continue;
-			}
-		}
-
+	FOR(vector_tpl<std::string>, const& ip, ips) {
 		int ret;
 		char port_nr[16];
 		sprintf( port_nr, "%u", port );
@@ -498,58 +388,67 @@ bool network_init_server( int port )
 		hints.ai_socktype = SOCK_STREAM;
 
 		// Insert potential listen address into hints struct to influence local address to bind to
-		DBG_MESSAGE( "network_init_server()", "Preparing to bind address: %s", ip.c_str() );
+		DBG_MESSAGE( "network_init_server()", "Preparing to bind address: \"%s\"", ip.c_str() );
 		hints.ai_family = PF_UNSPEC;
 		if (  (ret = getaddrinfo( ip.c_str(), port_nr, &hints, &server )) != 0  ) {
-			dbg->error( "network_init_server()", "Failed to getaddrinfo for %s, error was: %s", ip.c_str(), gai_strerror(ret) );
+			dbg->fatal( "network_init_server()", "Call to getaddrinfo() failed for: \"%s\", error was: \"%s\" - check listen directive in simuconf.tab!", ip.c_str(), gai_strerror(ret) );
+		} else {
+			printf( "Attempting to bind listening sockets for: \"%s\"\n", ip.c_str() );
 		}
 
-
 		SOCKET server_socket;
 		struct addrinfo *walk;
+
+		// Open a listen socket for each IP address specified by this entry in the listen list
 		for (  walk = server;  walk != NULL;  walk = walk->ai_next  ) {
-			server_socket = socket( walk->ai_family, walk->ai_socktype, walk->ai_protocol );
 			char ipstr[INET6_ADDRSTRLEN];
-			switch( walk->ai_addr->sa_family ) {
-				case AF_INET:
-					inet_ntop( AF_INET, &(((struct sockaddr_in *)walk->ai_addr)->sin_addr), ipstr, sizeof ipstr );
-					break;
+			socklen_t socklen;
 
-				case AF_INET6:
-					inet_ntop( AF_INET6, &(((struct sockaddr_in6 *)walk->ai_addr)->sin6_addr), ipstr, sizeof ipstr );
-					break;
-
-				default:
-					continue;
+			// Correct size for salen parameter of getnameinfo call depends on address family
+			if (  walk->ai_family == AF_INET6  ) {
+				socklen = sizeof(struct sockaddr_in6);
+			} else {
+				socklen = sizeof(struct sockaddr_in);
 			}
-			DBG_MESSAGE( "network_init_server()", "Potential bind address: %s", ipstr );
 
-			if (  server_socket == INVALID_SOCKET  ) {
-				DBG_MESSAGE( "network_init_server()", "Invalid socket, skipping..." );
+			// Validate address + get string representation for logging
+			if (  (ret = getnameinfo( (walk->ai_addr), socklen, ipstr, sizeof(ipstr), NULL, 0, NI_NUMERICHOST )) != 0  ) {
+				dbg->warning( "network_init_server()", "Call to getnameinfo() failed with error: \"%s\"", gai_strerror(ret) );
 				continue;
 			}
 
+			DBG_MESSAGE( "network_init_server()", "Potential bind address: %s", ipstr );
+
+			server_socket = socket( walk->ai_family, walk->ai_socktype, walk->ai_protocol );
+
+			if (  server_socket == INVALID_SOCKET  ) {
+				DBG_MESSAGE( "network_init_server()", "Could not create socket! Error: \"%s\"", strerror(GET_LAST_ERROR()) );
+				continue;
+			}
+
+			/* Disable IPv4-mapped IPv6 addresses for this IPv6 listen socket
+			   This ensures that we are using separate sockets for dual-stack, one for v4, one for v6 */
 			if (  walk->ai_family == AF_INET6  ) {
 				int on = 1;
-				if (  setsockopt(server_socket, IPPROTO_IPV6, IPV6_V6ONLY, (char*)&on, sizeof(on)) == -1  ) {
-					// only use real IPv6 sockets for IPv6
-					DBG_MESSAGE( "network_init_server()", "Not a real IPv6 socket, skipping..." );
+				if (  setsockopt(server_socket, IPPROTO_IPV6, IPV6_V6ONLY, (char*)&on, sizeof(on)) != 0  ) {
+					dbg->warning( "network_init_server()", "Call to setsockopt() failed for: \"%s\", error was: \"%s\"", ip.c_str(), strerror(GET_LAST_ERROR()) );
+					network_close_socket( server_socket );
+					server_socket = INVALID_SOCKET;
 					continue;
 				}
 			}
 
 			if (  bind( server_socket, walk->ai_addr, walk->ai_addrlen )  ) {
-				/* Hier kann eine Fehlermeldung hin, z.B. mit warn() */
-				DBG_MESSAGE( "network_init_server()", "Unable to bind socket to IP address!" );
-				continue;
+				/* Unable to bind a socket - abort execution as we are supposed to be a server on this interface */
+				dbg->fatal( "network_init_server()", "Unable to bind socket to IP address: \"%s\"", ipstr );
 			}
 
 			if (  listen( server_socket, 32 ) == -1  ) {
-				/* Hier kann eine Fehlermeldung hin, z.B. mit warn() */
-				DBG_MESSAGE( "network_init_server()", "Unable to set socket to listen for incoming connections!" );
-				continue;
+				/* Unable to listen on bound socket - abort execution as we are supposed to be a server on this interface */
+				dbg->fatal( "network_init_server()", "Unable to set socket to listen for incoming connections on: \"%s\"", ipstr );
 			}
 
+			printf("Added valid listen socket for address: \"%s\"\n", ipstr);
 			socket_list_t::add_server( server_socket );
 		}
 		freeaddrinfo( server );
@@ -560,7 +459,7 @@ bool network_init_server( int port )
 		dbg->fatal( "network_init_server()", "Unable to add any server sockets!" );
 	}
 	else {
-		dbg->message( "network_init_server()", "added %d server sockets", socket_list_t::get_server_sockets() );
+		printf("Server started, added %d server sockets\n", socket_list_t::get_server_sockets());
 	}
 
 #endif // USE_IP4_ONLY
@@ -629,22 +528,22 @@ network_command_t* network_check_activity(karte_t *, int timeout)
 			socklen_t size = sizeof(client_name);
 			SOCKET s = accept(accept_sock, (struct sockaddr *)&client_name, &size);
 			if(  s!=INVALID_SOCKET  ) {
-	#ifdef _WIN32
+#ifdef _WIN32
 				uint32 ip = ntohl((uint32)client_name.sin_addr.S_un.S_addr);
-	#else
+#else
 				uint32 ip = ntohl((uint32)client_name.sin_addr.s_addr);
-	#endif
+#endif
 				if (blacklist.contains(net_address_t( ip ))) {
 					// refuse connection
 					network_close_socket(s);
 					continue;
 				}
-	#ifdef  __BEOS__
+#ifdef  __BEOS__
 				char name[256];
 				sprintf(name, "%lh", client_name.sin_addr.s_addr );
-	#else
+#else
 				const char *name = inet_ntoa(client_name.sin_addr);
-	#endif
+#endif
 				dbg->message("check_activity()", "Accepted connection from: %s.",  name);
 				socket_list_t::add_client(s, ip);
 			}
@@ -762,6 +661,7 @@ void network_send_server(network_command_t* nwc )
 		}
 		else {
 			// I am the server
+			nwc->get_packet()->sent_by_server();
 			received_command_queue.append(nwc);
 		}
 	}
@@ -778,11 +678,11 @@ bool network_send_data( SOCKET dest, const char *buf, const uint16 size, uint16
 {
 	count = 0;
 	while (count < size) {
-		int sent = ::send(dest, buf+count, size-count, 0);
+		int sent = send(dest, buf+count, size-count, 0);
 		if (sent == -1) {
 			int err = GET_LAST_ERROR();
 			if (err != EWOULDBLOCK) {
-				dbg->warning("network_send_data", "error %d while sending to [%d]", err, dest);
+				dbg->warning("network_send_data", "error \"%s\" while sending to [%d]", strerror(err), dest);
 				return false;
 			}
 			if (timeout_ms <= 0) {
@@ -807,7 +707,7 @@ bool network_send_data( SOCKET dest, const char *buf, const uint16 size, uint16
 		}
 		if (sent == 0) {
 			// connection closed
-			dbg->error("network_send_data", "connection [%d] already closed (sent %d of &d)", dest, count, size );
+			dbg->warning("network_send_data", "connection [%d] already closed (sent %d of &d)", dest, count, size );
 			return false;
 		}
 		count += sent;
@@ -854,7 +754,7 @@ bool network_receive_data( SOCKET sender, void *dest, const uint16 len, uint16 &
 		}
 		if (res == 0) {
 			// connection closed
-			dbg->error("network_receive_data", "connection [%d] already closed", sender);
+			dbg->warning("network_receive_data", "connection [%d] already closed", sender);
 			return false;
 		}
 		received += res;
@@ -867,9 +767,7 @@ bool network_receive_data( SOCKET sender, void *dest, const uint16 len, uint16 &
 void network_close_socket( SOCKET sock )
 {
 	if(  sock != INVALID_SOCKET  ) {
-#if defined(__HAIKU__)
-		// no closesocket() ?!?
-#elif defined(_WIN32)  ||  defined(__BEOS__)
+#if defined _WIN32 || defined __BEOS__
 		closesocket( sock );
 #else
 		close( sock );
