@@ -299,13 +299,6 @@ bool nwc_chat_t::execute (karte_t* welt)
 
 		dbg->warning("nwc_chat_t::execute", "server, client id: %d", client_id);
 
-		// Invalid client_id means this is a message from the server to itself
-		if (  !socket_list_t::is_valid_client_id( client_id )  ) {
-			// Act on message as if we are a client
-			add_message(welt);
-			return true;
-		}
-
 		// Clients can only send messages as companies they have unlocked
 		if (  player_nr < PLAYER_UNOWNED  &&  !socket_list_t::get_client( client_id ).is_player_unlocked( player_nr )  ) {
 			dbg->warning("nwc_chat_t::execute", "attempt to send message as locked company by client %d, redirecting to PLAYER_UNOWNED", client_id);
@@ -318,7 +311,11 @@ bool nwc_chat_t::execute (karte_t* welt)
 		nwc_chat_t* nwchat = new nwc_chat_t( message, player_nr, info.nickname.c_str(), destination );
 
 		if (  destination == NULL  ) {
-			network_send_all( nwchat, false );
+			// Do not send messages to ourself (server)
+			network_send_all( nwchat, true );
+
+			// Act on message (for display of messages on server, and to keep record of messages for new clients joining)
+			add_message(welt);
 
 			// Log chat message - please don't change order of fields
 			CSV_t csv;
@@ -878,8 +875,8 @@ nwc_tool_t::nwc_tool_t(spieler_t *sp, werkzeug_t *wkz, koord3d pos_, uint32 sync
 	init = init_;
 	tool_client_id = 0;
 	flags = wkz->flags;
-	last_sync_step = sp->get_welt()->get_last_checklist_sync_step();
-	last_checklist = sp->get_welt()->get_last_checklist();
+	last_sync_step = spieler_t::get_welt()->get_last_checklist_sync_step();
+	last_checklist = spieler_t::get_welt()->get_last_checklist();
 	// write custom data of wkz to our internal buffer
 	custom_data = new memory_rw_t(custom_data_buf, lengthof(custom_data_buf), true);
 	if (sp) {
@@ -1121,6 +1118,11 @@ void nwc_tool_t::do_command(karte_t *welt)
 			}
 			// call WORK
 			else {
+				// remove preview tiles of active tool
+				two_click_werkzeug_t *active_wkz = dynamic_cast<two_click_werkzeug_t*>(welt->get_werkzeug(welt->get_active_player_nr()));
+				if(active_wkz  &&  active_wkz->remove_preview_necessary()) {
+					active_wkz->cleanup(true);
+				}
 				const char *err = wkz->work( welt, sp, pos );
 				// only local players or AIs get the callback
 				if (local  ||  sp->get_ai_id()!=spieler_t::HUMAN) {
