@@ -4,11 +4,17 @@
 #include "../simversion.h"
 #include "../simconst.h"
 #include "../simtypes.h"
+#include "../simtools.h"
 #include "../simcolor.h"
 #include "../simmesg.h"
 
 sint8 umgebung_t::pak_tile_height_step = 16;
-sint16 umgebung_t::simple_drawing_tile_size = 24;
+
+bool umgebung_t::simple_drawing = false;
+bool umgebung_t::simple_drawing_fast_forward = true;
+sint16 umgebung_t::simple_drawing_normal = 4;
+sint16 umgebung_t::simple_drawing_default = 24;
+
 char umgebung_t::program_dir[1024];
 const char *umgebung_t::user_dir = 0;
 const char *umgebung_t::savegame_version_str = SAVEGAME_VER_NR;
@@ -80,7 +86,7 @@ bool umgebung_t::window_buttons_right;
 bool umgebung_t::window_frame_active;
 uint8 umgebung_t::verbose_debug;
 uint8 umgebung_t::default_sortmode;
-sint8 umgebung_t::default_mapmode;
+uint32 umgebung_t::default_mapmode;
 uint8 umgebung_t::show_month;
 sint32 umgebung_t::intercity_road_length;
 plainstring umgebung_t::river_type[10];
@@ -101,8 +107,6 @@ bool umgebung_t::left_to_right_graphs;
 uint32 umgebung_t::tooltip_delay;
 uint32 umgebung_t::tooltip_duration;
 
-bool umgebung_t::add_player_name_to_message = true;
-
 uint8 umgebung_t::front_window_bar_color;
 uint8 umgebung_t::front_window_text_color;
 uint8 umgebung_t::bottom_window_bar_color;
@@ -130,7 +134,7 @@ void umgebung_t::init()
 
 	/* station stuff */
 	use_transparency_station_coverage = true;
-	station_coverage_show = NOT_SHOWN_COVERAGE;
+	station_coverage_show = 0;
 
 	show_names = 3;
 
@@ -155,16 +159,8 @@ void umgebung_t::init()
 
 	savegame_version_str = SAVEGAME_VER_NR;
 
-	/**
-	 * show month in date?
-	 * @author hsiegeln
-	 */
 	show_month = DATE_FMT_US;
 
-	/**
-	 * Max. Lnge fr initiale Stadtverbindungen
-	 * @author Hj. Malthaner
-	 */
 	intercity_road_length = 200;
 
 	river_types = 0;
@@ -258,7 +254,14 @@ void umgebung_t::rdwr(loadsave_t *file)
 	file->rdwr_bool( single_info );
 
 	file->rdwr_byte( default_sortmode );
-	file->rdwr_byte( default_mapmode );
+	if(  file->get_version()<111004  ) {
+		sint8 mode = log2(umgebung_t::default_mapmode)-1;
+		file->rdwr_byte( mode );
+		umgebung_t::default_mapmode = mode>=0 ? 1 << mode : 0;
+	}
+	else {
+		file->rdwr_long( umgebung_t::default_mapmode );
+	}
 
 	file->rdwr_bool( window_buttons_right );
 	file->rdwr_bool( window_frame_active );
@@ -304,7 +307,8 @@ void umgebung_t::rdwr(loadsave_t *file)
 	}
 
 	if(  file->get_version()>=110000  ) {
-		file->rdwr_bool( add_player_name_to_message );
+		bool dummy = false;
+		file->rdwr_bool(dummy); //was add_player_name_to_message
 		file->rdwr_short( window_snap_distance );
 	}
 	else if(  file->is_loading()  ) {
