@@ -175,7 +175,7 @@ public:
 
 	int get_post_level() const;
 
-	void set_tile(const haus_tile_besch_t *t);
+	void set_tile( const haus_tile_besch_t *t, bool start_with_construction );
 
 	const haus_tile_besch_t *get_tile() const { return tile; }
 
