@@ -19,6 +19,9 @@
 
 #include "../besch/tunnel_besch.h"
 
+#include "leitung2.h"
+#include "../bauer/wegbauer.h"
+
 #include "tunnel.h"
 
 
@@ -130,6 +133,10 @@ void tunnel_t::laden_abschliessen()
 			weg->set_max_speed(besch->get_topspeed());
 			spieler_t::add_maintenance( sp, -weg->get_besch()->get_wartung());
 		}
+		leitung_t *lt = gr->get_leitung();
+		if(lt) {
+			spieler_t::add_maintenance( sp, -lt->get_besch()->get_wartung());
+		}
 		spieler_t::add_maintenance( sp,  besch->get_wartung() );
 	}
 }
@@ -149,8 +156,10 @@ void tunnel_t::entferne( spieler_t *sp2 )
 		const grund_t *gr = welt->lookup(get_pos());
 		if(gr) {
 			weg_t *weg = gr->get_weg( besch->get_waytype() );
-			weg->set_max_speed( weg->get_besch()->get_topspeed() );
-			spieler_t::add_maintenance( sp,  weg->get_besch()->get_wartung());
+			if(weg)	{
+				weg->set_max_speed( weg->get_besch()->get_topspeed() );
+				spieler_t::add_maintenance( sp,  weg->get_besch()->get_wartung());
+			}
 			spieler_t::add_maintenance( sp,  -besch->get_wartung() );
 		}
 	}
