@@ -17,7 +17,7 @@ class freight_list_sorter_t
 public:
 	enum sort_mode_t { by_name=0, by_via=1, by_via_sum=2, by_amount=3};
 
-	static void sort_freight(const vector_tpl<ware_t>* warray, cbuffer_t& buf, sort_mode_t sort_mode, const slist_tpl<ware_t>* full_list, const char* what_doing, karte_t *world);
+	static void sort_freight(vector_tpl<ware_t> const& warray, cbuffer_t& buf, sort_mode_t sort_mode, const slist_tpl<ware_t>* full_list, const char* what_doing, karte_t *world);
 
 private:
 	static karte_t *welt;
