@@ -10,15 +10,10 @@
 #include <algorithm>
 #include <stdio.h>
 
-#include "../simcolor.h"
 #include "../simtools.h"
 #include "../simworld.h"
-#include "../simgraph.h"
-#include "../simskin.h"
 #include "../simwerkz.h"
 
-
-
 #include "../bauer/hausbauer.h"
 
 #include "../besch/grund_besch.h"
