@@ -39,8 +39,7 @@ public:
 
 	void sort(citylist::sort_mode_t sortby, bool sortreverse);
 
-	/** Events werden hiermit an die GUI-Komponenten gemeldet */
-	bool infowin_event(const event_t*);
+	bool infowin_event(event_t const*) OVERRIDE;
 
 	/** Recalc the current size required to display everything, and set komponente groesse */
 	void recalc_size();
