@@ -6,24 +6,22 @@
  */
 
 #include "gui_button.h"
-#include "../gui_frame.h"
 
-#include "../../simdebug.h"
 #include "../../simcolor.h"
 #include "../../simgraph.h"
 #include "../../simevent.h"
 #include "../../simwin.h"
 
-#include "../../besch/reader/obj_reader.h"
-
 #include "../../dataobj/translator.h"
 
 #include "../../simskin.h"
 #include "../../besch/skin_besch.h"
+#include "../../utils/simstring.h"
+
+#include "../gui_frame.h"
 
 #define STATE_MASK (127)
 #define AUTOMATIC_MASK (255)
-static const char *empty="";
 
 // default button codes
 #define SQUARE_BUTTON 0
@@ -180,7 +178,7 @@ void button_t::draw_roundbutton(sint16 x, sint16 y, sint16 w, sint16 h, bool pre
 		const sint16 rw = skinverwaltung_t::window_skin->get_bild(13)->get_pic()->w;
 		// first the center (may need extra clipping)
 		if(w-lw-rw<64) {
-			struct clip_dimension cl=display_get_clip_wh();
+			clip_dimension const cl = display_get_clip_wh();
 			display_set_clip_wh(cl.x, cl.y, max(0,min(x+w-rw,cl.xx)-cl.x), cl.h );
 			display_button_image(x+lw, y, RB_BODY_BUTTON, pressed);
 			display_set_clip_wh(cl.x, cl.y, cl.w, cl.h );
@@ -235,7 +233,7 @@ void button_t::draw_scrollbar(sint16 x, sint16 y, sint16 w, sint16 h, bool horiz
 			const sint16 rw = skinverwaltung_t::window_skin->get_bild(image_offset+1)->get_pic()->w;
 			// first the center (may need extra clipping)
 			if(w-lw-rw<64) {
-				struct clip_dimension cl=display_get_clip_wh();
+				clip_dimension const cl = display_get_clip_wh();
 				display_set_clip_wh(cl.x, cl.y, max(0,min(x+w-rw,cl.xx)-cl.x), cl.h );
 				display_color_img(skinverwaltung_t::window_skin->get_bild_nr(image_offset+2), x+lw, y, 0, false, true);
 				display_set_clip_wh(cl.x, cl.y, cl.w, cl.h );
@@ -258,7 +256,7 @@ void button_t::draw_scrollbar(sint16 x, sint16 y, sint16 w, sint16 h, bool horiz
 			const sint16 rh = skinverwaltung_t::window_skin->get_bild(image_offset+1)->get_pic()->h;
 			// first the center (may need extra clipping)
 			if(h-lh-rh<64) {
-				struct clip_dimension cl=display_get_clip_wh();
+				clip_dimension const cl = display_get_clip_wh();
 				display_set_clip_wh(cl.x, cl.y, cl.w, max(0,min(y+h-rh,cl.yy)-cl.y) );
 				display_color_img(skinverwaltung_t::window_skin->get_bild_nr(image_offset+2), x, y+lh, 0, false, true);
 				display_set_clip_wh(cl.x, cl.y, cl.w, cl.h );
@@ -281,7 +279,7 @@ button_t::button_t() :
 	gui_komponente_t(true)
 {
 	b_no_translate = false;
-	translated_text = text = empty;
+	translated_text = text = "";
 	pressed = false;
 	type = box;
 	foreground = COL_BLACK;
@@ -310,7 +308,7 @@ void button_t::set_typ(enum type t)
 	type = t;
 	switch (type&STATE_MASK) {
 		case square:
-			if(  translated_text  &&  strlen(translated_text)>0  ) {
+			if (!strempty(translated_text)) {
 				groesse.x = 16 + proportional_string_width( translated_text );
 			}
 			else {
@@ -347,7 +345,7 @@ void button_t::set_text(const char * text)
 	this->text = text;
 	translated_text = b_no_translate ? text : translator::translate(text);
 
-	if(  (type&STATE_MASK)==square  &&  translated_text  &&  strlen(translated_text)>0  ) {
+	if ((type & STATE_MASK) == square && !strempty(translated_text)) {
 		groesse.x = 16 + proportional_string_width( translated_text );
 	}
 }
@@ -461,11 +459,13 @@ void button_t::zeichnen(koord offset)
 		return;
 	}
 
-	const int bx = offset.x + pos.x;
-	const int by = offset.y + pos.y;
+	const KOORD_VAL bx = offset.x + pos.x;
+	const KOORD_VAL by = offset.y + pos.y;
 
-	const int bw = groesse.x;
-	const int bh = groesse.y;
+	const KOORD_VAL bw = groesse.x;
+	const KOORD_VAL bh = groesse.y;
+	// mean offset to center zero line relative to the button
+	const KOORD_VAL y_text_offset = (D_BUTTON_HEIGHT-LINESPACE)/2;
 
 	switch (type&STATE_MASK) {
 
@@ -479,7 +479,7 @@ void button_t::zeichnen(koord offset)
 				}
 				display_fillbox_wh_clip(bx+1, by+1, bw-2, bh-2, background, false);
 				int len = proportional_string_width(translated_text);
-				display_proportional_clip(bx+max((bw-len)/2,0),by+(bh-large_font_height)/2, translated_text, ALIGN_LEFT, b_enabled ? foreground : COL_GREY4, true);
+				display_proportional_clip(bx+max((bw-len)/2,0),by+y_text_offset, translated_text, ALIGN_LEFT, b_enabled ? foreground : COL_GREY4, true);
 				if(  win_get_focus()==this  ) {
 					// white box around
 					display_fillbox_wh_clip(bx, by, bw, 1, COL_WHITE, false);
@@ -493,7 +493,7 @@ void button_t::zeichnen(koord offset)
 		case roundbox: // new box with round corners
 			{
 				draw_roundbutton( bx, by, bw, bh, pressed );
-				display_proportional_clip(bx+(bw>>1),by+(bh-large_font_height)/2, translated_text, ALIGN_MIDDLE, b_enabled ? foreground : COL_GREY4, true);
+				display_proportional_clip(bx+(bw>>1),by+y_text_offset, translated_text, ALIGN_MIDDLE, b_enabled ? foreground : COL_GREY4, true);
 				if(  win_get_focus()==this  ) {
 					// white box around
 					const int rh = ( b_cap_left!=IMG_LEER && bh==14 ) ? skinverwaltung_t::window_skin->get_bild(13)->get_pic()->h : bh;
@@ -515,7 +515,7 @@ void button_t::zeichnen(koord offset)
 					display_fillbox_wh_clip( bx+1, by+1, 9, 9, pressed ? MN_GREY3 : MN_GREY1, true );
 				}
 				if(  text  ) {
-					display_proportional_clip(bx+16,by+(12-large_font_height)/2, translated_text, ALIGN_LEFT, b_enabled ? foreground : COL_GREY4, true);
+					display_proportional_clip(bx+16,by+y_text_offset, translated_text, ALIGN_LEFT, b_enabled ? foreground : COL_GREY4, true);
 				}
 				if(  win_get_focus()==this  ) {
 					// white box around
