@@ -304,9 +304,9 @@ void gui_vehicleinfo_t::zeichnen(koord offset)
 
 				// bonus stuff
 				int len = 5+display_proportional_clip( pos.x+w+offset.x, pos.y+offset.y+total_height+extra_y, translator::translate("Max income:"), ALIGN_LEFT, COL_BLACK, true );
-				const sint32 grundwert128 = v->get_fracht_typ()->get_preis()<<7;
+				const sint32 grundwert128 = v->get_fracht_typ()->get_preis() * v->get_besitzer()->get_welt()->get_settings().get_bonus_basefactor();	// bonus price will be always at least this
 				const sint32 grundwert_bonus = v->get_fracht_typ()->get_preis()*(1000l+kmh_base*v->get_fracht_typ()->get_speed_bonus());
-				const sint32 price = (v->get_fracht_max()*(grundwert128>grundwert_bonus ? grundwert128 : grundwert_bonus))/30 - v->get_betriebskosten();
+				const sint32 price = (v->get_fracht_max()*(grundwert128>grundwert_bonus ? grundwert128 : grundwert_bonus))/3000 - v->get_betriebskosten();
 				money_to_string( number, price/100.0 );
 				display_proportional_clip( pos.x+w+offset.x+len, pos.y+offset.y+total_height+extra_y, number, ALIGN_LEFT, price>0?MONEY_PLUS:MONEY_MINUS, true );
 				extra_y += LINESPACE;
@@ -330,6 +330,14 @@ void gui_vehicleinfo_t::zeichnen(koord offset)
 				}
 				extra_y += returns*LINESPACE;
 			}
+			else {
+				// bonus stuff
+				int len = 5+display_proportional_clip( pos.x+w+offset.x, pos.y+offset.y+total_height+extra_y, translator::translate("Max income:"), ALIGN_LEFT, COL_BLACK, true );
+				money_to_string( number, v->get_betriebskosten()/(-100.0) );
+				display_proportional_clip( pos.x+w+offset.x+len, pos.y+offset.y+total_height+extra_y, number, ALIGN_LEFT, v->get_betriebskosten()<=0?MONEY_PLUS:MONEY_MINUS, true );
+				extra_y += LINESPACE;
+
+			}
 			//skip at least five lines
 			total_height += max(extra_y+LINESPACE,5*LINESPACE);
 		}
