@@ -17,7 +17,6 @@
 #include "../simwin.h"
 #include "../simimg.h"
 #include "../simtools.h"
-#include "../simskin.h"
 #include "../simintr.h"
 
 #include "../dataobj/einstellungen.h"
@@ -45,6 +44,7 @@
 #define RIGHT_COLUMN_WIDTH (60)
 
 
+
 koord enlarge_map_frame_t::koord_from_rotation(settings_t const* const sets, sint16 const x, sint16 const y, sint16 const w, sint16 const h)
 {
 	koord offset( sets->get_origin_x(), sets->get_origin_y() );
@@ -58,7 +58,6 @@ koord enlarge_map_frame_t::koord_from_rotation(settings_t const* const sets, sin
 }
 
 
-
 enlarge_map_frame_t::enlarge_map_frame_t(spieler_t *, karte_t *w) :
 	gui_frame_t( translator::translate("enlarge map") ),
 	sets(new settings_t(w->get_settings())), // Make a copy.
@@ -124,6 +123,11 @@ enlarge_map_frame_t::enlarge_map_frame_t(spieler_t *, karte_t *w) :
 }
 
 
+enlarge_map_frame_t::~enlarge_map_frame_t()
+{
+	delete sets;
+}
+
 
 /**
  * This method is called if an action is triggered
@@ -151,10 +155,6 @@ bool enlarge_map_frame_t::action_triggered( gui_action_creator_t *komp,value_t v
 	}
 	else if(komp==&start_button) {
 		// since soon those are invalid
-		news_img* info_win = new news_img("Vergroessere die Karte\n", skinverwaltung_t::neueweltsymbol->get_bild_nr(0));
-		create_win(200, 100, info_win, w_info, magic_none);
-		// just hide it for the moment ...
-		win_set_pos( this, display_get_width()+2, display_get_height()+2 );
 		intr_refresh_display( true );
 		welt->enlarge_map(sets, NULL);
 		destroy_all_win( true );
@@ -166,7 +166,6 @@ bool enlarge_map_frame_t::action_triggered( gui_action_creator_t *komp,value_t v
 }
 
 
-
 void enlarge_map_frame_t::zeichnen(koord pos, koord gr)
 {
 	while (welt->get_settings().get_rotation() != sets->get_rotation()) {
@@ -194,7 +193,6 @@ void enlarge_map_frame_t::zeichnen(koord pos, koord gr)
 }
 
 
-
 /**
  * Berechnet Preview-Karte neu. Inititialisiert RNG neu!
  * @author Hj. Malthaner
@@ -225,14 +223,14 @@ void enlarge_map_frame_t::update_preview()
 					color = COL_WHITE;
 				}
 				else {
-					const sint16 height = welt->lookup_hgt( pos )*Z_TILE_STEP;
-					color = reliefkarte_t::calc_hoehe_farbe(height, sets->get_grundwasser()/Z_TILE_STEP);
+					const sint16 height = welt->lookup_hgt( pos );
+					color = reliefkarte_t::calc_hoehe_farbe(height, sets->get_grundwasser());
 				}
 			}
 			else {
 				// new part
 				const sint16 height = karte_t::perlin_hoehe(sets, pos, koord(old_x,old_y) );
-				color = reliefkarte_t::calc_hoehe_farbe(height*Z_TILE_STEP, sets->get_grundwasser()/Z_TILE_STEP);
+				color = reliefkarte_t::calc_hoehe_farbe(height, sets->get_grundwasser());
 			}
 			karte[j*preview_size+i] = color;
 		}
@@ -268,6 +266,6 @@ void enlarge_map_frame_t::update_preview()
 			sizeof(void*) * 4
 		) * sx * sy
 	) / (1024 * 1024);
-	sprintf(memory_str, translator::translate("3WORLD_CHOOSE"), memory);
+	sprintf(memory_str, translator::translate("Size (%d MB):"), memory);
 
 }
