@@ -9,7 +9,6 @@
 #include "../simline.h"
 #include "../simcolor.h"
 #include "../simhalt.h"
-#include "../simskin.h"
 #include "../simworld.h"
 #include "../simmenu.h"
 #include "../simgraph.h"
@@ -176,12 +175,12 @@ void fahrplan_gui_stats_t::zeichnen(koord offset)
 			buf.clear();
 			buf.printf("%i) ", ++i);
 			gimme_stop_name(buf, welt, sp, e);
-			PLAYER_COLOR_VAL const c = sel == 0 ? COL_BLACK : COL_WHITE;
+			PLAYER_COLOR_VAL const c = sel == 0 ? COL_WHITE : COL_BLACK;
 			sint16           const w = display_proportional_clip(offset.x + 4 + 10, offset.y, buf, ALIGN_LEFT, c, true);
 			if (width < w) width = w;
 
 			// the goto button (right arrow)
-			image_id const img = sel == 0 ? button_t::arrow_right_normal : button_t::arrow_right_pushed;
+			image_id const img = sel == 0 ? button_t::arrow_right_pushed : button_t::arrow_right_normal;
 			display_color_img(img, offset.x + 2, offset.y, 0, false, true);
 		}
 		set_groesse(koord(width + 16, fpl->get_count() * (LINESPACE + 1)));
@@ -220,7 +219,7 @@ fahrplan_gui_t::~fahrplan_gui_t()
 	if(  sp  ) {
 		update_werkzeug( false );
 		// hide schedule on minimap (may not current, but for safe)
-		reliefkarte_t::get_karte()->set_current_fpl(NULL, 0); // (*fpl,player_nr)
+		reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
 	}
 	delete fpl;
 
@@ -249,6 +248,8 @@ fahrplan_gui_t::fahrplan_gui_t(schedule_t* fpl_, spieler_t* sp_, convoihandle_t
 		show_line_selector(false);
 	}
 	else {
+		// set this schedule as current to show on minimap if possible
+		reliefkarte_t::get_karte()->set_current_cnv( cnv );
 		old_line = new_line = cnv_->get_line();
 	}
 	old_line_count = 0;
@@ -359,9 +360,6 @@ fahrplan_gui_t::fahrplan_gui_t(schedule_t* fpl_, spieler_t* sp_, convoihandle_t
 
 	set_resizemode(diagonal_resize);
 	resize( koord(0,0) );
-
-	// set this schedule as current to show on minimap if possible
-	reliefkarte_t::get_karte()->set_current_fpl(fpl, sp->get_player_nr()); // (*fpl,player_nr)
 }
 
 
