@@ -21,8 +21,11 @@
 #include "gui_frame.h"
 
 
-goods_stats_t::goods_stats_t()
+karte_t *goods_stats_t::welt = NULL;
+
+goods_stats_t::goods_stats_t( karte_t *wl )
 {
+	welt = wl;
 	set_groesse(koord(BUTTON4_X+D_BUTTON_WIDTH+2,(warenbauer_t::get_waren_anzahl()-1)*(LINESPACE+1)));
 }
 
@@ -57,7 +60,7 @@ void goods_stats_t::zeichnen(koord offset)
 		display_proportional_clip(offset.x + 14, yoff,	buf, ALIGN_LEFT, COL_BLACK, true);
 
 		// prissi
-		const sint32 grundwert128 = wtyp->get_preis()<<7;
+		const sint32 grundwert128 = wtyp->get_preis() * welt->get_settings().get_bonus_basefactor();	// bonus price will be always at least this
 		const sint32 grundwert_bonus = wtyp->get_preis()*(1000l+(bonus-100l)*wtyp->get_speed_bonus());
 		const sint32 price = (grundwert128>grundwert_bonus ? grundwert128 : grundwert_bonus);
 		money_to_string( money_buf, price/300000.0 );
