@@ -13,12 +13,10 @@
 #include "halt_list_frame.h"
 #include "halt_list_filter_frame.h"
 
-#include "../simskin.h"
 #include "../simhalt.h"
 #include "../simware.h"
 #include "../simfab.h"
 #include "../simwin.h"
-#include "../simcolor.h"
 #include "../besch/skin_besch.h"
 
 #include "../bauer/warenbauer.h"
@@ -134,12 +132,14 @@ static bool passes_filter_special(haltestelle_t const& s)
 
 	if (halt_list_frame_t::get_filter(halt_list_frame_t::ueberfuellt_filter)) {
 		COLOR_VAL const farbe = s.get_status_farbe();
-		if (farbe == COL_RED || farbe == COL_ORANGE) return true;
+		if (farbe != COL_RED  &&  farbe != COL_ORANGE) {
+			return false; // not overcrowded
+		}
 	}
 
 	if (halt_list_frame_t::get_filter(halt_list_frame_t::ohneverb_filter)) {
 		for (uint8 i = 0; i < warenbauer_t::get_max_catg_index(); ++i){
-			if (s.get_connections(i).empty()) return false; // only display stations with NO connection
+			if (!s.get_connections(i).empty()) return false; // only display stations with NO connection
 		}
 	}
 
