@@ -8,23 +8,36 @@
 #ifndef gui_help_frame_h
 #define gui_help_frame_h
 
+#include <string>
+
 #include "gui_frame.h"
 #include "components/gui_scrollpane.h"
 #include "components/gui_flowtext.h"
 #include "components/action_listener.h"
 
+
 class help_frame_t : public gui_frame_t, action_listener_t
 {
 private:
-	gui_scrollpane_t scrolly;
-	gui_flowtext_t flow;
+	gui_scrollpane_t scrolly_generaltext;
+	gui_flowtext_t generaltext;
+
+	gui_scrollpane_t scrolly_helptext;
+	gui_flowtext_t helptext;
+
+	std::string title;
+
+	// show the help to one topic
+	void set_helpfile(const char *filename, bool resize_frame );
+
+	help_frame_t(char const* filename);
 
 public:
 	help_frame_t();
-	help_frame_t(char const* filename);
 
-	void set_text(const char * text);
+	static void open_help_on( const char *helpfilename );
 
+	void set_text(const char * text, bool resize = true );
 
 	/**
 	 * resize window in response to a resize event
@@ -32,15 +45,7 @@ public:
 	 */
 	void resize(const koord delta);
 
-	/**
-	 * This method is called if an action is triggered
-	 * @author Hj. Malthaner
-	 *
-	 * Returns true, if action is done and no more
-	 * components should be triggered.
-	 * V.Meyer
-	 */
-	bool action_triggered( gui_action_creator_t *komp, value_t extra);
+	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 };
 
 #endif
