@@ -12,7 +12,7 @@
 #include "components/gui_label.h"
 #include "components/gui_textarea.h"
 #include "components/gui_textinput.h"
-#include "components/location_view_t.h"
+#include "components/gui_location_view_t.h"
 #include "components/action_listener.h"
 
 class label_t;
@@ -39,15 +39,7 @@ private:
 public:
 	label_info_t(karte_t *welt, label_t* l);
 
-	/**
-	 * This method is called if an action is triggered
-	 * @author Hj. Malthaner
-	 *
-	 * Returns true, if action is done and no more
-	 * components should be triggered.
-	 * V.Meyer
-	 */
-	bool action_triggered( gui_action_creator_t *komp, value_t extra);
+	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 
 	// rotated map need new info ...
 	void map_rotate90( sint16 );
