@@ -9,9 +9,7 @@
 
 #include "../simgraph.h"
 #include "../simtypes.h"
-#include "../simcolor.h"
 #include "../simworld.h"
-#include "../simskin.h"
 #include "../player/simplay.h"
 
 #include "../dings/gebaeude.h"
