@@ -7,6 +7,7 @@
 #include "../dataobj/fahrplan.h"
 #include "../dataobj/translator.h"
 #include "../dataobj/loadsave.h"
+#include "../gui/karte.h"
 #include "../simline.h"
 #include "../simwin.h"
 #include "../simwerkz.h"
@@ -19,6 +20,10 @@ line_management_gui_t::line_management_gui_t(linehandle_t line, spieler_t* sp) :
 	fahrplan_gui_t(line->get_schedule()->copy(), sp, convoihandle_t() )
 {
 	this->line = line;
+	// has this line a single running convoi?
+	if(  line->count_convoys() > 0  ) {
+		reliefkarte_t::get_karte()->set_current_cnv( line->get_convoy(0) );
+	}
 	show_line_selector(false);
 }
 
