@@ -28,10 +28,13 @@
 #include "../dataobj/loadsave.h"
 #include "../besch/fabrik_besch.h"
 #include "../simfab.h"
+#include "../simtools.h"
 
 
 static koord old_ij=koord::invalid;
 
+karte_t *map_frame_t::welt;
+
 koord map_frame_t::size=koord(0,0);
 bool map_frame_t::legend_visible=false;
 bool map_frame_t::scale_visible=false;
@@ -62,42 +65,47 @@ public:
 static vector_tpl<legend_entry_t> legend(16);
 
 
-// @author hsiegeln
-const char map_frame_t::map_type[reliefkarte_t::MAX_MAP_BUTTON][64] =
-{
-	"Towns",
-	"Passagiere",
-	"Post",
-	"Fracht",
-	"Status",
-	"Service",
-	"Traffic",
-	"Origin",
-	"Destination",
-	"hl_btn_sort_waiting",
-	"Tracks",
-	"Speedlimit",
-	"Powerlines",
-	"Tourists",
-	"Factories",
-	"Depots",
-	"Forest",
-	"CityLimit",
-	"PaxDest",
-	"Ownership"
-};
+typedef struct {
+	COLOR_VAL color;
+	COLOR_VAL select_color;
+	const char *button_text;
+	const char *tooltip_text;
+	reliefkarte_t::MAP_MODES mode;
+} map_button_t;
 
-const uint8 map_frame_t::map_type_color[reliefkarte_t::MAX_MAP_BUTTON] =
-{
-	215, 23, 31, 157, 46, 55, 63, 133, 79, 191, 207, 11, 123, 221, 71, 135, 127, 198, 23, COL_BLUE
+map_button_t button_init[MAP_MAX_BUTTONS] = {
+	{ COL_LIGHT_GREEN,  COL_DARK_GREEN,  "Towns", "Overlay town names", reliefkarte_t::MAP_TOWN },
+	{ COL_LIGHT_GREEN,  COL_DARK_GREEN,  "CityLimit", "Overlay city limits", reliefkarte_t::MAP_CITYLIMIT },
+	{ COL_WHITE,        COL_BLACK,       "Buildings", "Show level of city buildings", reliefkarte_t::MAP_LEVEL },
+	{ COL_LIGHT_GREEN,  COL_DARK_GREEN,  "PaxDest", "Overlay passenger destinations when a town window is open", reliefkarte_t::MAP_PAX_DEST },
+	{ COL_LIGHT_GREEN,  COL_DARK_GREEN,  "Tourists", "Highlite tourist attraction", reliefkarte_t::MAP_TOURIST },
+	{ COL_LIGHT_GREEN,  COL_DARK_GREEN,  "Factories", "Highlite factories", reliefkarte_t::MAP_FACTORIES },
+	{ COL_LIGHT_YELLOW, COL_BLACK,        "Passagiere", "Show passenger coverage/passenger network", reliefkarte_t::MAP_PASSENGER },
+	{ COL_LIGHT_YELLOW, COL_BLACK,        "Post", "Show mail service coverage/mail network", reliefkarte_t::MAP_MAIL },
+	{ COL_LIGHT_YELLOW, COL_BLACK,        "Fracht", "Show transported freight/freight network", reliefkarte_t::MAP_FREIGHT },
+	{ COL_LIGHT_PURPLE, COL_DARK_PURPLE,  "Status", "Show capacity and if halt is overcrowded", reliefkarte_t::MAP_STATUS },
+	{ COL_LIGHT_PURPLE, COL_DARK_PURPLE,  "hl_btn_sort_waiting", "Show how many people/much is waiting at halts", reliefkarte_t::MAP_WAITING },
+	{ COL_LIGHT_PURPLE, COL_DARK_PURPLE,  "Queing", "Show the change of waiting at halts", reliefkarte_t::MAP_WAITCHANGE },
+	{ COL_LIGHT_PURPLE, COL_DARK_PURPLE,  "Service", "Show how many convoi reach a station", reliefkarte_t::MAP_SERVICE },
+	{ COL_LIGHT_PURPLE, COL_DARK_PURPLE,  "Transfers", "Sum of departure/arrivals at halts", reliefkarte_t::MAP_TRANSFER },
+	{ COL_LIGHT_PURPLE, COL_DARK_PURPLE,  "Origin", "Show initial passenger departure", reliefkarte_t::MAP_ORIGIN },
+	{ COL_WHITE,        COL_BLACK,        "Traffic", "Show usage of network", reliefkarte_t::MAP_TRAFFIC },
+	{ COL_WHITE,        COL_BLACK,        "Speedlimit", "Show speedlimit of ways", reliefkarte_t::MAX_SPEEDLIMIT },
+	{ COL_WHITE,        COL_BLACK,        "Tracks", "Highlight railroad tracks", reliefkarte_t::MAP_TRACKS },
+	{ COL_LIGHT_GREEN,  COL_DARK_GREEN,   "Depots", "Highlite depots", reliefkarte_t::MAP_DEPOT },
+	{ COL_WHITE,        COL_BLACK,        "Powerlines", "Highlite electrical transmission lines", reliefkarte_t::MAP_POWERLINES },
+	{ COL_WHITE,        COL_BLACK,        "Forest", "Highlite forests", reliefkarte_t::MAP_FOREST },
+	{ COL_WHITE,        COL_BLACK,        "Ownership", "Show the owenership of infrastructure", reliefkarte_t::MAP_OWNER }
 };
 
 
-map_frame_t::map_frame_t(karte_t *welt) :
+map_frame_t::map_frame_t(karte_t *w) :
 	gui_frame_t( translator::translate("Reliefkarte") ),
 	scrolly(reliefkarte_t::get_karte()),
 	zoom_label("map zoom")
 {
+	welt = w;
+
 	// show the various objects
 	b_show_legend.init(button_t::roundbox_state, "Show legend", koord(BUTTON1_X,0), koord(D_BUTTON_WIDTH-1,D_BUTTON_HEIGHT));
 	b_show_legend.set_tooltip("Shows buttons on special topics.");
@@ -115,44 +123,39 @@ map_frame_t::map_frame_t(karte_t *welt) :
 	add_komponente(&b_show_directory);
 
 	// zoom levels
-	zoom_buttons[0].init(button_t::repeatarrowleft, NULL, koord(2,D_BUTTON_HEIGHT+4));
+	zoom_buttons[0].init(button_t::repeatarrowleft, NULL, koord(BUTTON1_X,D_BUTTON_HEIGHT+D_V_SPACE));
 	zoom_buttons[0].add_listener( this );
 	add_komponente( zoom_buttons+0 );
 
-	zoom_buttons[1].init(button_t::repeatarrowright, NULL, koord(40,D_BUTTON_HEIGHT+4));
+	zoom_buttons[1].init(button_t::repeatarrowright, NULL, koord(BUTTON1_X+40,D_BUTTON_HEIGHT+D_V_SPACE));
 	zoom_buttons[1].add_listener( this );
 	add_komponente( zoom_buttons+1 );
 
-	zoom_label.set_pos( koord(54,D_BUTTON_HEIGHT+4) );
+	zoom_label.set_pos( koord(BUTTON1_X+54,D_BUTTON_HEIGHT+D_V_SPACE) );
 	add_komponente( &zoom_label );
 
 	// rotate map 45
-	b_rotate45.init(button_t::square_state, "isometric map", koord(D_BUTTON_WIDTH+40,D_BUTTON_HEIGHT+4));
+	b_rotate45.init( button_t::square_state, "isometric map", koord(BUTTON1_X+54+proportional_string_width(zoom_label.get_text_pointer())+D_H_SPACE+10,D_BUTTON_HEIGHT+D_V_SPACE));
 	b_rotate45.set_tooltip("Similar view as the main window");
 	b_rotate45.add_listener(this);
 	add_komponente(&b_rotate45);
 
-	// show/hide factory links
-	b_show_fab_connections.init(button_t::square_state, "factory details", koord(2,D_BUTTON_HEIGHT*2+4)); // right align
-	b_show_fab_connections.set_tooltip("Shows consumer/suppliers for factories");
-	b_show_fab_connections.add_listener(this);
-	add_komponente( &b_show_fab_connections );
+	b_overlay_networks.init(button_t::square_state, "Networks", koord(BUTTON1_X,D_BUTTON_HEIGHT*2+2*D_V_SPACE));
+	b_overlay_networks.set_tooltip("Overlay schedules/network");
+	b_overlay_networks.add_listener(this);
+	b_overlay_networks.set_visible( legend_visible );
+	b_overlay_networks.pressed = (umgebung_t::default_mapmode & reliefkarte_t::MAP_LINES)!=0;
+	add_komponente( &b_overlay_networks );
 
 	// filter factory list
-	b_filter_factory_list.init(button_t::square_state, "Show only used", koord(D_BUTTON_WIDTH+40,D_BUTTON_HEIGHT*2+4));
+	b_filter_factory_list.init(button_t::square_state, "Show only used", koord(BUTTON1_X,D_BUTTON_HEIGHT*3+4));
 	b_filter_factory_list.set_tooltip("In the industry legend show only currently existing factories");
 	b_filter_factory_list.add_listener(this);
-	b_filter_factory_list.disable();
+	b_filter_factory_list.set_visible( directory_visible );
 	add_komponente( &b_filter_factory_list );
 
-	// show/hide schedule
-	b_show_schedule.init(button_t::square_state, "Show schedules", koord(2,D_BUTTON_HEIGHT*3+4)); // right align
-	b_show_schedule.set_tooltip("Shows the currently selected schedule");
-	b_show_schedule.add_listener(this);
-	add_komponente( &b_show_schedule );
-
 	// init factory name legend
-	update_factory_legend(welt);
+	update_factory_legend();
 
 	// init the rest
 	scrolly.set_pos( koord(0, D_BUTTON_HEIGHT*4 + 2) );
@@ -161,11 +164,13 @@ map_frame_t::map_frame_t(karte_t *welt) :
 	add_komponente(&scrolly);
 
 	// and now the buttons
-	for (int type=0; type<reliefkarte_t::MAX_MAP_BUTTON; type++) {
-		filter_buttons[type].init(button_t::box_state, translator::translate(map_type[type]), koord(0,0), koord(D_BUTTON_WIDTH, D_BUTTON_HEIGHT));
-		filter_buttons[type].background = map_type_color[type];
+	for (int type=0; type<MAP_MAX_BUTTONS; type++) {
+		filter_buttons[type].init( button_t::box_state, button_init[type].button_text, koord(0,0), koord(D_BUTTON_WIDTH, D_BUTTON_HEIGHT));
+		filter_buttons[type].set_tooltip( button_init[type].tooltip_text );
 		filter_buttons[type].set_visible(false);
-		filter_buttons[type].pressed = type==umgebung_t::default_mapmode;
+		filter_buttons[type].pressed = button_init[type].mode&umgebung_t::default_mapmode;
+		filter_buttons[type].background = filter_buttons[type].pressed ? button_init[type].select_color : button_init[type].color;
+		filter_buttons[type].foreground = filter_buttons[type].pressed ? COL_WHITE : COL_BLACK;
 		filter_buttons[type].add_listener(this);
 		add_komponente(filter_buttons + type);
 	}
@@ -214,34 +219,33 @@ map_frame_t::map_frame_t(karte_t *welt) :
 }
 
 
-void map_frame_t::update_factory_legend(karte_t *welt /*= NULL*/)
+void map_frame_t::update_factory_legend()
 {
-	legend.clear();
-
 	// When dialog is opened, update the list of industries currently in the world
-	if (welt != NULL) {
-		factory_list.clear();
-		FOR(slist_tpl<fabrik_t*>, const f, welt->get_fab_list()) {
-			fabrik_besch_t const* const factory_description = f->get_besch();
-			factory_list.put(factory_description->get_name(), factory_description);
-		}
-	}
-
-	// Build factory legend
-	const stringhashtable_tpl<const fabrik_besch_t *> & fabesch = (filter_factory_list) ? factory_list : fabrikbauer_t::get_fabesch();
-	FOR(stringhashtable_tpl<fabrik_besch_t const*>, const& i, fabesch) {
-		fabrik_besch_t const& d = *i.value;
-		if (d.get_gewichtung() > 0) {
-			std::string const label(translator::translate(d.get_name()));
-			legend.append_unique(legend_entry_t(label, d.get_kennfarbe()));
-		}
-	}
-
-	// If any names are too long for current windows size, shorten them. Can't be done in above loop in case shortening some names cause
-	// then to become non unique and thus get clumped together
+	legend.clear();
 	if(  directory_visible  ) {
+		if(  filter_factory_list  ) {
+			FOR(slist_tpl<fabrik_t*>, const f, welt->get_fab_list()) {
+				if(  f->get_besch()->get_gewichtung() > 0  ) {
+					std::string const label( translator::translate(f->get_besch()->get_name()) );
+					legend.append_unique( legend_entry_t(label, f->get_besch()->get_kennfarbe()) );
+				}
+			}
+		}
+		else {
+			FOR(stringhashtable_tpl<fabrik_besch_t const*>, const& i, fabrikbauer_t::get_fabesch()) {
+				fabrik_besch_t const& d = *i.value;
+				if (d.get_gewichtung() > 0) {
+					std::string const label(translator::translate(d.get_name()));
+					legend.append_unique(legend_entry_t(label, d.get_kennfarbe()));
+				}
+			}
+		}
+
+		// If any names are too long for current windows size, shorten them. Can't be done in above loop in case shortening some names cause
+		// then to become non unique and thus get clumped together
 		const int dot_len = proportional_string_width("..");
-		const int fac_cols = clamp(fabesch.get_count(), 1, get_fenstergroesse().x / (D_DEFAULT_WIDTH/3));
+		const int fac_cols = clamp(legend.get_count(), 1, get_fenstergroesse().x / (D_DEFAULT_WIDTH/3));
 
 		FOR(vector_tpl<legend_entry_t>, & l, legend) {
 			std::string label = l.text;
@@ -262,12 +266,14 @@ void map_frame_t::show_hide_legend(const bool show)
 	b_show_legend.pressed = show;
 	legend_visible = show;
 
-	const int col = max( 1, min( (get_fenstergroesse().x-2)/(D_BUTTON_WIDTH+D_H_SPACE), reliefkarte_t::MAX_MAP_BUTTON ) );
-	const int row = ((reliefkarte_t::MAX_MAP_BUTTON-1)/col)+1;
+	b_overlay_networks.set_visible( show );
+
+	const int col = max( 1, min( (get_fenstergroesse().x-2)/(D_BUTTON_WIDTH+D_H_SPACE), MAP_MAX_BUTTONS ) );
+	const int row = ((MAP_MAX_BUTTONS-1)/col)+1;
 	const int offset_y = (D_BUTTON_HEIGHT+2)*row;
 	const koord offset = show ? koord(0, offset_y) : koord(0, -offset_y);
 
-	for(  int type=0;  type<reliefkarte_t::MAX_MAP_BUTTON;  type++  ) {
+	for(  int type=0;  type<MAP_MAX_BUTTONS;  type++  ) {
 		filter_buttons[type].set_visible(show);
 	}
 	scrolly.set_pos(scrolly.get_pos() + offset);
@@ -300,17 +306,12 @@ void map_frame_t::show_hide_directory(const bool show)
 	b_filter_factory_list.pressed = filter_factory_list;
 	directory_visible = show;
 
-	if (directory_visible) {
-		b_filter_factory_list.enable();
-	}
-	else {
-		b_filter_factory_list.disable();
-	}
+	b_filter_factory_list.set_visible( directory_visible );
 
-	const int fac_cols = clamp(legend.get_count(), 1, get_fenstergroesse().x / (D_DEFAULT_WIDTH/3));
-	const int fac_rows = (legend.get_count() - 1) / fac_cols + 1;
+	const int fac_cols = clamp( legend.get_count(), 1, get_fenstergroesse().x / (D_DEFAULT_WIDTH/3) );
+	const int fac_rows = (legend.get_count() - 1) / fac_cols + 1 + D_V_SPACE*2 + D_BUTTON_HEIGHT;
 	//No need to resize when only factory filter button state changes
-	const koord offset = directory_view_toggeled ? (show ? koord(0, (fac_rows*14)) : koord(0, -(fac_rows*14))) : koord(0, 0);
+	const koord offset = directory_view_toggeled ? (show ? koord(0, (fac_rows*LINESPACE)) : koord(0, -(fac_rows*LINESPACE))) : koord(0, 0);
 
 	scrolly.set_pos(scrolly.get_pos() + offset);
 
@@ -320,7 +321,7 @@ void map_frame_t::show_hide_directory(const bool show)
 }
 
 
-bool map_frame_t::action_triggered( gui_action_creator_t *komp,value_t /* */)
+bool map_frame_t::action_triggered( gui_action_creator_t *komp, value_t v )
 {
 	if(komp==&b_show_legend) {
 		show_hide_legend( !b_show_legend.pressed );
@@ -350,65 +351,51 @@ bool map_frame_t::action_triggered( gui_action_creator_t *komp,value_t /* */)
 		reliefkarte_t::get_karte()->calc_map_groesse();
 		scrolly.set_groesse( scrolly.get_groesse() );
 	}
-	else if(komp==&b_show_schedule) {
-		//	show/hide schedule of convoi
-		reliefkarte_t::get_karte()->is_show_schedule = !reliefkarte_t::get_karte()->is_show_schedule;
-		b_show_schedule.pressed = reliefkarte_t::get_karte()->is_show_schedule;
+	else if(komp==&b_overlay_networks) {
+		b_overlay_networks.pressed ^= 1;
+		if(  b_overlay_networks.pressed  ) {
+			umgebung_t::default_mapmode |= reliefkarte_t::MAP_LINES;
 		}
-	else if(komp==&b_show_fab_connections) {
-		//	show/hide factory connections
-		reliefkarte_t::get_karte()->is_show_fab = !reliefkarte_t::get_karte()->is_show_fab;
-		b_show_fab_connections.pressed = reliefkarte_t::get_karte()->is_show_fab;
+		else {
+			umgebung_t::default_mapmode &= ~reliefkarte_t::MAP_LINES;
+		}
+		reliefkarte_t::get_karte()->set_mode(  (reliefkarte_t::MAP_MODES)umgebung_t::default_mapmode  );
 	}
 	else {
-		for (int i=0;i<reliefkarte_t::MAX_MAP_BUTTON;i++) {
-			if (komp == &filter_buttons[i]) {
-				if(filter_buttons[i].pressed) {
-					umgebung_t::default_mapmode = -1;
+		for(  int i=0;  i<MAP_MAX_BUTTONS;  i++  ) {
+			if(  komp == filter_buttons+i  ) {
+				if(  filter_buttons[i].pressed  ) {
+					umgebung_t::default_mapmode &= ~button_init[i].mode;
 				}
 				else {
-					umgebung_t::default_mapmode = i;
+					if(  (button_init[i].mode & reliefkarte_t::MAP_MODE_FLAGS) == 0  ) {
+						// clear all persistent states
+						umgebung_t::default_mapmode &= reliefkarte_t::MAP_MODE_FLAGS;
+					}
+					else if(  button_init[i].mode & reliefkarte_t::MAP_MODE_HALT_FLAGS  ) {
+						// clear all other halt states
+						umgebung_t::default_mapmode &= ~reliefkarte_t::MAP_MODE_HALT_FLAGS;
+					}
+					umgebung_t::default_mapmode |= button_init[i].mode;
 				}
+				filter_buttons[i].pressed ^= 1;
+				break;
 			}
 		}
-		reliefkarte_t::get_karte()->set_mode((reliefkarte_t::MAP_MODES)umgebung_t::default_mapmode);
-		for (int i=0;i<reliefkarte_t::MAX_MAP_BUTTON;i++) {
-			filter_buttons[i].pressed = i==umgebung_t::default_mapmode;
+		reliefkarte_t::get_karte()->set_mode(  (reliefkarte_t::MAP_MODES)umgebung_t::default_mapmode  );
+		for(  int i=0;  i<MAP_MAX_BUTTONS;  i++  ) {
+			filter_buttons[i].pressed = (button_init[i].mode&umgebung_t::default_mapmode)!=0;
+			filter_buttons[i].background = filter_buttons[i].pressed ? button_init[i].select_color : button_init[i].color;
+			filter_buttons[i].foreground = filter_buttons[i].pressed ? COL_WHITE : COL_BLACK;
 		}
 	}
 	return true;
 }
 
 
-void map_frame_t::zoom(bool zoom_out)
+void map_frame_t::zoom(bool magnify)
 {
-	zoomed = false;
-	if(  zoom_out  ) {
-		// zoom out
-		if(  reliefkarte_t::get_karte()->zoom_in>1  ) {
-			reliefkarte_t::get_karte()->zoom_in--;
-			zoomed = true;
-		}
-		else if(  reliefkarte_t::get_karte()->zoom_out<4  ) {
-			reliefkarte_t::get_karte()->zoom_out++;
-			zoomed = true;
-		}
-	}
-	else {
-		// zoom in
-		if(  reliefkarte_t::get_karte()->zoom_out>1  ) {
-			reliefkarte_t::get_karte()->zoom_out--;
-			zoomed = true;
-		}
-		else if(  reliefkarte_t::get_karte()->zoom_in<8  ) {
-			reliefkarte_t::get_karte()->zoom_in++;
-			zoomed = true;
-		}
-	}
-
-	if(  zoomed  ){
-		// recalc map size
-		reliefkarte_t::get_karte()->calc_map_groesse();
+	if (reliefkarte_t::get_karte()->change_zoom_factor(magnify)) {
 		// recalc all the other data incl scrollbars
 		resize(koord(0,0));
 	}
@@ -538,32 +525,41 @@ void map_frame_t::resize(const koord delta)
 	gui_frame_t::resize(delta);
 
 	const KOORD_VAL old_offset_y = scrolly.get_pos().y;
-	int offset_y = D_BUTTON_HEIGHT*4 + 2;
+	int offset_y = D_BUTTON_HEIGHT*2 + D_V_SPACE*2;
 
 	if(legend_visible) {
+		// MOVE NETWORK OVERLAY BUTTON
+		b_overlay_networks.set_pos( koord( D_MARGIN_LEFT, offset_y ) );
+		offset_y += D_BUTTON_HEIGHT;
+
 		// calculate space with legend
-		const int col = max( 1, min( (get_fenstergroesse().x-2)/(D_BUTTON_WIDTH+D_H_SPACE), reliefkarte_t::MAX_MAP_BUTTON ) );
-		const int row = ((reliefkarte_t::MAX_MAP_BUTTON-1)/col)+1;
+		const int col = max( 1, min( (get_fenstergroesse().x-D_MARGIN_LEFT-D_MARGIN_RIGHT+D_H_SPACE)/(D_BUTTON_WIDTH+D_H_SPACE), MAP_MAX_BUTTONS ) );
+		const int row = ((MAP_MAX_BUTTONS-1)/col)+1;
 
 		// set button pos
-		for (int type=0; type<reliefkarte_t::MAX_MAP_BUTTON; type++) {
-			koord pos = koord( 2+(D_BUTTON_WIDTH+D_H_SPACE)*(type%col), offset_y+(D_BUTTON_HEIGHT+2)*((int)type/col) );
+		for (int type=0; type<MAP_MAX_BUTTONS; type++) {
+			koord pos = koord( D_MARGIN_LEFT+(D_BUTTON_WIDTH+D_H_SPACE)*(type%col), offset_y+(D_BUTTON_HEIGHT+2)*((int)type/col) );
 			filter_buttons[type].set_pos( pos );
 		}
 		offset_y += (D_BUTTON_HEIGHT+2)*row;
+		offset_y += D_V_SPACE;
 	}
 
 	if(scale_visible) {
 		// plus scale bar
-		offset_y += LINESPACE+4;
+		offset_y += LINESPACE;
+		offset_y += D_V_SPACE;
 	}
 
 	if(directory_visible) {
+		b_filter_factory_list.set_pos( koord( D_MARGIN_LEFT, offset_y ) );
+		offset_y += D_BUTTON_HEIGHT;
 		// full program including factory texts
 		update_factory_legend();
-		const int fac_cols = clamp(legend.get_count(), 1, get_fenstergroesse().x / (D_DEFAULT_WIDTH/3));
+		const int fac_cols = clamp( legend.get_count(), 1, get_fenstergroesse().x / (D_DEFAULT_WIDTH/3));
 		const int fac_rows = (legend.get_count() - 1) / fac_cols + 1;
-		offset_y += fac_rows*14;
+		offset_y += fac_rows*LINESPACE;
+		offset_y += D_V_SPACE;
 	}
 
 	// offset of map
@@ -611,12 +607,18 @@ void map_frame_t::zeichnen(koord pos, koord gr)
 	gui_frame_t::zeichnen(pos, gr);
 
 	char buf[16];
-	sprintf( buf, "%i:%i", reliefkarte_t::get_karte()->zoom_in, reliefkarte_t::get_karte()-> zoom_out );
-	display_proportional( pos.x+18, pos.y+D_TITLEBAR_HEIGHT+D_BUTTON_HEIGHT+5, buf, ALIGN_LEFT, COL_WHITE, true);
+	sint16 zoom_in, zoom_out;
+	reliefkarte_t::get_karte()->get_zoom_factors(zoom_out, zoom_in);
+	sprintf( buf, "%i:%i", zoom_out, zoom_in );
+	int zoomextwidth = display_proportional( pos.x+BUTTON1_X+D_BUTTON_HEIGHT+D_H_SPACE, pos.y+D_TITLEBAR_HEIGHT+D_BUTTON_HEIGHT+D_V_SPACE, buf, ALIGN_LEFT, COL_WHITE, true);
+	// move zoom arrow position and label accordingly
+	zoom_buttons[1].set_pos( koord( BUTTON1_X+D_BUTTON_HEIGHT+2*D_H_SPACE+zoomextwidth, zoom_buttons[1].get_pos().y ) );
+	zoom_label.set_pos( koord( BUTTON1_X+2*D_BUTTON_HEIGHT+3*D_H_SPACE+zoomextwidth, zoom_label.get_pos().y ) );
+	b_rotate45.set_pos( koord( zoom_label.get_pos().x+proportional_string_width(zoom_label.get_text_pointer())+D_H_SPACE+10, b_rotate45.get_pos().y ) );
 
-	int offset_y = D_BUTTON_HEIGHT*4 + 2 + D_TITLEBAR_HEIGHT;
+	int offset_y = D_BUTTON_HEIGHT*2 + D_V_SPACE*2 + D_TITLEBAR_HEIGHT;
 	if(legend_visible) {
-		offset_y = 16+filter_buttons[reliefkarte_t::MAX_MAP_BUTTON-1].get_pos().y+D_BUTTON_HEIGHT+2;
+		offset_y = D_TITLEBAR_HEIGHT+filter_buttons[MAP_MAX_BUTTONS-1].get_pos().y+D_BUTTON_HEIGHT+2+D_V_SPACE;
 	}
 
 	// draw scale
@@ -628,16 +630,19 @@ void map_frame_t::zeichnen(koord pos, koord gr)
 		}
 		display_proportional(bar_pos.x + 26, bar_pos.y, translator::translate("min"), ALIGN_RIGHT, COL_BLACK, false);
 		display_proportional(bar_pos.x + size.x - 26, bar_pos.y, translator::translate("max"), ALIGN_LEFT, COL_BLACK, false);
-		offset_y += LINESPACE+4;
+		offset_y += LINESPACE;
+		offset_y += D_V_SPACE;
 	}
 
 	// draw factory descriptions
 	if(directory_visible) {
+		offset_y += D_BUTTON_HEIGHT;
+
 		const int fac_cols = clamp(legend.get_count(), 1, gr.x / (D_DEFAULT_WIDTH/3));
 		uint u = 0;
 		FORX(vector_tpl<legend_entry_t>, const& i, legend, ++u) {
 			const int xpos = pos.x + (u % fac_cols) * (gr.x-fac_cols/2-1)/fac_cols + 3;
-			const int ypos = pos.y + (u / fac_cols) * 14 + offset_y+2;
+			const int ypos = pos.y + (u / fac_cols) * LINESPACE + offset_y+2;
 
 			if(  ypos+LINESPACE > pos.y+gr.y  ) {
 				break;
@@ -651,16 +656,30 @@ void map_frame_t::zeichnen(koord pos, koord gr)
 
 void map_frame_t::rdwr( loadsave_t *file )
 {
+	bool is_show_schedule = (umgebung_t::default_mapmode & reliefkarte_t::MAP_LINES);
+	bool is_show_fab = (umgebung_t::default_mapmode & reliefkarte_t::MAP_FACTORIES);
+
 	file->rdwr_bool( reliefkarte_t::get_karte()->isometric );
-	file->rdwr_bool( reliefkarte_t::get_karte()->is_show_schedule );
-	file->rdwr_bool( reliefkarte_t::get_karte()->is_show_fab );
-	file->rdwr_short( reliefkarte_t::get_karte()->zoom_in );
-	file->rdwr_short( reliefkarte_t::get_karte()->zoom_out );
+	if(  file->get_version()<111004  ) {
+		file->rdwr_bool( is_show_schedule );
+		file->rdwr_bool( is_show_fab );
+	}
+	reliefkarte_t::get_karte()->rdwr(file);
 	bool show_legend_state = legend_visible;
 	file->rdwr_bool( show_legend_state );
 	file->rdwr_bool( scale_visible );
 	file->rdwr_bool( directory_visible );
-	file->rdwr_byte( umgebung_t::default_mapmode );
+	if(  file->get_version()<111004  ) {
+		sint8 mode = log2(umgebung_t::default_mapmode & ~reliefkarte_t::MAP_MODE_FLAGS);
+		file->rdwr_byte( mode );
+		umgebung_t::default_mapmode = 1 << mode;
+		umgebung_t::default_mapmode = mode>=0 ? 1 << mode : 0;
+		umgebung_t::default_mapmode |= is_show_schedule * reliefkarte_t::MAP_LINES;
+		umgebung_t::default_mapmode |= is_show_fab * reliefkarte_t::MAP_FACTORIES;
+	}
+	else {
+		file->rdwr_long( umgebung_t::default_mapmode );
+	}
 
 	if(  file->is_loading()  ) {
 		koord savesize;
@@ -678,12 +697,15 @@ void map_frame_t::rdwr( loadsave_t *file )
 		scrolly.set_scroll_position( xoff, yoff );
 
 		reliefkarte_t::get_karte()->set_mode((reliefkarte_t::MAP_MODES)umgebung_t::default_mapmode);
-		for (int i=0;i<reliefkarte_t::MAX_MAP_BUTTON;i++) {
+		for (int i=0;i<MAP_MAX_BUTTONS;i++) {
 			filter_buttons[i].pressed = i==umgebung_t::default_mapmode;
 		}
 		if(  legend_visible!=show_legend_state  ) {
 			action_triggered( &b_show_legend, (long)0 );
 		}
+		b_filter_factory_list.set_visible( directory_visible );
+
+		b_overlay_networks.pressed = (umgebung_t::default_mapmode & reliefkarte_t::MAP_LINES)!=0;
 	}
 	else {
 		koord gr = get_fenstergroesse();
