@@ -159,6 +159,7 @@ schedule_list_gui_t::schedule_list_gui_t(spieler_t *sp_) :
 	loadfactor = 0;
 	schedule_filter[0] = 0;
 	old_schedule_filter[0] = 0;
+	last_schedule = NULL;
 
 	// init scrolled list
 	scl.set_pos(koord(0,1));
@@ -260,7 +261,6 @@ schedule_list_gui_t::schedule_list_gui_t(spieler_t *sp_) :
 	// normal buttons edit new remove
 	bt_new_line.init(button_t::roundbox, "New Line", koord(11, 8+SCL_HEIGHT+D_BUTTON_HEIGHT ), koord(D_BUTTON_WIDTH,D_BUTTON_HEIGHT));
 	bt_new_line.add_listener(this);
-	bt_new_line.disable();
 	add_komponente(&bt_new_line);
 
 	bt_change_line.init(button_t::roundbox, "Update Line", koord(11+D_BUTTON_WIDTH, 8+SCL_HEIGHT+D_BUTTON_HEIGHT ), koord(D_BUTTON_WIDTH,D_BUTTON_HEIGHT));
@@ -307,6 +307,12 @@ schedule_list_gui_t::schedule_list_gui_t(spieler_t *sp_) :
 	}
 	selected_tab = tabs_to_lineindex[index]; // reset if previous selected tab is not there anymore
 	tabs.set_active_tab_index(index);
+	if (index>0) {
+		bt_new_line.enable();
+	}
+	else {
+		bt_new_line.disable();
+	}
 	update_lineinfo( line );
 
 	// resize button
@@ -321,6 +327,7 @@ schedule_list_gui_t::schedule_list_gui_t(spieler_t *sp_) :
 
 schedule_list_gui_t::~schedule_list_gui_t()
 {
+	delete last_schedule;
 	// change line name if necessary
 	rename_line();
 }
@@ -335,11 +342,17 @@ bool schedule_list_gui_t::infowin_event(const event_t *ev)
 	if(ev->ev_class == INFOWIN) {
 		if(ev->ev_code == WIN_CLOSE) {
 			// hide schedule on minimap (may not current, but for safe)
-			reliefkarte_t::get_karte()->set_current_fpl(NULL, 0); // (*fpl,player_nr)
+			reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
 		}
 		else if(  (ev->ev_code==WIN_OPEN  ||  ev->ev_code==WIN_TOP)  &&  line.is_bound() ) {
-			// set this schedule as current to show on minimap if possible
-			reliefkarte_t::get_karte()->set_current_fpl(line->get_schedule(), sp->get_player_nr()); // (*fpl,player_nr)
+			if(  line->count_convoys()>0  ) {
+				// set this schedule as current to show on minimap if possible
+				reliefkarte_t::get_karte()->set_current_cnv( line->get_convoy(0) );
+			}
+			else {
+				// set this schedule as current to show on minimap if possible
+				reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
+			}
 		}
 	}
 	return gui_frame_t::infowin_event(ev);
@@ -680,10 +693,17 @@ void schedule_list_gui_t::update_lineinfo(linehandle_t new_line)
 		}
 		chart.set_visible(true);
 
-		// set this schedule as current to show on minimap if possible
-		reliefkarte_t::get_karte()->set_current_fpl(new_line->get_schedule(), sp->get_player_nr()); // (*fpl,player_nr)
+		// has this line a single running convoi?
+		if(  new_line.is_bound()  &&  new_line->count_convoys() > 0  ) {
+			// set this schedule as current to show on minimap if possible
+			reliefkarte_t::get_karte()->set_current_cnv( new_line->get_convoy(0) );
+		}
+		else {
+			reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
+		}
 
-		last_schedule = new_line->get_schedule();
+		delete last_schedule;
+		last_schedule = new_line->get_schedule()->copy();
 		last_vehicle_count = new_line->count_convoys();
 	}
 	else if(  inp_name.is_visible()  ) {
@@ -705,8 +725,9 @@ void schedule_list_gui_t::update_lineinfo(linehandle_t new_line)
 		chart.set_visible(true);
 
 		// hide schedule on minimap (may not current, but for safe)
-		reliefkarte_t::get_karte()->set_current_fpl(NULL, 0); // (*fpl,player_nr)
+		reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
 
+		delete last_schedule;
 		last_schedule = NULL;
 		last_vehicle_count = 0;
 	}
