@@ -65,20 +65,12 @@ public:
 
 	virtual ~stadt_info_t();
 
-	/**
-	 * Manche Fenster haben einen Hilfetext assoziiert.
-	 * @return den Dateinamen fr die Hilfe, oder NULL
-	 * @author Hj. Malthaner
-	 */
 	const char *get_hilfe_datei() const {return "citywindow.txt";}
 
-	virtual koord3d get_weltpos();
+	virtual koord3d get_weltpos(bool);
+
+	virtual bool is_weltpos();
 
-	/**
-	* komponente neu zeichnen. Die bergebenen Werte beziehen sich auf
-	* das Fenster, d.h. es sind die Bildschirmkoordinaten des Fensters
-	* in dem die Komponente dargestellt wird.
-	*/
 	void zeichnen(koord pos, koord gr);
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
