@@ -38,15 +38,7 @@ class station_building_select_t : public gui_frame_t, action_listener_t
 public:
 	station_building_select_t(karte_t *welt, const haus_besch_t *besch);
 
-	/**
-	 * This method is called if an action is triggered
-	 * @author Hj. Malthaner
-	 *
-	 * Returns true, if action is done and no more
-	 * components should be triggered.
-	 * V.Meyer
-	 */
-	bool action_triggered( gui_action_creator_t *komp, value_t extra);
+	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 };
 
 #endif
