@@ -6,14 +6,6 @@
  * April 2000
  */
 
-#include <string.h>
-#ifdef _MSC_VER
-#include <new.h> // for _set_new_handler
-#include <direct.h>
-#else
-#include <unistd.h>
-#endif
-
 #include "welt.h"
 #include "karte.h"
 
@@ -22,6 +14,7 @@
 #include "../simwin.h"
 #include "../simimg.h"
 #include "../simmesg.h"
+#include "../simskin.h"
 #include "../simtools.h"
 #include "../simversion.h"
 
@@ -48,8 +41,9 @@
 
 #include "load_relief_frame.h"
 
+#include "../simsys.h"
 #include "../utils/simstring.h"
-#include "components/list_button.h"
+
 
 #include "sprachen.h"
 #include "climates.h"
@@ -72,26 +66,30 @@
 #define RIGHT_COLUMN (185)
 #define RIGHT_COLUMN_WIDTH (60)
 
-#include <sys/stat.h>
-#include <time.h>
+#define PREVIEW_SIZE (64) // size of the minimap
+#define PREVIEW_SIZE_MIN (16) // minimum width/height of the minimap
 
 
 welt_gui_t::welt_gui_t(karte_t* const welt, settings_t* const sets) :
-	gui_frame_t( translator::translate("Neue Welt" ) )
+	gui_frame_t( translator::translate("Neue Welt" ) ),
+	karte(0,0)
 {
-DBG_MESSAGE("","sizeof(stat)=%d, sizeof(tm)=%d",sizeof(struct stat),sizeof(struct tm) );
 	this->welt = welt;
 	this->sets = sets;
 	this->old_lang = -1;
 	this->sets->beginner_mode = umgebung_t::default_einstellungen.get_beginner_mode();
 
+	city_density = sets->get_anzahl_staedte() ? sqrt((double)sets->get_groesse_x()*sets->get_groesse_y()) / sets->get_anzahl_staedte() : 0.0;
+	industry_density = sets->get_land_industry_chains() ? sqrt((double)sets->get_groesse_x()*sets->get_groesse_y()) / sets->get_land_industry_chains() : 0.0;
+	attraction_density = sets->get_tourist_attractions() ? sqrt((double)sets->get_groesse_x()*sets->get_groesse_y()) / sets->get_tourist_attractions() : 0.0;
+
+	karte_size = koord(PREVIEW_SIZE, PREVIEW_SIZE); // default preview minimap size
+
 	// find earliest start and end date ...
 	uint16 game_start = 4999;
 	uint16 game_ends = 0;
 	// first townhalls
-	const vector_tpl<const haus_besch_t *> *s = hausbauer_t::get_list(haus_besch_t::rathaus);
-	for (uint32 i = 0; i<s->get_count(); i++) {
-		const haus_besch_t *besch = (*s)[i];
+	FOR(vector_tpl<haus_besch_t const*>, const besch, *hausbauer_t::get_list(haus_besch_t::rathaus)) {
 		uint16 intro_year = (besch->get_intro_year_month()+11)/12;
 		if(  intro_year<game_start  ) {
 			game_start = intro_year;
@@ -137,17 +135,17 @@ DBG_MESSAGE("","sizeof(stat)=%d, sizeof(tm)=%d",sizeof(struct stat),sizeof(struc
 	// maps etc.
 	intTopOfButton += 5;
 	random_map.set_pos( koord(10, intTopOfButton) );
-	random_map.set_groesse( koord(104, BUTTON_HEIGHT) );
+	random_map.set_groesse( koord(104, D_BUTTON_HEIGHT) );
 	random_map.set_typ(button_t::roundbox);
 	random_map.add_listener( this );
 	add_komponente( &random_map );
 
 	load_map.set_pos( koord(104+11+30, intTopOfButton) );
-	load_map.set_groesse( koord(104, BUTTON_HEIGHT) );
+	load_map.set_groesse( koord(104, D_BUTTON_HEIGHT) );
 	load_map.set_typ(button_t::roundbox);
 	load_map.add_listener( this );
 	add_komponente( &load_map );
-	intTopOfButton += BUTTON_HEIGHT;
+	intTopOfButton += D_BUTTON_HEIGHT;
 
 	// city stuff
 	intTopOfButton += 5;
@@ -252,7 +250,7 @@ DBG_MESSAGE("","sizeof(stat)=%d, sizeof(tm)=%d",sizeof(struct stat),sizeof(struc
 	add_komponente( &load_scenario );
 
 	// start game
-	intTopOfButton += 5+BUTTON_HEIGHT;
+	intTopOfButton += 5+D_BUTTON_HEIGHT;
 	start_game.set_pos( koord(10, intTopOfButton) );
 	start_game.set_groesse( koord(104, 14) );
 	start_game.set_typ(button_t::roundbox);
@@ -272,7 +270,6 @@ DBG_MESSAGE("","sizeof(stat)=%d, sizeof(tm)=%d",sizeof(struct stat),sizeof(struc
 }
 
 
-
 /**
  * Calculates preview from height map
  * @param filename name of heightfield file
@@ -280,51 +277,47 @@ DBG_MESSAGE("","sizeof(stat)=%d, sizeof(tm)=%d",sizeof(struct stat),sizeof(struc
  */
 bool welt_gui_t::update_from_heightfield(const char *filename)
 {
-	DBG_MESSAGE("welt_gui_t::update_from_heightfield()",filename);
+	DBG_MESSAGE("welt_gui_t::update_from_heightfield()", "%s", filename);
 
 	sint16 w, h;
 	sint8 *h_field=NULL;
-	if(karte_t::get_height_data_from_file(filename, sets->get_grundwasser(), h_field, w, h, false )) {
+	if(karte_t::get_height_data_from_file(filename, (sint8)sets->get_grundwasser(), h_field, w, h, false )) {
 		sets->set_groesse_x(w);
 		sets->set_groesse_y(h);
+		update_densities();
 
-		// ensure correct display under all circumstances
-		const float skip_x = (float)preview_size/(float)w;
-		const long skip_y = h>preview_size  ? h/preview_size :  1;
-		for(int karte_y=0, y=0; y<h  &&  karte_y<preview_size; y++) {
-			// new line?
-			if(y%skip_y==0) {
-				int karte_x=0;
-				float rest_x=0.0;
+		inp_x_size.set_value(sets->get_groesse_x());
+		inp_y_size.set_value(sets->get_groesse_y());
 
-				for(int x=0; x<w; x++) {
-					while(karte_x<=rest_x  &&  karte_x<preview_size) {
-						karte[(karte_y*preview_size)+karte_x] = reliefkarte_t::calc_hoehe_farbe( h_field[x+y*w], sets->get_grundwasser()-1 );
-						karte_x ++;
-					}
-					rest_x += skip_x;
-				}
-				karte_y++;
+		resize_preview();
+
+		const int mx = sets->get_groesse_x()/karte_size.x;
+		const int my = sets->get_groesse_y()/karte_size.y;
+		for(  int y=0;  y<karte_size.y;  y++  ) {
+			for(  int x=0;  x<karte_size.x;  x++  ) {
+				karte.at(x,y) = reliefkarte_t::calc_hoehe_farbe( h_field[x*mx+y*my*w], sets->get_grundwasser()-1 );
 			}
 		}
-
-		// blow up y direction
-		if(h<preview_size) {
-			const sint16 repeat_y = ((sint16)preview_size)/h;
-			for(sint16 oy=h-1, y=preview_size-1;  oy>0;  oy--  ) {
-				for( sint16 i=0;  i<=repeat_y  &&  y>0;  i++  ) {
-					memcpy( karte+y, karte+oy, 3*preview_size );
-					y --;
-				}
-			}
-		}
-
 		return true;
 	}
 	return false;
 }
 
 
+// sets the new values for the numbinpu filed for the densities
+void welt_gui_t::update_densities()
+{
+	if(  city_density!=0.0  ) {
+		inp_number_of_towns.set_value( max( 1, (sint32)(0.5+sqrt((double)sets->get_groesse_x()*sets->get_groesse_y())/city_density) ) );
+	}
+	if(  industry_density!=0.0  ) {
+		inp_other_industries.set_value( max( 1, (sint32)(0.5+sqrt((double)sets->get_groesse_x()*sets->get_groesse_y())/industry_density) ) );
+	}
+	if(  attraction_density!=0.0  ) {
+		inp_tourist_attractions.set_value( max( 1, (sint32)(0.5+sqrt((double)sets->get_groesse_x()*sets->get_groesse_y())/attraction_density) ) );
+	}
+}
+
 
 /**
  * Berechnet Preview-Karte neu. Inititialisiert RNG neu!
@@ -332,25 +325,40 @@ bool welt_gui_t::update_from_heightfield(const char *filename)
  */
 void welt_gui_t::update_preview()
 {
-	const int mx = sets->get_groesse_x()/preview_size;
-	const int my = sets->get_groesse_y()/preview_size;
-
-	if(loaded_heightfield) {
+	if(  loaded_heightfield  ) {
 		update_from_heightfield(sets->heightfield.c_str());
 	}
 	else {
+		resize_preview();
+
 		setsimrand( 0xFFFFFFFF, sets->get_karte_nummer() );
-		for(int j=0; j<preview_size; j++) {
-			for(int i=0; i<preview_size; i++) {
-				karte[j*preview_size+i] = reliefkarte_t::calc_hoehe_farbe(karte_t::perlin_hoehe( sets, koord(i*mx,j*my), koord::invalid ), sets->get_grundwasser()/Z_TILE_STEP);
+
+		const int mx = sets->get_groesse_x()/karte_size.x;
+		const int my = sets->get_groesse_y()/karte_size.y;
+		for(  int y=0;  y<karte_size.y;  y++  ) {
+			for(  int x=0;  x<karte_size.x;  x++  ) {
+				karte.at(x,y) = reliefkarte_t::calc_hoehe_farbe(karte_t::perlin_hoehe( sets, koord(x*mx,y*my), koord::invalid ), sets->get_grundwasser());
 			}
 		}
 		sets->heightfield = "";
-		loaded_heightfield = false;
 	}
 }
 
 
+void welt_gui_t::resize_preview()
+{
+	const float world_aspect = (float)sets->get_groesse_x() / (float)sets->get_groesse_y();
+
+	if(  world_aspect > 1.0  ) {
+		karte_size.x = PREVIEW_SIZE;
+		karte_size.y = (sint16) max( (float)karte_size.x / world_aspect, PREVIEW_SIZE_MIN);
+	}
+	else {
+		karte_size.y = PREVIEW_SIZE;
+		karte_size.x = (sint16) max( (float)karte_size.y * world_aspect, PREVIEW_SIZE_MIN);
+	}
+	karte.resize( karte_size.x, karte_size.y );
+}
 
 
 /**
@@ -362,20 +370,35 @@ bool welt_gui_t::action_triggered( gui_action_creator_t *komp,value_t v)
 	// check for changed map (update preview for any event)
 	int knr = inp_map_number.get_value(); //
 
-	if(komp==&inp_x_size) {
-		sets->set_groesse_x( v.i );
-		inp_x_size.set_increment_mode( v.i>=64 ? (v.i>=512 ? 128 : 64) : 8 );
-		inp_y_size.set_limits( 8, min(32000,16777216/sets->get_groesse_x()) );
-		update_preview();
+	if(komp==&inp_map_number) {
+		sets->heightfield = "";
+		loaded_heightfield = false;
+	}
+	else if(komp==&inp_x_size) {
+		if(  !loaded_heightfield  ) {
+			sets->set_groesse_x( v.i );
+			inp_x_size.set_increment_mode( v.i>=64 ? (v.i>=512 ? 128 : 64) : 8 );
+			inp_y_size.set_limits( 8, min(32000,16777216/sets->get_groesse_x()) );
+			update_densities();
+		}
+		else {
+			inp_x_size.set_value(sets->get_groesse_x()); // can't change size with heightfield loaded
+		}
 	}
 	else if(komp==&inp_y_size) {
-		sets->set_groesse_y( v.i );
-		inp_y_size.set_increment_mode( v.i>=64 ? (v.i>=512 ? 128 : 64) : 8 );
-		inp_x_size.set_limits( 8, min(32000,16777216/sets->get_groesse_y()) );
-		update_preview();
+		if(  !loaded_heightfield  ) {
+			sets->set_groesse_y( v.i );
+			inp_y_size.set_increment_mode( v.i>=64 ? (v.i>=512 ? 128 : 64) : 8 );
+			inp_x_size.set_limits( 8, min(32000,16777216/sets->get_groesse_y()) );
+			update_densities();
+		}
+		else {
+			inp_y_size.set_value(sets->get_groesse_y()); // can't change size with heightfield loaded
+		}
 	}
 	else if(komp==&inp_number_of_towns) {
 		sets->set_anzahl_staedte( v.i );
+		city_density = sets->get_anzahl_staedte() ? sqrt((double)sets->get_groesse_x()*sets->get_groesse_y()) / sets->get_anzahl_staedte() : 0.0;
 	}
 	else if(komp==&inp_town_size) {
 		sets->set_mittlere_einwohnerzahl( v.i );
@@ -386,12 +409,14 @@ bool welt_gui_t::action_triggered( gui_action_creator_t *komp,value_t v)
 	}
 	else if(komp==&inp_other_industries) {
 		sets->set_land_industry_chains( v.i );
+		industry_density = sets->get_land_industry_chains() ? sqrt((double)sets->get_groesse_x()*sets->get_groesse_y()) / sets->get_land_industry_chains() : 0.0;
 	}
 	else if(komp==&inp_tourist_attractions) {
 		sets->set_tourist_attractions( v.i );
+		attraction_density = sets->get_tourist_attractions() ? sqrt((double)sets->get_groesse_x()*sets->get_groesse_y()) / sets->get_tourist_attractions() : 0.0;
 	}
 	else if(komp==&inp_intro_date) {
-		sets->set_starting_year( v.i );
+		sets->set_starting_year( (sint16)(v.i) );
 	}
 	else if(komp==&random_map) {
 		knr = simrand(9999);
@@ -493,7 +518,6 @@ bool welt_gui_t::action_triggered( gui_action_creator_t *komp,value_t v)
 }
 
 
-
 bool  welt_gui_t::infowin_event(const event_t *ev)
 {
 	gui_frame_t::infowin_event(ev);
@@ -506,7 +530,6 @@ bool  welt_gui_t::infowin_event(const event_t *ev)
 }
 
 
-
 void welt_gui_t::zeichnen(koord pos, koord gr)
 {
 	if(!loaded_heightfield  && sets->heightfield.size()!=0) {
@@ -554,8 +577,8 @@ void welt_gui_t::zeichnen(koord pos, koord gr)
 	display_proportional_clip(x, y-20, translator::translate("1WORLD_CHOOSE"),ALIGN_LEFT, COL_BLACK, true);
 	display_ddd_box_clip(x, y-5, RIGHT_ARROW, 0, MN_GREY0, MN_GREY4);		// seperator
 
-	display_ddd_box_clip(x+173, y-20, preview_size+2, preview_size+2, MN_GREY0,MN_GREY4);
-	display_array_wh(x+174, y-19, preview_size, preview_size, karte);
+	display_ddd_box_clip(x+173, y-20, karte_size.x+2, karte_size.y+2, MN_GREY0,MN_GREY4);
+	display_array_wh(x+174, y-19, karte_size.x, karte_size.y, karte.to_array());
 
 	display_proportional_clip(x, y, translator::translate("2WORLD_CHOOSE"), ALIGN_LEFT, COL_BLACK, true);
 	// since the display is done via a textfiled, we have nothing to do
@@ -576,11 +599,11 @@ void welt_gui_t::zeichnen(koord pos, koord gr)
 			sizeof(void*) * 4
 		) * sx * sy
 	) / (1024 * 1024);
-	buf.printf( translator::translate("3WORLD_CHOOSE"), memory );
+	buf.printf( translator::translate("Size (%d MB):"), memory );
 	display_proportional_clip(x, y, buf, ALIGN_LEFT, COL_BLACK, true);
 	y += 12;	// x size
 	y += 12+5;	// y size
-	y += BUTTON_HEIGHT+12+5;	// buttons
+	y += D_BUTTON_HEIGHT+12+5;	// buttons
 
 	display_proportional_clip(x, y, translator::translate("5WORLD_CHOOSE"), ALIGN_LEFT, COL_BLACK, true);
 	y += 12;
