@@ -56,6 +56,10 @@
 
 karte_t *spieler_t::welt = NULL;
 
+#if MULTI_THREAD>1
+#include <pthread.h>
+static pthread_mutex_t laden_abschl_mutex = PTHREAD_MUTEX_INITIALIZER;
+#endif
 
 /**
  * Encapsulate margin calculation  (Operating_Profit / Income)
@@ -637,8 +641,8 @@ void spieler_t::ai_bankrupt()
 								delete dt;
 								break;
 							case ding_t::leitung:
-								if (gr->ist_bruecke()) {
-									add_maintenance( -((leitung_t*)dt)->get_besch()->get_wartung() );
+								if(gr->ist_bruecke()) {
+									maintenance -= ((leitung_t*)dt)->get_besch()->get_wartung();
 									// do not remove powerline from bridges
 									dt->set_besitzer( welt->get_spieler(1) );
 								}
@@ -657,7 +661,7 @@ void spieler_t::ai_bankrupt()
 									w->set_besitzer( NULL );
 								}
 								else if(w->get_waytype()==road_wt  ||  w->get_waytype()==water_wt) {
-									add_maintenance( -w->get_besch()->get_wartung() );
+									maintenance -= w->get_besch()->get_wartung();
 									w->set_besitzer( NULL );
 								}
 								else {
@@ -666,11 +670,11 @@ void spieler_t::ai_bankrupt()
 								break;
 							}
 							case ding_t::bruecke:
-								add_maintenance( -((bruecke_t*)dt)->get_besch()->get_wartung() );
+								maintenance -= ((bruecke_t*)dt)->get_besch()->get_wartung();
 								dt->set_besitzer( NULL );
 								break;
 							case ding_t::tunnel:
-								add_maintenance( -((tunnel_t*)dt)->get_besch()->get_wartung() );
+								maintenance -= ((tunnel_t*)dt)->get_besch()->get_wartung();
 								dt->set_besitzer( NULL );
 								break;
 
@@ -886,13 +890,13 @@ void spieler_t::rdwr(loadsave_t *file)
 			finance_history_year[year][COST_OPERATING_PROFIT] = finance_history_year[year][COST_INCOME] + finance_history_year[year][COST_POWERLINES] + finance_history_year[year][COST_VEHICLE_RUN] + finance_history_year[year][COST_MAINTENANCE] + finance_history_year[year][COST_WAY_TOLLS];
 
 			// including also investements into vehicles/infrastructure
-			finance_history_year[year][COST_PROFIT] = finance_history_year[year][COST_INCOME]+finance_history_year[year][COST_VEHICLE_RUN]+finance_history_year[year][COST_MAINTENANCE]+finance_history_year[year][COST_CONSTRUCTION]+finance_history_year[year][COST_NEW_VEHICLE];
+			finance_history_year[year][COST_PROFIT] = finance_history_year[year][COST_OPERATING_PROFIT]+finance_history_year[year][COST_CONSTRUCTION]+finance_history_year[year][COST_NEW_VEHICLE];
 			finance_history_year[year][COST_MARGIN] = calc_margin(finance_history_year[year][COST_OPERATING_PROFIT], finance_history_year[year][COST_INCOME]);
 		}
 		for(  int month=0;  month<MAX_PLAYER_HISTORY_MONTHS;  month++  ) {
 			finance_history_month[month][COST_NETWEALTH] = finance_history_month[month][COST_CASH]+finance_history_month[month][COST_ASSETS];
 			finance_history_month[month][COST_OPERATING_PROFIT] = finance_history_month[month][COST_INCOME] + finance_history_month[month][COST_POWERLINES] + finance_history_month[month][COST_VEHICLE_RUN] + finance_history_month[month][COST_MAINTENANCE] + finance_history_month[month][COST_WAY_TOLLS];
-			finance_history_month[month][COST_PROFIT] = finance_history_month[month][COST_INCOME]+finance_history_month[month][COST_VEHICLE_RUN]+finance_history_month[month][COST_MAINTENANCE]+finance_history_month[month][COST_CONSTRUCTION]+finance_history_month[month][COST_NEW_VEHICLE];
+			finance_history_month[month][COST_PROFIT] = finance_history_month[month][COST_OPERATING_PROFIT]+finance_history_month[month][COST_CONSTRUCTION]+finance_history_month[month][COST_NEW_VEHICLE];
 			finance_history_month[month][COST_MARGIN] = calc_margin(finance_history_month[month][COST_OPERATING_PROFIT], finance_history_month[month][COST_INCOME]);
 		}
 
@@ -964,6 +968,20 @@ void spieler_t::laden_abschliessen()
 }
 
 
+void spieler_t::add_maintenance(spieler_t *sp, sint32 change)
+{
+	if(sp) {
+#if MULTI_THREAD>1
+		pthread_mutex_lock( &laden_abschl_mutex  );
+#endif
+		sp->maintenance += change;
+#if MULTI_THREAD>1
+		pthread_mutex_unlock( &laden_abschl_mutex  );
+#endif
+	}
+}
+
+
 void spieler_t::rotate90( const sint16 y_size )
 {
 	simlinemgmt.rotate90( y_size );
@@ -1094,10 +1112,11 @@ sint64 spieler_t::undo()
 			cost += gr->weg_entfernen(undo_type,true);
 		}
 		else {
-			leitung_t* lt = gr->get_leitung();
-			cost += lt->get_besch()->get_preis();
-			lt->entferne(NULL);
-			delete lt;
+			if (leitung_t* lt = gr->get_leitung()) {
+				cost += lt->get_besch()->get_preis();
+				lt->entferne(NULL);
+				delete lt;
+			}
 		}
 	}
 	last_built.clear();
