@@ -3,7 +3,6 @@
  * von Hansjrg Malthaner
  */
 
-#include <math.h>
 #include <stdlib.h>
 
 #include "simdebug.h"
@@ -21,6 +20,7 @@
 #include "simintr.h"
 #include "simlinemgmt.h"
 #include "simline.h"
+#include "simtools.h"
 #include "freight_list_sorter.h"
 
 #include "gui/karte.h"
@@ -119,6 +119,7 @@ void convoi_t::init(karte_t *wl, spieler_t *sp)
 	sum_running_costs = sum_gesamtgewicht = sum_gewicht = sum_gear_und_leistung = sum_leistung = 0;
 	previous_delta_v = 0;
 	min_top_speed = SPEED_UNLIMITED;
+	speedbonus_kmh = SPEED_UNLIMITED; // speed_to_kmh() not needed
 
 	fpl = NULL;
 	line = linehandle_t();
@@ -134,6 +135,11 @@ void convoi_t::init(karte_t *wl, spieler_t *sp)
 	jahresgewinn = 0;
 	total_distance_traveled = 0;
 
+	distance_since_last_stop = 0;
+	sum_speed_limit = 0;
+	maxspeed_average_count = 0;
+	next_reservation_index = 0;
+
 	alte_richtung = ribi_t::keine;
 	next_wolke = 0;
 
@@ -160,7 +166,7 @@ void convoi_t::init(karte_t *wl, spieler_t *sp)
 	home_depot = koord3d::invalid;
 	last_stop_pos = koord3d::invalid;
 
-	recalc_brake_soll = true;
+	recalc_data_front = true;
 	recalc_data = true;
 }
 
@@ -234,7 +240,7 @@ void convoi_t::unreserve_route()
 {
 	// need a route, vehicles, and vehicles must belong to this convoi
 	// (otherwise crash during loading when fahr[0]->convoi is not initialized yet
-	if(  !route.empty()  &&  anz_vehikel>0  &&  fahr[0]->get_convoi() == this) {
+	if(  !route.empty()  &&  anz_vehikel>0  &&  fahr[0]->get_convoi() == this  ) {
 		waggon_t* lok = dynamic_cast<waggon_t*>(fahr[0]);
 		if (lok) {
 			// free all reserved blocks
@@ -245,6 +251,23 @@ void convoi_t::unreserve_route()
 }
 
 
+/**
+ * unreserves the whole remaining route
+ */
+void convoi_t::reserve_route()
+{
+	if(  !route.empty()  &&  anz_vehikel>0  &&  (is_waiting()  ||  state==DRIVING  ||  state==LEAVING_DEPOT)  ) {
+		for(  int idx = back()->get_route_index();  idx < next_reservation_index  /*&&  idx < route.get_count()*/;  idx++  ) {
+			if(  grund_t *gr = welt->lookup( route.position_bei(idx) )  ) {
+				if(  schiene_t *sch = (schiene_t *)gr->get_weg( front()->get_waytype() )  ) {
+					sch->reserve( self, ribi_typ( route.position_bei(max(1u,idx)-1u), route.position_bei(min(route.get_count()-1u,idx+1u)) ) );
+				}
+			}
+		}
+	}
+}
+
+
 uint32 convoi_t::move_to(karte_t const& welt, koord3d const& k, uint16 const start_index)
 {
 	uint32 train_length = 0;
@@ -327,7 +350,7 @@ DBG_MESSAGE("convoi_t::laden_abschliessen()","state=%s, next_stop_index=%d", sta
 		}
 		else {
 			// test also for realignment
-			sint16 step_pos;
+			sint16 step_pos = 0;
 			koord3d drive_pos;
 			uint8 const diagonal_vehicle_steps_per_tile = (uint8)(130560U / welt->get_settings().get_pak_diagonal_multiplier());
 			for( uint8 i=0;  i<anz_vehikel;  i++ ) {
@@ -382,8 +405,7 @@ DBG_MESSAGE("convoi_t::laden_abschliessen()","next_stop_index=%d", next_stop_ind
 				vector_tpl<linehandle_t> lines;
 				get_besitzer()->simlinemgmt.get_lines(fpl->get_type(), &lines);
 				new_line = linehandle_t();
-				for (vector_tpl<linehandle_t>::const_iterator i = lines.begin(), end = lines.end(); i != end; i++) {
-					linehandle_t l = *i;
+				FOR(vector_tpl<linehandle_t>, const l, lines) {
 					if(  fpl->matches( welt, l->get_schedule() )  ) {
 						// if a line is assigned, set line!
 						new_line = l;
@@ -456,7 +478,9 @@ DBG_MESSAGE("convoi_t::laden_abschliessen()","next_stop_index=%d", next_stop_ind
 	}
 	// when saving with open window, this can happen
 	if(  state==FAHRPLANEINGABE  ) {
-		wait_lock = 30000; // 60s to drive on, if the client in question had left
+		if (umgebung_t::networkmode) {
+			wait_lock = 30000; // 60s to drive on, if the client in question had left
+		}
 		fpl->eingabe_abschliessen();
 	}
 	// some convois had wrong old direction in them
@@ -467,6 +491,8 @@ DBG_MESSAGE("convoi_t::laden_abschliessen()","next_stop_index=%d", next_stop_ind
 	if(  !line.is_bound()  ) {
 		register_stops();
 	}
+
+	calc_speedbonus_kmh();
 }
 
 
@@ -501,6 +527,7 @@ void convoi_t::rotate90( const sint16 y_size )
 	for(  int i=0;  i<anz_vehikel;  i++  ) {
 		fahr[i]->remove_stale_freight();
 	}
+	freight_info_resort = true;
 }
 
 
@@ -629,7 +656,7 @@ void convoi_t::calc_acceleration(long delta_t)
 	// Dwachs: only compute this if a vehicle in the convoi hopped
 	if (recalc_data) {
 		// calculate total friction and lowest speed limit
-		sint32 min_speed_limit = min( min_top_speed, front()->get_speed_limit() );
+		speed_limit = min( min_top_speed, front()->get_speed_limit() );
 		sum_gesamtgewicht = front()->get_gesamtgewicht();
 		sum_friction_weight = front()->get_frictionfactor() * sum_gesamtgewicht;
 		for(  unsigned i=1; i<anz_vehikel; i++  ) {
@@ -638,10 +665,10 @@ void convoi_t::calc_acceleration(long delta_t)
 
 			sum_friction_weight += v->get_frictionfactor() * total_vehicle_weight;
 			sum_gesamtgewicht += total_vehicle_weight;
-			min_speed_limit = min( min_speed_limit, v->get_speed_limit() );
+			speed_limit = min( speed_limit, v->get_speed_limit() );
 		}
 
-		if(  recalc_brake_soll  ) {
+		if(  recalc_data_front  ) {
 			// brake at the end of stations/in front of signals and crossings
 			const uint32 tiles_left = 1 + get_next_stop_index() - front()->get_route_index();
 			brake_speed_soll = SPEED_UNLIMITED;
@@ -654,9 +681,12 @@ void convoi_t::calc_acceleration(long delta_t)
 				};
 				brake_speed_soll = brake_speed_countdown[tiles_left];
 			}
-			recalc_brake_soll = false;
+			distance_since_last_stop++;
+			sum_speed_limit += speed_to_kmh( min( min_top_speed, speed_limit ));
+
+			recalc_data_front = false;
 		}
-		akt_speed_soll = min( min_speed_limit, brake_speed_soll );
+		akt_speed_soll = min( speed_limit, brake_speed_soll );
 
 		recalc_data = false;
 	}
@@ -678,7 +708,8 @@ void convoi_t::calc_acceleration(long delta_t)
 		 * since akt_speed=10/128 km/h and we want 64*200kW=(100km/h)^2*100t, we must multiply by (128*2)/100
 		 * But since the acceleration was too fast, we just deccelerate 4x more => >>6 instead >>8 */
 		//sint32 deccel = ( ( (akt_speed*sum_friction_weight)>>6 )*(akt_speed>>2) ) / 25 + (sum_gesamtgewicht*64);	// this order is needed to prevent overflows!
-		sint32 deccel = (sint32)(( (sint64)akt_speed * (sint64)sum_friction_weight * (sint64)akt_speed ) / (25ll*256ll)) + sum_gesamtgewicht * 64l; // intermediate still overflows so sint64
+		//sint32 deccel = (sint32)( ( (sint64)akt_speed * (sint64)sum_friction_weight * (sint64)akt_speed ) / (25ll*256ll) + sum_gesamtgewicht * 64ll) / 1000ll; // intermediate still overflows so sint64
+		sint32 deccel = (sint32)( ( (sint64)akt_speed * ( (sum_friction_weight * (sint64)akt_speed ) / 3125ll + 1ll) ) / 2048ll + (sum_gesamtgewicht * 64ll) / 1000ll);
 
 		// prissi: integer sucks with planes => using floats ...
 		// turfit: result can overflow sint32 and double so onto sint64. planes ok.
@@ -686,7 +717,7 @@ void convoi_t::calc_acceleration(long delta_t)
 
 		// we normalize delta_t to 1/64th and check for speed limit */
 		//sint32 delta_v = ( ( (akt_speed>akt_speed_soll?0l:sum_gear_und_leistung) - deccel) * delta_t)/sum_gesamtgewicht;
-		sint64 delta_v = ( (sint64)((akt_speed>akt_speed_soll?0l:sum_gear_und_leistung) - deccel) * (sint64)delta_t ) / (sint64)sum_gesamtgewicht;
+		sint64 delta_v = ( (sint64)((akt_speed>akt_speed_soll?0l:sum_gear_und_leistung) - deccel) * (sint64)delta_t * 1000ll) / (sint64)sum_gesamtgewicht;
 
 		// we need more accurate arithmetic, so we store the previous value
 		delta_v += previous_delta_v;
@@ -1141,6 +1172,11 @@ void convoi_t::new_month()
 		self_destruct();
 		return;
 	}
+	// update statistics of average speed
+	if(  maxspeed_average_count==0  ) {
+		financial_history[0][CONVOI_MAXSPEED] = distance_since_last_stop>0 ? get_speedbonus_kmh() : 0;
+	}
+	maxspeed_average_count = 0;
 	// everything normal: update histroy
 	for (int j = 0; j<MAX_CONVOI_COST; j++) {
 		for (int k = MAX_MONTHS-1; k>0; k--) {
@@ -1235,6 +1271,7 @@ void convoi_t::betrete_depot(depot_t *dep)
 	// remove the current sync object from
 	// the sync list from inside sync_step()
 	welt->sync_remove(this);
+	maxspeed_average_count = 0;
 	state = INITIAL;
 }
 
@@ -1265,10 +1302,13 @@ void convoi_t::start()
 
 		// recalc weight and image
 		// also for any vehicle entered a depot, set_letztes is true! => reset it correctly
+		sint64 restwert_delta = 0;
 		for(unsigned i=0; i<anz_vehikel; i++) {
 			fahr[i]->set_erstes( false );
 			fahr[i]->set_letztes( false );
+			restwert_delta -= fahr[i]->calc_restwert();
 			fahr[i]->set_driven();
+			restwert_delta += fahr[i]->calc_restwert();
 			fahr[i]->clear_flag( ding_t::not_on_map );
 			fahr[i]->beladen( halthandle_t() );
 		}
@@ -1277,8 +1317,13 @@ void convoi_t::start()
 		// do not show the vehicle - it will be wrong positioned -vorfahren() will correct this
 		fahr[0]->set_bild(IMG_LEER);
 
+		// update finances for used vehicle reduction when first driven
+		besitzer_p->update_assets( restwert_delta );
+
 		// calc state for convoi
 		calc_loading();
+		calc_speedbonus_kmh();
+		maxspeed_average_count = 0;
 
 		if(line.is_bound()) {
 			// might have changed the vehicles in this car ...
@@ -1318,7 +1363,7 @@ void convoi_t::ziel_erreicht()
 		calc_gewinn();
 
 		akt_speed = 0;
-		buf.printf( translator::translate("!1_DEPOT_REACHED"), get_name() );
+		buf.printf( translator::translate("%s has entered a depot."), get_name() );
 		welt->get_message()->add_message(buf, v->get_pos().get_2d(),message_t::warnings, PLAYER_FLAG|get_besitzer()->get_player_nr(), IMG_LEER);
 
 		betrete_depot(dp);
@@ -1399,7 +1444,7 @@ DBG_MESSAGE("convoi_t::add_vehikel()","extend array_tpl to %i totals.",max_rail_
 		if(v->get_fracht_max() != 0) {
 			const ware_besch_t *ware=v->get_fracht_typ();
 			if(ware!=warenbauer_t::nichts  ) {
-				goods_catg_index.append_unique( ware->get_catg_index(), 1 );
+				goods_catg_index.append_unique( ware->get_catg_index() );
 			}
 		}
 		// check for obsolete
@@ -1480,11 +1525,6 @@ vehikel_t *convoi_t::remove_vehikel_bei(uint16 i)
 // recalc what good this convoy is moving
 void convoi_t::recalc_catg_index()
 {
-	// first copy old
-	minivec_tpl<uint8> old_goods_catg_index(goods_catg_index.get_count());
-	for(  uint i=0;  i<goods_catg_index.get_count();  i++  ) {
-		old_goods_catg_index.append( goods_catg_index[i] );
-	}
 	goods_catg_index.clear();
 
 	for(  uint8 i = 0;  i < get_vehikel_anzahl();  i++  ) {
@@ -1496,7 +1536,7 @@ void convoi_t::recalc_catg_index()
 		}
 		const ware_besch_t *ware=get_vehikel(i)->get_fracht_typ();
 		if(ware!=warenbauer_t::nichts  ) {
-			goods_catg_index.append_unique( ware->get_catg_index(), 1 );
+			goods_catg_index.append_unique( ware->get_catg_index() );
 		}
 	}
 	/* since during composition of convois all kinds of composition could happen,
@@ -1573,6 +1613,7 @@ bool convoi_t::set_schedule(schedule_t * f)
 	for(unsigned i=0; i<anz_vehikel; i++) {
 		fahr[i]->remove_stale_freight();
 	}
+	freight_info_resort = true;
 
 	// ok, now we have a schedule
 	if(old_state!=INITIAL) {
@@ -1753,7 +1794,7 @@ void convoi_t::vorfahren()
 	// Hajo: init speed settings
 	sp_soll = 0;
 	set_tiles_overtaking( 0 );
-	recalc_brake_soll = true;
+	recalc_data_front = true;
 	recalc_data = true;
 
 	koord3d k0 = route.front();
@@ -1901,9 +1942,6 @@ void convoi_t::rdwr(loadsave_t *file)
 	// do the update, otherwise we might lose the line after save & reload
 	if(file->is_saving()  &&  line_update_pending.is_bound()) {
 		check_pending_updates();
-		if (fpl->ist_abgeschlossen()  &&  state == FAHRPLANEINGABE) {
-			state = ROUTING_1;
-		}
 	}
 
 	simline_t::rdwr_linehandle_t(file, line);
@@ -2053,7 +2091,7 @@ void convoi_t::rdwr(loadsave_t *file)
 						v->set_pos( gr->get_pos() );
 					}
 					else {
-						dbg->fatal("convoi_t::rdwr()", "invalid position %s for vehicle %s in state %d (setting to %i,%i,%i)", v->get_pos().get_str(), v->get_name(), state, gr->get_pos().x, gr->get_pos().y, gr->get_pos().z );
+						dbg->fatal("convoi_t::rdwr()", "invalid position %s for vehicle %s in state %d", v->get_pos().get_str(), v->get_name(), state);
 					}
 					state = INITIAL;
 				}
@@ -2117,34 +2155,47 @@ void convoi_t::rdwr(loadsave_t *file)
 		// load statistics
 		int j;
 		for (j = 0; j<3; j++) {
-			for (int k = MAX_MONTHS-1; k>=0; k--) {
+			for (size_t k = MAX_MONTHS; k-- != 0;) {
 				file->rdwr_longlong(financial_history[k][j]);
 			}
 		}
 		for (j = 2; j<5; j++) {
-			for (int k = MAX_MONTHS-1; k>=0; k--) {
+			for (size_t k = MAX_MONTHS; k-- != 0;) {
 				file->rdwr_longlong(financial_history[k][j]);
 			}
 		}
-		for (int k = MAX_MONTHS-1; k>=0; k--) {
+		for (size_t k = MAX_MONTHS; k-- != 0;) {
 			financial_history[k][CONVOI_DISTANCE] = 0;
+			financial_history[k][CONVOI_MAXSPEED] = 0;
 		}
 	}
 	else if(  file->get_version()<=102002  ){
 		// load statistics
 		for (int j = 0; j<5; j++) {
-			for (int k = MAX_MONTHS-1; k>=0; k--) {
+			for (size_t k = MAX_MONTHS; k-- != 0;) {
 				file->rdwr_longlong(financial_history[k][j]);
 			}
 		}
-		for (int k = MAX_MONTHS-1; k>=0; k--) {
+		for (size_t k = MAX_MONTHS; k-- != 0;) {
 			financial_history[k][CONVOI_DISTANCE] = 0;
+			financial_history[k][CONVOI_MAXSPEED] = 0;
+		}
+	}
+	else if(  file->get_version()<111001  ){
+		// load statistics
+		for (int j = 0; j<6; j++) {
+			for (size_t k = MAX_MONTHS; k-- != 0;) {
+				file->rdwr_longlong(financial_history[k][j]);
+			}
+		}
+		for (size_t k = MAX_MONTHS; k-- != 0;) {
+			financial_history[k][CONVOI_MAXSPEED] = 0;
 		}
 	}
 	else {
 		// load statistics
 		for (int j = 0; j<MAX_CONVOI_COST; j++) {
-			for (int k = MAX_MONTHS-1; k>=0; k--) {
+			for (size_t k = MAX_MONTHS; k-- != 0;) {
 				file->rdwr_longlong(financial_history[k][j]);
 			}
 		}
@@ -2238,7 +2289,22 @@ void convoi_t::rdwr(loadsave_t *file)
 		file->rdwr_bool(withdraw);
 	}
 
-	if( file->is_loading() ) {
+	if(file->get_version()>=111001) {
+		file->rdwr_long( distance_since_last_stop );
+		file->rdwr_long( sum_speed_limit );
+	}
+
+	if(  file->get_version()>=111002  ) {
+		file->rdwr_long( maxspeed_average_count );
+	}
+
+	if(  file->get_version()>=111003  ) {
+		file->rdwr_short( next_stop_index );
+		file->rdwr_short( next_reservation_index );
+	}
+
+	if(  file->is_loading()  ) {
+		reserve_route();
 		recalc_catg_index();
 	}
 }
@@ -2322,13 +2388,9 @@ void convoi_t::get_freight_info(cbuffer_t & buf)
 			}
 
 			// then add the actual load
-			slist_iterator_tpl<ware_t> iter_vehicle_ware(v->get_fracht());
-			while(iter_vehicle_ware.next()) {
-				ware_t ware = iter_vehicle_ware.get_current();
-				for(unsigned i=0;  i<total_fracht.get_count();  i++ ) {
-
+			FOR(slist_tpl<ware_t>, ware, v->get_fracht()) {
+				FOR(vector_tpl<ware_t>, & tmp, total_fracht) {
 					// could this be joined with existing freight?
-					ware_t &tmp = total_fracht[i];
 
 					// for pax: join according next stop
 					// for all others we *must* use target coordinates
@@ -2355,25 +2417,21 @@ void convoi_t::get_freight_info(cbuffer_t & buf)
 			if(max_loaded_waren[i]>0  &&  i!=warenbauer_t::INDEX_NONE) {
 				ware_t ware(warenbauer_t::get_info(i));
 				ware.menge = max_loaded_waren[i];
-				if(ware.get_catg()==0) {
-					capacity.append( ware );
+				// append to category?
+				slist_tpl<ware_t>::iterator j   = capacity.begin();
+				slist_tpl<ware_t>::iterator end = capacity.end();
+				while (j != end && j->get_besch()->get_catg_index() < ware.get_besch()->get_catg_index()) ++j;
+				if (j != end && j->get_besch()->get_catg_index() == ware.get_besch()->get_catg_index()) {
+					j->menge += max_loaded_waren[i];
 				} else {
-					// append to category?
-					slist_tpl<ware_t>::iterator j   = capacity.begin();
-					slist_tpl<ware_t>::iterator end = capacity.end();
-					while (j != end && j->get_catg() < ware.get_catg()) ++j;
-					if (j != end && j->get_catg() == ware.get_catg()) {
-						j->menge += max_loaded_waren[i];
-					} else {
-						// not yet there
-						capacity.insert(j, ware);
-					}
+					// not yet there
+					capacity.insert(j, ware);
 				}
 			}
 		}
 
 		// show new info
-		freight_list_sorter_t::sort_freight(&total_fracht, buf, (freight_list_sorter_t::sort_mode_t)freight_info_order, &capacity, "loaded", welt);
+		freight_list_sorter_t::sort_freight(total_fracht, buf, (freight_list_sorter_t::sort_mode_t)freight_info_order, &capacity, "loaded", welt);
 	}
 }
 
@@ -2460,9 +2518,6 @@ void convoi_t::laden()
 			// loading/unloading ...
 			halt->request_loading( self );
 		}
-		else {
-			halt = halthandle_t();
-		}
 	}
 
 	// just wait a little longer to get maximum load ...
@@ -2484,6 +2539,16 @@ void convoi_t::calc_gewinn()
 		v->last_stop_pos = v->get_pos().get_2d();
 	}
 
+	// update statistics of average speed
+	if(  distance_since_last_stop  ) {
+		financial_history[0][CONVOI_MAXSPEED] *= maxspeed_average_count;
+		financial_history[0][CONVOI_MAXSPEED] += get_speedbonus_kmh();
+		maxspeed_average_count ++;
+		financial_history[0][CONVOI_MAXSPEED] /= maxspeed_average_count;
+	}
+	distance_since_last_stop = 0;
+	sum_speed_limit = 0;
+
 	if(gewinn) {
 		besitzer_p->buche(gewinn, fahr[0]->get_pos().get_2d(), COST_INCOME);
 		jahresgewinn += gewinn;
@@ -2505,6 +2570,7 @@ void convoi_t::hat_gehalten(halthandle_t halt)
 	sint64 gewinn = 0;
 	grund_t *gr=welt->lookup(fahr[0]->get_pos());
 
+	// now find out station length
 	int station_length=0;
 	if(gr->ist_wasser()) {
 		// harbour has any size
@@ -2517,14 +2583,14 @@ void convoi_t::hat_gehalten(halthandle_t halt)
 		const grund_t *grund = welt->lookup(pos);
 		if(  grund->get_weg_yoff()==TILE_HEIGHT_STEP  ) {
 			// start on bridge?
-			pos.z += Z_TILE_STEP;
+			pos.z ++;
 		}
 		while(  grund  &&  grund->get_halt() == halt  ) {
 			station_length += 16;
 			pos += zv;
 			grund = welt->lookup(pos);
 			if(  grund==NULL  ) {
-				grund = welt->lookup(pos-koord3d(0,0,Z_TILE_STEP));
+				grund = welt->lookup(pos-koord3d(0,0,1));
 				if(  grund &&  grund->get_weg_yoff()!=TILE_HEIGHT_STEP  ) {
 					// not end/start of bridge
 					break;
@@ -2571,6 +2637,16 @@ void convoi_t::hat_gehalten(halthandle_t halt)
 	calc_loading();
 	loading_limit = fpl->get_current_eintrag().ladegrad;
 
+	// update statistics of average speed
+	if(  distance_since_last_stop  ) {
+		financial_history[0][CONVOI_MAXSPEED] *= maxspeed_average_count;
+		financial_history[0][CONVOI_MAXSPEED] += get_speedbonus_kmh();
+		maxspeed_average_count ++;
+		financial_history[0][CONVOI_MAXSPEED] /= maxspeed_average_count;
+	}
+	distance_since_last_stop = 0;
+	sum_speed_limit = 0;
+
 	if(gewinn) {
 		besitzer_p->buche(gewinn, fahr[0]->get_pos().get_2d(), COST_INCOME);
 		jahresgewinn += gewinn;
@@ -2579,7 +2655,7 @@ void convoi_t::hat_gehalten(halthandle_t halt)
 		book(gewinn, CONVOI_REVENUE);
 	}
 
-	// Nun wurde ein/ausgeladen werden
+	// loading is finished => maybe drive on
 	if(loading_level>=loading_limit  ||  no_load  ||  welt->get_zeit_ms()>go_on_ticks)  {
 
 		if(withdraw  &&  (loading_level==0  ||  goods_catg_index.empty())) {
@@ -2588,6 +2664,8 @@ void convoi_t::hat_gehalten(halthandle_t halt)
 			return;
 		}
 
+		calc_speedbonus_kmh();
+
 		// add available capacity after loading(!) to statistics
 		for (unsigned i = 0; i<anz_vehikel; i++) {
 			book(get_vehikel(i)->get_fracht_max()-get_vehikel(i)->get_fracht_menge(), CONVOI_CAPACITY);
@@ -2636,6 +2714,58 @@ void convoi_t::calc_loading()
 }
 
 
+void convoi_t::calc_speedbonus_kmh()
+{
+	// init with default
+	const sint32 cnv_min_top_kmh = speed_to_kmh( min_top_speed );
+	speedbonus_kmh = cnv_min_top_kmh;
+	// flying aircraft have 0 friction --> speed not limited by power, so just use top_speed
+	if(  front()!=NULL  &&  front()->get_waytype() != air_wt  ) {
+		const sint32 total_power = sum_gear_und_leistung/64;
+		sint32 total_max_weight = 0;
+		sint32 total_weight = 0;
+		for(  unsigned i=0;  i<anz_vehikel;  i++  ) {
+			const vehikel_besch_t* const besch = fahr[i]->get_besch();
+			total_max_weight += besch->get_gewicht();
+			total_weight += fahr[i]->get_gesamtgewicht(); // convoi_t::sum_gesamgewicht may not be updated yet when this method is called...
+			if(  besch->get_ware() == warenbauer_t::nichts  ) {
+				; // nothing
+			}
+			else if(  besch->get_ware()->get_catg() == 0  ) {
+				// use full weight for passengers, post, and special goods
+				total_max_weight += besch->get_ware()->get_weight_per_unit() * besch->get_zuladung();
+			}
+			else {
+				// use actual weight for regular goods
+				total_max_weight += fahr[i]->get_fracht_gewicht();
+			}
+		}
+		// very old vehicles have zero weight ...
+		if(  total_weight>0  ) {
+			total_weight = max( 1, total_weight/1000 );
+			total_max_weight = max( 1, total_max_weight/1000 );
+			// uses weight of full passenger, mail, and special goods cars and current weight of regular goods cars for convoi weight
+			speedbonus_kmh = total_power < total_max_weight ? 1 : min( cnv_min_top_kmh, sint32( sqrt_i32( ((1000l*total_power<<8)/total_max_weight-(1<<8))<<8)*50 >>8 ) );
+
+			// convoi overtakers use current actual weight for achievable speed
+			if(  front()->get_overtaker()  ) {
+				max_power_speed = kmh_to_speed( total_power < total_weight ? 1 : min( cnv_min_top_kmh, (sint32)( sqrt_i32(((total_power<<8)/total_weight-(1<<8))<<8)*50 >>8 ) ) );
+			}
+		}
+	}
+}
+
+
+// return the current bonus speed
+sint32 convoi_t::get_speedbonus_kmh() const
+{
+	if(  distance_since_last_stop > 0  &&  front()!=NULL  &&  front()->get_waytype() != air_wt  ) {
+		return min( speedbonus_kmh, (sint32)(sum_speed_limit / distance_since_last_stop) );
+	}
+	return speedbonus_kmh;
+}
+
+
 /**
  * Schedule convoid for self destruction. Will be executed
  * upon next sync step
@@ -2671,7 +2801,7 @@ void convoi_t::destroy()
 
 	if(  state == INITIAL  ) {
 		// in depot => not on map
-		for(int i=anz_vehikel-1;  i>=0; i--) {
+		for(  uint8 i = anz_vehikel;  i-- != 0;  ) {
 			fahr[i]->set_flag( ding_t::not_on_map );
 		}
 	}
@@ -2692,13 +2822,13 @@ void convoi_t::destroy()
 	besitzer_p->buche( calc_restwert(), get_pos().get_2d(), COST_NEW_VEHICLE );
 	besitzer_p->buche( -calc_restwert(), COST_ASSETS );
 
-	for(int i=anz_vehikel-1;  i>=0; i--) {
+	for(  uint8 i = anz_vehikel;  i-- != 0;  ) {
 		if(  !fahr[i]->get_flag( ding_t::not_on_map )  ) {
 			// remove from rails/roads/crossings
 			grund_t *gr = welt->lookup(fahr[i]->get_pos());
 			fahr[i]->set_letztes( true );
 			fahr[i]->verlasse_feld();
-			if(gr  &&  gr->ist_uebergang()) {
+			if(  gr  &&  gr->ist_uebergang()  ) {
 				gr->find<crossing_t>()->release_crossing(fahr[i]);
 			}
 			fahr[i]->set_flag( ding_t::not_on_map );
@@ -2756,9 +2886,8 @@ void convoi_t::book(sint64 amount, int cost_type)
 
 	financial_history[0][cost_type] += amount;
 	if (line.is_bound()) {
-		line->book(amount, simline_t::convoi_to_line_catgory(cost_type) );
+		line->book( amount, simline_t::convoi_to_line_catgory(cost_type) );
 	}
-
 	if(cost_type == CONVOI_TRANSPORTED_GOODS) {
 		besitzer_p->buche(amount, COST_ALL_TRANSPORTED);
 	}
@@ -2768,7 +2897,7 @@ void convoi_t::book(sint64 amount, int cost_type)
 void convoi_t::init_financial_history()
 {
 	for (int j = 0; j<MAX_CONVOI_COST; j++) {
-		for (int k = MAX_MONTHS-1; k>=0; k--) {
+		for (size_t k = MAX_MONTHS; k-- != 0;) {
 			financial_history[k][j] = 0;
 		}
 	}
@@ -2829,7 +2958,7 @@ DBG_DEBUG("convoi_t::unset_line()", "removing old destinations from line=%d, fpl
 }
 
 
-// matches two halts; if the pos is not identical, maybe the halt still is
+// matches two halts; if the pos is not identical, maybe the halt still is the same
 bool convoi_t::matches_halt( const koord3d pos1, const koord3d pos2 )
 {
 	halthandle_t halt1 = haltestelle_t::get_halt( welt, pos1, besitzer_p );
@@ -2952,6 +3081,7 @@ void convoi_t::check_pending_updates()
 				for(uint8 i=0; i<anz_vehikel; i++) {
 					fahr[i]->remove_stale_freight();
 				}
+				freight_info_resort = true;
 			}
 			else {
 				// need re-routing
@@ -2973,8 +3103,8 @@ void convoi_t::check_pending_updates()
 void convoi_t::register_stops()
 {
 	if(  fpl  ) {
-		for(  uint8 i=0;  i<fpl->get_count();  ++i  ) {
-			const halthandle_t halt = haltestelle_t::get_halt( welt, fpl->eintrag[i].pos, get_besitzer() );
+		FOR(minivec_tpl<linieneintrag_t>, const& i, fpl->eintrag) {
+			halthandle_t const halt = haltestelle_t::get_halt(welt, i.pos, get_besitzer());
 			if(  halt.is_bound()  ) {
 				halt->add_convoy(self);
 			}
@@ -2990,8 +3120,8 @@ void convoi_t::register_stops()
 void convoi_t::unregister_stops()
 {
 	if(  fpl  ) {
-		for(  uint8 i=0;  i<fpl->get_count();  ++i  ) {
-			const halthandle_t halt = haltestelle_t::get_halt( welt, fpl->eintrag[i].pos, get_besitzer() );
+		FOR(minivec_tpl<linieneintrag_t>, const& i, fpl->eintrag) {
+			halthandle_t const halt = haltestelle_t::get_halt(welt, i.pos, get_besitzer());
 			if(  halt.is_bound()  ) {
 				halt->remove_convoy(self);
 			}
@@ -3017,6 +3147,20 @@ void convoi_t::set_next_stop_index(uint16 n)
 
 
 
+/* including this route_index, the route was reserved the laste time
+ * currently only used for tracks
+ */
+void convoi_t::set_next_reservation_index(uint16 n)
+{
+	// stop at station or signals, not at waypoints
+	if(  n==INVALID_INDEX  ) {
+		n = route.get_count()-1;
+	}
+	next_reservation_index = n;
+}
+
+
+
 /*
  * the current state saved as color
  * Meanings are BLACK (ok), WHITE (no convois), YELLOW (no vehicle moved), RED (last month income minus), BLUE (at least one convoi vehicle is obsolete)
@@ -3026,8 +3170,7 @@ uint8 convoi_t::get_status_color() const
 	if(state==INITIAL) {
 		// in depot/under assembly
 		return COL_WHITE;
-	}
-	else if(state==WAITING_FOR_CLEARANCE_ONE_MONTH  ||  state==CAN_START_ONE_MONTH  ||  hat_keine_route()) {
+	} else if (state == WAITING_FOR_CLEARANCE_ONE_MONTH || state == CAN_START_ONE_MONTH || get_state() == NO_ROUTE) {
 		// stuck or no route
 		return COL_ORANGE;
 	}
@@ -3074,8 +3217,15 @@ void convoi_t::set_withdraw(bool new_withdraw)
 	if(  withdraw  &&  (loading_level==0  ||  goods_catg_index.empty())) {
 		// test if convoi in depot and not driving
 		grund_t *gr = welt->lookup( get_pos());
-		if (gr && gr->get_depot()  &&  state == INITIAL) {
+		if(  gr  &&  gr->get_depot()  &&  state == INITIAL  ) {
+#if 1
+			// do not touch line bound convois in depots
+			withdraw = false;
+			no_load = false;
+#else
+			// disassemble also line bound convois in depots
 			gr->get_depot()->disassemble_convoi(self, true);
+#endif
 		}
 		else {
 			self_destruct();
@@ -3090,7 +3240,7 @@ void convoi_t::set_withdraw(bool new_withdraw)
  * The city car is not overtaking/being overtaken.
  * @author isidoro
  */
-bool convoi_t::can_overtake(overtaker_t *other_overtaker, int other_speed, int steps_other, int diagonal_vehicle_steps_per_tile)
+bool convoi_t::can_overtake(overtaker_t *other_overtaker, sint32 other_speed, sint16 steps_other)
 {
 	if(fahr[0]->get_waytype()!=road_wt) {
 		return false;
@@ -3117,7 +3267,7 @@ bool convoi_t::can_overtake(overtaker_t *other_overtaker, int other_speed, int s
 
 		uint16 idx = fahr[0]->get_route_index();
 		const sint32 tiles = (steps_other-1)/(CARUNITS_PER_TILE*VEHICLE_STEPS_PER_CARUNIT) + get_tile_length() + 1;
-		if(  idx+tiles >= route.get_count()  ) {
+		if(  tiles > 0  &&  idx+(uint32)tiles >= route.get_count()  ) {
 			// needs more space than there
 			return false;
 		}
@@ -3219,7 +3369,7 @@ bool convoi_t::can_overtake(overtaker_t *other_overtaker, int other_speed, int s
 			return false;
 		}
 
-		int d = ribi_t::ist_gerade(str->get_ribi()) ? VEHICLE_STEPS_PER_TILE : diagonal_vehicle_steps_per_tile;
+		int d = ribi_t::ist_gerade(str->get_ribi()) ? VEHICLE_STEPS_PER_TILE : vehikel_basis_t::get_diagonal_vehicle_steps_per_tile();
 		distance -= d;
 		time_overtaking += d;
 
@@ -3278,7 +3428,7 @@ bool convoi_t::can_overtake(overtaker_t *other_overtaker, int other_speed, int s
 			time_overtaking -= (VEHICLE_STEPS_PER_TILE<<16) / kmh_to_speed(str->get_max_speed());
 		}
 		else {
-			time_overtaking -= (diagonal_vehicle_steps_per_tile<<16) / kmh_to_speed(str->get_max_speed());
+			time_overtaking -= (vehikel_basis_t::get_diagonal_vehicle_steps_per_tile()<<16) / kmh_to_speed(str->get_max_speed());
 		}
 
 		// Check for other vehicles in facing direction
