@@ -16,7 +16,6 @@
 
 #include "simdebug.h"
 #include "simimg.h"
-#include "simmem.h"
 #include "simcolor.h"
 #include "boden/grund.h"
 #include "boden/boden.h"
@@ -24,7 +23,6 @@
 #include "simfab.h"
 #include "simcity.h"
 #include "simhalt.h"
-#include "simskin.h"
 #include "simtools.h"
 #include "simware.h"
 #include "simworld.h"
@@ -32,7 +30,6 @@
 #include "besch/ware_besch.h"
 #include "player/simplay.h"
 
-
 #include "simintr.h"
 
 #include "dings/wolke.h"
@@ -45,7 +42,6 @@
 #include "dataobj/translator.h"
 #include "dataobj/loadsave.h"
 
-#include "besch/skin_besch.h"
 #include "besch/fabrik_besch.h"
 #include "bauer/hausbauer.h"
 #include "bauer/warenbauer.h"
@@ -525,7 +521,7 @@ void fabrik_t::set_base_production(sint32 p)
 }
 
 
-fabrik_t *fabrik_t::get_fab(const karte_t *welt, const koord pos)
+fabrik_t *fabrik_t::get_fab(const karte_t *welt, const koord &pos)
 {
 	const grund_t *gr = welt->lookup_kartenboden(pos);
 	if(gr) {
@@ -1086,13 +1082,13 @@ DBG_DEBUG("fabrik_t::rdwr()","loading factory '%s'",s);
 		else {
 			uint16 nr=0;
 			koord k;
-			uint16 idx;
 			file->rdwr_short(nr);
 			fields.resize(nr);
 			if(  file->get_version()>102002  ) {
 				// each field stores location and a field class index
 				for(  uint16 i=0  ;  i<nr  ;  ++i  ) {
 					k.rdwr(file);
+					uint16 idx;
 					file->rdwr_short(idx);
 					if(  besch==NULL  ||  idx>=besch->get_field_group()->get_field_class_count()  ) {
 						// set class index to 0 if it is out of range
@@ -1191,13 +1187,13 @@ void fabrik_t::smoke() const
 		const koord size = besch->get_haus()->get_groesse(0)-koord(1,1);
 		const uint8 rot = rotate%besch->get_haus()->get_all_layouts();
 		koord ro = rada->get_pos_off(size,rot);
-		grund_t *gr=welt->lookup_kartenboden(pos.get_2d()+ro);
+		grund_t *gr = welt->lookup_kartenboden(pos.get_2d()+ro);
 		// to get same random order on different compilers
-		const sint8 offsetx =  ((rada->get_xy_off(rot).x+simrand(7)-3)*OBJECT_OFFSET_STEPS)/16;
-		const sint8 offsety =  ((rada->get_xy_off(rot).y+simrand(7)-3)*OBJECT_OFFSET_STEPS)/16;
+		const sint8 offsetx =  ((rada->get_xy_off(rot).x+sim_async_rand(7)-3)*OBJECT_OFFSET_STEPS)/16;
+		const sint8 offsety =  ((rada->get_xy_off(rot).y+sim_async_rand(7)-3)*OBJECT_OFFSET_STEPS)/16;
 		wolke_t *smoke =  new wolke_t(welt, gr->get_pos(), offsetx, offsety, rada->get_bilder() );
 		gr->obj_add(smoke);
-		welt->sync_add( smoke );
+		welt->sync_way_eyecandy_add( smoke );
 	}
 }
 
@@ -1615,11 +1611,9 @@ void fabrik_t::verteile_waren(const uint32 produkt)
 
 			// prissi: this way, the halt, that is tried first, will change. As a result, if all destinations are empty, it will be spread evenly
 			const koord lieferziel = lieferziele[(n + index_offset) % lieferziele.get_count()];
-
 			fabrik_t * ziel_fab = get_fab(welt, lieferziel);
-			int vorrat;
 
-			if(  ziel_fab  &&  (vorrat = ziel_fab->verbraucht(ausgang[produkt].get_typ())) >= 0  ) {
+			if(  ziel_fab  &&  ziel_fab->verbraucht(ausgang[produkt].get_typ()) >= 0  ) {
 				ware_t ware(ausgang[produkt].get_typ());
 				ware.menge = menge;
 				ware.to_factory = 1;
