@@ -1,11 +1,6 @@
 /*
- * Copyright (c) 2001 Hansjrg Malthaner
- * hansjoerg.malthaner@gmx.de
- *
- * This file is part of the Simugraph engine and may not be used
- * in other projects without written permission of the author.
- *
- * Usage for Iso-Angband is granted.
+ * Copyright 2010 Simutrans contributors
+ * Available under the Artistic License (see license.txt)
  */
 
 #include "simconst.h"
@@ -17,6 +12,8 @@
 typedef uint16 PIXVAL;
 
 int large_font_height = 10;
+int large_font_total_height = 11;
+int large_font_ascent = 9;
 
 KOORD_VAL tile_raster_width = 16; // zoomed
 KOORD_VAL base_tile_raster_width = 16; // original
@@ -178,6 +175,10 @@ display_image_proc display_color = display_base_img;
 display_blend_proc display_blend = display_base_img_blend;
 signed short current_tile_raster_width = 0;
 
+void display_blend_wh(KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, int, int )
+{
+}
+
 void display_mark_img_dirty(unsigned, KOORD_VAL, KOORD_VAL)
 {
 }
@@ -311,6 +312,10 @@ void simgraph_resize(KOORD_VAL, KOORD_VAL)
 {
 }
 
+void reset_textur(void *)
+{
+}
+
 void display_snapshot()
 {
 }
@@ -319,6 +324,26 @@ void display_direct_line(const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, cons
 {
 }
 
+void display_direct_line(const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const PLAYER_COLOR_VAL)
+{
+}
+
+void display_direct_line_dotted(const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const KOORD_VAL, const PLAYER_COLOR_VAL)
+{
+}
+
+void display_circle( KOORD_VAL, KOORD_VAL, int, const PLAYER_COLOR_VAL )
+{
+}
+
+void display_filled_circle( KOORD_VAL, KOORD_VAL, int, const PLAYER_COLOR_VAL )
+{
+}
+
+void draw_bezier(KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, const PLAYER_COLOR_VAL, KOORD_VAL, KOORD_VAL )
+{
+}
+
 void display_set_progress_text(const char *)
 {
 }
