@@ -111,7 +111,7 @@ void haltestelle_t::step_all()
 halthandle_t haltestelle_t::get_halt(const karte_t *welt, const koord pos, const spieler_t *sp )
 {
 	const planquadrat_t *plan = welt->lookup(pos);
-	if(plan) {
+	if(  plan  ) {
 		if(plan->get_halt().is_bound()  &&  spieler_t::check_owner(sp,plan->get_halt()->get_besitzer())  ) {
 			return plan->get_halt();
 		}
@@ -504,13 +504,13 @@ void haltestelle_t::set_name(const char *new_name)
 		if(gr->get_flag(grund_t::has_text)) {
 			halthandle_t h = all_names.remove(gr->get_text());
 			if(h!=self) {
-				DBG_MESSAGE("haltestelle_t::set_name()","name %s already used!",gr->get_text());
+				DBG_MESSAGE("haltestelle_t::set_name()","removing name %s already used!",gr->get_text());
 			}
 		}
 		if(!gr->find<label_t>()) {
 			gr->set_text( new_name );
 			if(new_name  &&  !all_names.put(gr->get_text(),self)) {
-				DBG_MESSAGE("haltestelle_t::set_name()","name %s already used!",new_name);
+ 				DBG_MESSAGE("haltestelle_t::set_name()","name %s already used!",new_name);
 			}
 		}
 		// Knightly : need to update the title text of the associated halt detail and info dialogs, if present
@@ -611,7 +611,7 @@ char* haltestelle_t::create_name(koord const k, char const* const typ)
 				int this_distance = 999;
 				FOR(slist_tpl<fabrik_t*>, const f, get_fab_list()) {
 					int distance = koord_distance(f->get_pos().get_2d(), k);
-					if (distance < this_distance) {
+					if(  distance < this_distance  ) {
 						fabs.insert(f);
 						this_distance = distance;
 					}
@@ -690,11 +690,13 @@ char* haltestelle_t::create_name(koord const k, char const* const typ)
 				const uint32 idx = simrand(street_names.get_count());
 
 				buf.clear();
-				buf.printf( street_names[idx], city_name, stop );
-				if(  !all_names.get(buf).is_bound()  ) {
-					return strdup(buf);
+				if (cbuffer_t::check_format_strings("%s %s", street_names[idx])) {
+					buf.printf( street_names[idx], city_name, stop );
+					if(  !all_names.get(buf).is_bound()  ) {
+						return strdup(buf);
+					}
 				}
-				// else remove this entry
+				// remove this entry
 				street_names[idx] = street_names.back();
 				street_names.pop_back();
 			}
@@ -761,14 +763,18 @@ char* haltestelle_t::create_name(koord const k, char const* const typ)
 				// allow for names without direction
 				uint8 count_s = count_printf_param( base_name );
 				if(count_s==3) {
-					// ok, try this name, if free ...
-					buf.printf( base_name, city_name, dirname, stop );
+					if (cbuffer_t::check_format_strings("%s %s %s", base_name) ) {
+						// ok, try this name, if free ...
+						buf.printf( base_name, city_name, dirname, stop );
+					}
 				}
 				else {
-					// ok, try this name, if free ...
-					buf.printf( base_name, city_name, stop );
+					if (cbuffer_t::check_format_strings("%s %s", base_name) ) {
+						// ok, try this name, if free ...
+						buf.printf( base_name, city_name, stop );
+					}
 				}
-				if(  !all_names.get(buf).is_bound()  ) {
+				if(  buf.len()>0  &&  !all_names.get(buf).is_bound()  ) {
 					return strdup(buf);
 				}
 				buf.clear();
@@ -868,7 +874,7 @@ void haltestelle_t::neuer_monat()
 {
 	if(  welt->get_active_player()==besitzer_p  &&  status_color==COL_RED  ) {
 		cbuffer_t buf;
-		buf.printf( translator::translate("!0_STATION_CROWDED"), get_name() );
+		buf.printf( translator::translate("%s\nis crowded."), get_name() );
 		welt->get_message()->add_message(buf, get_basis_pos(),message_t::full, PLAYER_FLAG|besitzer_p->get_player_nr(), IMG_LEER );
 		enables &= (PAX|POST|WARE);
 	}
@@ -880,6 +886,8 @@ void haltestelle_t::neuer_monat()
 		}
 		financial_history[0][j] = 0;
 	}
+	// number of waitung should be constant ...
+	financial_history[0][HALT_WAITING] = financial_history[1][HALT_WAITING];
 }
 
 
@@ -1952,17 +1960,19 @@ dbg->warning("haltestelle_t::liefere_an()","%d %s delivered to %s have no longer
 	}
 
 	// did we arrived?
-	if(welt->lookup(ware.get_zielpos())->is_connected(self)) {
+	if(  welt->lookup(ware.get_zielpos())->is_connected(self)  ) {
 		if(  ware.to_factory  ) {
 			// muss an fabrik geliefert werden
 			liefere_an_fabrik(ware);
 		}
-		else if(ware.get_besch()==warenbauer_t::passagiere) {
+		else if(  ware.get_besch() == warenbauer_t::passagiere  ) {
 			// arriving passenger may create pedestrians
-			if (welt->get_settings().get_show_pax()) {
+			if(  welt->get_settings().get_show_pax()  ) {
 				int menge = ware.menge;
-				FOR(slist_tpl<tile_t>, const& i, tiles) {
-					if (menge <= 0) break;
+				FOR( slist_tpl<tile_t>, const& i, tiles ) {
+					if (menge <= 0) {
+						break;
+					}
 					menge = erzeuge_fussgaenger(welt, i.grund->get_pos(), menge);
 				}
 				INT_CHECK("simhalt 938");
@@ -2577,9 +2587,27 @@ void haltestelle_t::laden_abschliessen()
 		}
 	}
 	else {
-		if(!all_names.put(bd->get_text(),self)) {
-			DBG_MESSAGE("haltestelle_t::set_name()","name %s already used!",bd->get_text());
+		const char *current_name = bd->get_text();
+		if(  all_names.get(current_name).is_bound()  ) {
+			// try to get a new name ...
+			const char *new_name;
+			if(  station_type & airstop  ) {
+				new_name = create_name( get_basis_pos(), "Airport" );
+			}
+			else if(  station_type & dock  ) {
+				new_name = create_name( get_basis_pos(), "Dock" );
+			}
+			else if(  station_type & (railstation|monorailstop|maglevstop|narrowgaugestop)  ) {
+				new_name = create_name( get_basis_pos(), "Bf" );
+			}
+			else {
+				new_name = create_name( get_basis_pos(), "H" );
+			}
+			dbg->warning("haltestelle_t::set_name()","name already used: \'%s\' -> \'%s\'", current_name, new_name );
+			bd->set_text( new_name );
+			current_name = new_name;
 		}
+		all_names.put( current_name, self );
 	}
 	recalc_status();
 	reconnect_counter = welt->get_schedule_counter()-1;
