@@ -249,7 +249,9 @@ void modal_dialogue( gui_frame_t *gui, long magic, karte_t *welt, bool (*quit)()
 				if (ev.ev_code==SYSTEM_RESIZE) {
 					// main window resized
 					simgraph_resize( ev.mx, ev.my );
+					dr_prepare_flush();
 					display_fillbox_wh( 0, 0, ev.mx, ev.my, COL_BLACK, true );
+					dr_flush();
 				}
 				else if (ev.ev_code == SYSTEM_QUIT) {
 					umgebung_t::quit_simutrans = true;
@@ -262,7 +264,9 @@ void modal_dialogue( gui_frame_t *gui, long magic, karte_t *welt, bool (*quit)()
 			}
 		}
 		set_pointer(1);
+		dr_prepare_flush();
 		display_fillbox_wh( 0, 0, display_get_width(), display_get_height(), COL_BLACK, true );
+		dr_flush();
 	}
 
 	// just trigger not another following window => wait for button release
@@ -378,7 +382,6 @@ int simu_main(int argc, char** argv)
 			"\n"
 			"  Based on Simutrans 0.84.21.2\n"
 			"  by Hansjrg Malthaner et. al.\n"
-			"  <hansjoerg.malthaner@gmx.de>\n"
 			"---------------------------------------\n"
 			"command line parameters available: \n"
 			" -addons             loads also addons (with -objects)\n"
@@ -680,10 +683,21 @@ int simu_main(int argc, char** argv)
 			return 0;
 		}
 		if(  umgebung_t::objfilename.empty()  ) {
-			// nothing to be loaded => exit
-			dr_fatal_notify("*** No pak set found ***\n\nMost likely, you have no pak set installed.\nPlease download and install a pak set (graphics).\n");
-			simgraph_exit();
-			return 0;
+			// try to download missing paks
+			if(  dr_download_pakset( umgebung_t::program_dir, umgebung_t::program_dir == umgebung_t::user_dir )  ) {
+				ask_objfilename();
+				if(  umgebung_t::quit_simutrans  ) {
+					simgraph_exit();
+					return 0;
+				}
+			}
+			// still nothing?
+			if(  umgebung_t::objfilename.empty()  ) {
+				// nothing to be loaded => exit
+				dr_fatal_notify("*** No pak set found ***\n\nMost likely, you have no pak set installed.\nPlease download and install a pak set (graphics).\n");
+				simgraph_exit();
+				return 0;
+			}
 		}
 		show_pointer(0);
 	}
@@ -1098,9 +1112,9 @@ DBG_MESSAGE("simmain","loadgame file found at %s",buffer);
 		file.close();
 	}
 
+	destroy_all_win( true );
 	werkzeug_t::exit_menu();
 
-	welt->destroy();	// some compiler aparently do not like accessing welt during destroy
 	delete welt;
 	welt = NULL;
 
