@@ -57,6 +57,19 @@ vector_tpl<toolbar_t *>werkzeug_t::toolbar_tool(0);
 
 char werkzeug_t::toolstr[1024];
 
+// separator in toolbars
+class wkz_dummy_t : public werkzeug_t {
+public:
+	wkz_dummy_t() : werkzeug_t(dummy_id) {}
+
+	bool init(karte_t*, spieler_t*) OVERRIDE { return false; }
+	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_move_network_save(spieler_t*) const OVERRIDE { return true; }
+};
+werkzeug_t *werkzeug_t::dummy = new wkz_dummy_t();
+
+
 
 
 werkzeug_t *create_general_tool(int toolnr)
@@ -310,186 +323,106 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 	tabfileobj_t contents;
 	menuconf.read(contents);
 
-	// ok, first init all tools
+	// structure to hold information for iterating through different tool types
+	struct tool_class_info_t {
+		const char* type;
+		uint16 count;
+		vector_tpl<werkzeug_t *> &tools;
+		const skin_besch_t *icons;
+		const skin_besch_t *cursor;
+		bool with_sound;
+
+	};
+	tool_class_info_t info[] = {
+		{ "general_tool", GENERAL_TOOL_COUNT, general_tool, skinverwaltung_t::werkzeuge_general, skinverwaltung_t::cursor_general, true },
+		{ "simple_tool",  SIMPLE_TOOL_COUNT,  simple_tool,  skinverwaltung_t::werkzeuge_simple,  NULL, false},
+		{ "dialog_tool",  DIALOGE_TOOL_COUNT, dialog_tool,  skinverwaltung_t::werkzeuge_dialoge, NULL, false }
+	};
+
+	// first init all tools
 	DBG_MESSAGE( "werkzeug_t::init_menu()", "Reading general menu" );
-	for(  uint16 i=0;  i<GENERAL_TOOL_COUNT;  i++  ) {
-		char id[256];
-		sprintf( id, "general_tool[%i]", i );
-		const char *str = contents.get( id );
-		/* str should now contain something like 1,2,-1
-		 * first parameter is the image number in "GeneralTools"
-		 * next is the cursor in "GeneralTools"
-		 * final is the sound
-		 * -1 will disable any of them
-		 */
-		werkzeug_t *w = general_tool[i];
-		if(*str  &&  *str!=',') {
-			// ok, first comes icon
-			while(*str==' ') {
-				str++;
-			}
-			uint16 icon = (uint16)atoi(str);
-			if(  icon==0  &&  *str!='0'  ) {
-				// check, if file name ...
-				int i=0;
-				while(  str[i]!=0  &&  str[i]!=','  ) {
-					i++;
-				}
-				const skin_besch_t *s=skinverwaltung_t::get_extra(str,i-1);
-				w->icon = s ? s->get_bild_nr(0) : IMG_LEER;
-			}
-			else {
-				if(  icon>=skinverwaltung_t::werkzeuge_general->get_bild_anzahl()  ) {
-					dbg->fatal( "werkzeug_t::init_menu()", "wrong icon (%i) given for general_tool[%i]", icon, i );
-				}
-				w->icon = skinverwaltung_t::werkzeuge_general->get_bild_nr(icon);
-			}
-			do {
-				str++;
-			} while(*str  &&  *str!=',');
-		}
-		if(*str==',') {
-			// next comes cursor
-			str++;
-			if(*str!=',') {
-				uint16 cursor = (uint16)atoi(str);
-				if(  cursor>=skinverwaltung_t::cursor_general->get_bild_anzahl()  ) {
-					dbg->fatal( "werkzeug_t::init_menu()", "wrong cursor (%i) given for general_tool[%i]", cursor, i );
-				}
-				w->cursor = skinverwaltung_t::cursor_general->get_bild_nr(cursor);
-				do {
+	for(  uint16 t=0; t<3; t++) {
+		for(  uint16 i=0;  i<info[t].count;  i++  ) {
+			char id[256];
+			sprintf( id, "%s[%i]", info[t].type, i );
+			const char *str = contents.get( id );
+			/* Format of str:
+			 * for general tools: icon,cursor,sound,key
+			 *     icon is image number in menu.GeneralTools, cursor image number in cursor.GeneralTools
+			 * for simple and dialog tools: icon,key
+			 *     icon is image number in menu.SimpleTools and menu.DialogeTools
+			 * -1 will disable any of them
+			 */
+			werkzeug_t *w = info[t].tools[i];
+			if(*str  &&  *str!=',') {
+				// ok, first comes icon
+				while(*str==' ') {
 					str++;
-				} while(*str  &&  *str!=',');
-			}
-		}
-		if(*str==',') {
-			// ok_sound
-			str++;
-			if(*str!=',') {
-				int sound = atoi(str);
-				if(  sound>0  ) {
-					w->ok_sound = sound_besch_t::get_compatible_sound_id(sound);
+				}
+				uint16 icon = (uint16)atoi(str);
+				if(  icon==0  &&  *str!='0'  ) {
+					// check, if file name ...
+					int i=0;
+					while(  str[i]!=0  &&  str[i]!=','  ) {
+						i++;
+					}
+					const skin_besch_t *s=skinverwaltung_t::get_extra(str,i-1);
+					w->icon = s ? s->get_bild_nr(0) : IMG_LEER;
+				}
+				else {
+					if(  icon>=info[t].icons->get_bild_anzahl()  ) {
+						dbg->warning( "werkzeug_t::init_menu()", "wrong icon (%i) given for %s[%i]", icon, info[t].type, i );
+					}
+					w->icon = info[t].icons->get_bild_nr(icon);
 				}
 				do {
 					str++;
 				} while(*str  &&  *str!=',');
 			}
-		}
-		if(*str==',') {
-			// key
-			str++;
-			while(*str==' ') {
-				str++;
+			if(info[t].cursor) {
+				if(*str==',') {
+					// next comes cursor
+					str++;
+					if(*str!=',') {
+						uint16 cursor = (uint16)atoi(str);
+						if(  cursor>=info[t].cursor->get_bild_anzahl()  ) {
+							dbg->warning( "werkzeug_t::init_menu()", "wrong cursor (%i) given for %s[%i]", cursor, info[t].type, i );
+						}
+						w->cursor = info[t].cursor->get_bild_nr(cursor);
+						do {
+							str++;
+						} while(*str  &&  *str!=',');
+					}
+				}
 			}
-			if(*str>=' ') {
-				w->command_key = str_to_key(str);
-				char_to_tool.append(w);
+			if(info[t].with_sound) {
+				if(*str==',') {
+					// ok_sound
+					str++;
+					if(*str!=',') {
+						int sound = atoi(str);
+						if(  sound>0  ) {
+							w->ok_sound = sound_besch_t::get_compatible_sound_id(sound);
+						}
+						do {
+							str++;
+						} while(*str  &&  *str!=',');
+					}
+				}
+			}
+			if(*str==',') {
+				// key
+				str++;
+				while(*str==' ') {
+					str++;
+				}
+				if(*str>=' ') {
+					w->command_key = str_to_key(str);
+					char_to_tool.append(w);
+				}
 			}
 		}
 	}
-
-	// now the simple tools
-	DBG_MESSAGE( "werkzeug_t::init_menu()", "Reading simple menu" );
-	for(  uint16 i=0;  i<SIMPLE_TOOL_COUNT;  i++  ) {
-		char id[256];
-		sprintf( id, "simple_tool[%i]", i );
-		const char *str = contents.get( id );
-		werkzeug_t *w = simple_tool[i];
-		/* str should now contain something like 1,2,-1
-		 * first parameter is the image number in "GeneralTools"
-		 * next is the cursor in "GeneralTools"
-		 * final is the sound
-		 * -1 will disable any of them
-		 */
-		if(*str  &&  *str!=',') {
-			// ok, first come icon
-			while(*str==' ') {
-				str++;
-			}
-			uint16 icon = (uint16)atoi(str);
-			if(  icon==0  &&  *str!='0'  ) {
-				// check, if file name ...
-				int i=0;
-				while(  str[i]!=0  &&  str[i]!=','  ) {
-					i++;
-				}
-				const skin_besch_t *s=skinverwaltung_t::get_extra(str,i-1);
-				w->icon = s ? s->get_bild_nr(0) : IMG_LEER;
-			}
-			else {
-				if(  icon>=skinverwaltung_t::werkzeuge_simple->get_bild_anzahl()  ) {
-					dbg->fatal( "werkzeug_t::init_menu()", "wrong icon (%i) given for simple_tool[%i]", icon, i );
-				}
-				w->icon = skinverwaltung_t::werkzeuge_simple->get_bild_nr(icon);
-			}
-			do {
-				str++;
-			} while(*str  &&  *str!=',');
-		}
-		if(*str==',') {
-			// key
-			str++;
-			while(*str==' ') {
-				str++;
-			}
-			if(*str>=' ') {
-				w->command_key = str_to_key(str);
-				char_to_tool.append(w);
-			}
-		}
-	}
-
-	// now the dialoge tools
-	DBG_MESSAGE( "werkzeug_t::init_menu()", "Reading dialoge menu" );
-	for(  uint16 i=0;  i<DIALOGE_TOOL_COUNT;  i++  ) {
-		char id[256];
-		sprintf( id, "dialog_tool[%i]", i );
-		const char *str = contents.get( id );
-		werkzeug_t *w = dialog_tool[i];
-		/* str should now contain something like 1,2,-1
-		 * first parameter is the image number in "GeneralTools"
-		 * next is the cursor in "GeneralTools"
-		 * final is the sound
-		 * -1 will disable any of them
-		 */
-		if(*str  &&  *str!=',') {
-			// ok, first come icon
-			while(*str==' ') {
-				str++;
-			}
-			uint16 icon = (uint16)atoi(str);
-			if(  icon==0  &&  *str!='0'  ) {
-				// check, if file name ...
-				int i=0;
-				while(  str[i]!=0  &&  str[i]!=','  ) {
-					i++;
-				}
-				const skin_besch_t *s=skinverwaltung_t::get_extra(str,i-1);
-				w->icon = s ? s->get_bild_nr(0) : IMG_LEER;
-			}
-			else {
-				if(  icon>=skinverwaltung_t::werkzeuge_dialoge->get_bild_anzahl()  ) {
-					dbg->fatal( "werkzeug_t::init_menu()", "wrong icon (%i) given for dialoge_tool[%i]", icon, i );
-				}
-				w->icon = skinverwaltung_t::werkzeuge_dialoge->get_bild_nr(icon);
-			}
-			do {
-				str++;
-			} while(*str  &&  *str!=',');
-		}
-		if(*str==',') {
-			// key
-			str++;
-			while(*str==' ') {
-				str++;
-			}
-			if(*str>=' ') {
-				w->command_key = str_to_key(str);
-				char_to_tool.append(w);
-			}
-		}
-	}
-
 	// now the toolbar tools
 	DBG_MESSAGE( "werkzeug_t::read_menu()", "Reading toolbars" );
 	// default size
@@ -513,12 +446,7 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 				// empty entry => toolbar finished ...
 				break;
 			}
-			/* str should now contain something like 1,2,-1
-			 * first parameter is the image number in "GeneralTools"
-			 * next is the cursor in "GeneralTools"
-			 * final is the sound
-			 * -1 will disable any of them
-			 */
+
 			werkzeug_t *addtool = NULL;
 
 			/* first, parse the string; we could have up to four parameters */
@@ -526,11 +454,18 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 			image_id icon = IMG_LEER;
 			const char *key_str = NULL;
 			const char *param_str = NULL;	// in case of toolbars, it will also contain the tooltip
-
-			while(*str!=']'  &&  *str) {
-				str ++;
-			}
-			while(*str==']'  ||  *str==' ') {
+			// parse until next zero-level comma
+			uint level = 0;
+			while(*str) {
+				if (*str == ')') {
+					level++;
+				}
+				else if (*str == '(') {
+					level--;
+				}
+				else if (*str == ','  &&  level == 0) {
+					break;
+				}
 				str++;
 			}
 			// icon
@@ -553,7 +488,8 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 					}
 					else {
 						if(  icon>=skinverwaltung_t::werkzeuge_toolbars->get_bild_anzahl()  ) {
-							dbg->fatal( "werkzeug_t::read_menu()", "wrong icon (%i) given for toolbar_tool[%i][%i]", icon, i, j );
+							dbg->warning( "werkzeug_t::read_menu()", "wrong icon (%i) given for toolbar_tool[%i][%i]", icon, i, j );
+							icon = 0;
 						}
 						icon = skinverwaltung_t::werkzeuge_toolbars->get_bild_nr(icon);
 					}
@@ -582,11 +518,12 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 					param_str = str;
 				}
 			}
+			bool create_tool = icon!=IMG_LEER  ||  key_str  ||  param_str;
 
 			if (char const* const c = strstart(toolname, "general_tool[")) {
 				uint8 toolnr = atoi(c);
 				if(  toolnr<GENERAL_TOOL_COUNT  ) {
-					if(icon!=IMG_LEER  ||  key_str  ||  param_str) {
+					if(create_tool) {
 						// compatibility mode: wkz_cityroad is used for wkz_wegebau with defaultparam 'cityroad'
 						if(  toolnr==WKZ_WEGEBAU  &&  param_str  &&  strcmp(param_str,"city_road")==0) {
 							toolnr = WKZ_CITYROAD;
@@ -596,17 +533,7 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 						addtool = create_general_tool( toolnr );
 						// copy defaults
 						*addtool = *(general_tool[toolnr]);
-						// add specials
-						if(icon!=IMG_LEER) {
-							addtool->icon = icon;
-						}
-						if(key_str!=NULL) {
-							addtool->command_key = str_to_key(key_str);
-							char_to_tool.append(addtool);
-						}
-						if(param_str!=NULL) {
-							addtool->default_param = strdup(param_str);
-						}
+
 						general_tool.append( addtool );
 					}
 					else {
@@ -619,19 +546,9 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 			} else if (char const* const c = strstart(toolname, "simple_tool[")) {
 				uint8 const toolnr = atoi(c);
 				if(  toolnr<SIMPLE_TOOL_COUNT  ) {
-					if(icon!=IMG_LEER  ||  key_str  ||  param_str) {
+					if(create_tool) {
 						addtool = create_simple_tool( toolnr );
 						*addtool = *(simple_tool[toolnr]);
-						if(icon!=IMG_LEER) {
-							addtool->icon = icon;
-						}
-						if(key_str!=NULL) {
-							addtool->command_key = str_to_key(key_str);
-							char_to_tool.append(addtool);
-						}
-						if(param_str!=NULL) {
-							addtool->default_param = strdup(param_str);
-						}
 						simple_tool.append( addtool );
 					}
 					else {
@@ -644,19 +561,9 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 			} else if (char const* const c = strstart(toolname, "dialog_tool[")) {
 				uint8 const toolnr = atoi(c);
 				if(  toolnr<DIALOGE_TOOL_COUNT  ) {
-					if(icon!=IMG_LEER  ||  key_str  ||  param_str) {
+					if(create_tool) {
 						addtool = create_dialog_tool( toolnr );
 						*addtool = *(dialog_tool[toolnr]);
-						if(icon!=IMG_LEER) {
-							addtool->icon = icon;
-						}
-						if(key_str!=NULL) {
-							addtool->command_key = str_to_key(key_str);
-							char_to_tool.append(addtool);
-						}
-						if(param_str!=NULL) {
-							addtool->default_param = strdup(param_str);
-						}
 						dialog_tool.append( addtool );
 					}
 					else {
@@ -671,31 +578,35 @@ void werkzeug_t::read_menu(const std::string &objfilename)
 				assert(toolnr>0);
 				if(toolbar_tool.get_count()==toolnr) {
 					if(param_str==NULL) {
-						dbg->fatal( "werkzeug_t::read_menu()", "Missing parameter for toolbar" );
+						param_str = "Unnamed toolbar";
+						dbg->warning( "werkzeug_t::read_menu()", "Missing title for toolbar[%d]", toolnr);
 					}
 					char *c = strdup(param_str);
 					const char *title = c;
 					c += strcspn(c, ",");
 					if (*c != '\0') *c++ = '\0';
 					toolbar_t* const tb = new toolbar_t(toolbar_tool.get_count() | TOOLBAR_TOOL, title, c, size);
-					if(icon!=IMG_LEER) {
-						tb->icon = icon;
-					}
-					if(key_str!=NULL) {
-						tb->command_key = str_to_key(key_str);
-						char_to_tool.append(tb);
-					}
 					toolbar_tool.append(tb);
 					addtool = tb;
 				}
 			}
 			else {
 				// make a default tool to add the parameter here
-				addtool = new werkzeug_t(werkzeug_t::dummy_id);
+				addtool = new wkz_dummy_t();
 				addtool->default_param = strdup(toolname);
 				addtool->command_key = 1;
 			}
 			if(addtool) {
+				if(icon!=IMG_LEER) {
+					addtool->icon = icon;
+				}
+				if(key_str!=NULL) {
+					addtool->command_key = str_to_key(key_str);
+					char_to_tool.append(addtool);
+				}
+				if(param_str!=NULL  &&  ((addtool->get_id() & TOOLBAR_TOOL) == 0)) {
+					addtool->default_param = strdup(param_str);
+				}
 				toolbar_tool[i]->append(addtool);
 			}
 		}
@@ -734,25 +645,24 @@ const char *werkzeug_t::check_pos( karte_t *welt, spieler_t *, koord3d pos )
 	return (gr  &&  !gr->is_visible()) ? "" : NULL;
 }
 
+/**
+ * Initializes cursor object: image, y-offset, size of marked area,
+ * has to be called after init().
+ * @param zeiger cursor object
+ */
+void werkzeug_t::init_cursor( zeiger_t *zeiger) const
+{
+	zeiger->set_bild( cursor );
+	zeiger->set_yoff( offset );
+	zeiger->set_area( cursor_area, cursor_centered);
+}
+
 const char *kartenboden_werkzeug_t::check_pos( karte_t *welt, spieler_t *, koord3d pos )
 {
 	grund_t *gr = welt->lookup_kartenboden(pos.get_2d());
 	return (gr  &&  !gr->is_visible()) ? "" : NULL;
 }
 
-// seperator in toolbars
-class wkz_dummy_t : public werkzeug_t {
-public:
-	wkz_dummy_t() : werkzeug_t(dummy_id) {}
-
-	bool init(karte_t*, spieler_t*) OVERRIDE { return false; }
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
-	bool is_move_network_save(spieler_t*) const OVERRIDE { return true; }
-};
-
-werkzeug_t *werkzeug_t::dummy = new wkz_dummy_t();
-
 
 
 image_id toolbar_t::get_icon(spieler_t *sp) const
@@ -762,10 +672,8 @@ image_id toolbar_t::get_icon(spieler_t *sp) const
 		return IMG_LEER;
 	}
 	// now have we a least one visible tool?
-	FOR(slist_tpl<werkzeug_t*>, const i, tools) {
-		if (i->get_icon(sp) != IMG_LEER) {
-			return icon;
-		}
+	if (wzw  &&  !wzw->empty(sp)) {
+		return icon;
 	}
 	return IMG_LEER;
 }
@@ -805,11 +713,6 @@ void toolbar_t::update(karte_t *welt, spieler_t *sp)
 		DBG_MESSAGE("toolbar_t::update()","update toolbar %s",default_param);
 	}
 
-	if(  (strcmp(this->default_param,"EDITTOOLS")==0  &&  sp!=welt->get_spieler(1))  ) {
-		destroy_win(wzw);
-		return;
-	}
-
 	wzw->reset_tools();
 	// now (re)fill it
 	FOR(slist_tpl<werkzeug_t*>, const w, tools) {
@@ -864,6 +767,11 @@ void toolbar_t::update(karte_t *welt, spieler_t *sp)
 			wzw->add_werkzeug( w );
 		}
 	}
+
+	if(  (strcmp(this->default_param,"EDITTOOLS")==0  &&  sp!=welt->get_spieler(1))  ) {
+		destroy_win(wzw);
+		return;
+	}
 }
 
 
@@ -902,43 +810,40 @@ bool toolbar_t::exit( karte_t *, spieler_t *)
 }
 
 
-bool two_click_werkzeug_t::init( karte_t *welt, spieler_t *sp )
+bool two_click_werkzeug_t::init( karte_t *welt, spieler_t *)
 {
-	dbg->warning("two_click_werkzeug_t::init", "" );
-	first_click_var[sp->get_player_nr()] = true;
-	start[sp->get_player_nr()] = koord3d::invalid;
+	first_click_var = true;
+	start = koord3d::invalid;
 	if (is_local_execution()) {
 		welt->show_distance = koord3d::invalid;
 	}
-	cleanup( sp, true );
+	cleanup( true );
 	return true;
 }
 
 
-void two_click_werkzeug_t::rdwr_custom_data(uint8 player_nr_, memory_rw_t *packet)
+void two_click_werkzeug_t::rdwr_custom_data(uint8, memory_rw_t *packet)
 {
-	uint8 player_nr = player_nr_ < MAX_PLAYER_COUNT ? player_nr_ : MAX_PLAYER_COUNT-1;
-	packet->rdwr_bool(first_click_var[player_nr]);
-	koord3d & pos = start[player_nr];
-	sint16 posx = pos.x; packet->rdwr_short(posx); pos.x = posx;
-	sint16 posy = pos.y; packet->rdwr_short(posy); pos.y = posy;
-	sint8  posz = pos.z; packet->rdwr_byte(posz);  pos.z = posz;
+	packet->rdwr_bool(first_click_var);
+	sint16 posx = start.x; packet->rdwr_short(posx); start.x = posx;
+	sint16 posy = start.y; packet->rdwr_short(posy); start.y = posy;
+	sint8  posz = start.z; packet->rdwr_byte(posz);  start.z = posz;
 }
 
 
-bool two_click_werkzeug_t::is_first_click( spieler_t *sp ) const
+bool two_click_werkzeug_t::is_first_click() const
 {
-	return first_click_var[sp->get_player_nr()];
+	return first_click_var;
 }
 
 
 bool two_click_werkzeug_t::is_work_here_network_save( karte_t *welt, spieler_t *sp, koord3d pos )
 {
-	if(  !is_first_click(sp)  ) {
+	if(  !is_first_click()  ) {
 		return false;
 	}
 	const char *error = "";	//default: nosound
-	uint8 value = is_valid_pos( welt, sp, pos, error, !is_first_click(sp) ? start[sp->get_player_nr()] : koord3d::invalid );
+	uint8 value = is_valid_pos( welt, sp, pos, error, koord3d::invalid );
 	DBG_MESSAGE("two_click_werkzeug_t::is_work_here_network_save", "Position %s valid=%d", pos.get_str(), value );
 	if(  value == 0  ) {
 		return false;
@@ -958,15 +863,15 @@ bool two_click_werkzeug_t::is_work_here_network_save( karte_t *welt, spieler_t *
 
 const char *two_click_werkzeug_t::work( karte_t *welt, spieler_t *sp, koord3d pos )
 {
-	if(  !is_first_click(sp)  &&  start_marker[sp->get_player_nr()]  ) {
-		start[sp->get_player_nr()]= start_marker[sp->get_player_nr()]->get_pos(); // if map was rotated.
+	if(  !is_first_click()  &&  start_marker  ) {
+		start = start_marker->get_pos(); // if map was rotated.
 	}
 
 	// remove marker
-	cleanup( sp, true );
+	cleanup( true );
 
 	const char *error = "";	//default: nosound
-	uint8 value = is_valid_pos( welt, sp, pos, error, !is_first_click(sp) ? start[sp->get_player_nr()] : koord3d::invalid );
+	uint8 value = is_valid_pos( welt, sp, pos, error, !is_first_click() ? start : koord3d::invalid );
 	DBG_MESSAGE("two_click_werkzeug_t::work", "Position %s valid=%d", pos.get_str(), value );
 	if(  value == 0  ) {
 		flags &= ~(WFL_SHIFT | WFL_CTRL);
@@ -974,7 +879,7 @@ const char *two_click_werkzeug_t::work( karte_t *welt, spieler_t *sp, koord3d po
 		return error;
 	}
 
-	if(  is_first_click(sp)  ) {
+	if(  is_first_click()  ) {
 		// work directly if possible and ctrl is NOT pressed
 		if( (value & 1)  &&  !( (value & 2)  &&  is_ctrl_pressed())) {
 			// Work here directly.
@@ -984,13 +889,13 @@ const char *two_click_werkzeug_t::work( karte_t *welt, spieler_t *sp, koord3d po
 		else {
 			// set starting position.
 			DBG_MESSAGE("two_click_werkzeug_t::work", "Setting start to %s", pos.get_str() );
-			start_at( welt, sp, pos );
+			start_at( welt, pos );
 		}
 	}
 	else {
 		if( value & 2 ) {
 			DBG_MESSAGE("two_click_werkzeug_t::work", "Setting end to %s", pos.get_str() );
-			error = do_work( welt, sp, start[sp->get_player_nr()], pos );
+			error = do_work( welt, sp, start, pos );
 		}
 		flags &= ~(WFL_SHIFT | WFL_CTRL);
 		init( welt, sp ); // Do the cleanup stuff after(!) do_work (otherwise start==koord3d::invalid).
@@ -1006,39 +911,38 @@ const char *two_click_werkzeug_t::move( karte_t *welt, spieler_t *sp, uint16 but
 		return "";
 	}
 
-	const uint8 sp_nr = sp->get_player_nr();
-	if(  start[sp_nr] == pos  ) {
+	if(  start == pos  ) {
 		init( welt, sp );
 	}
 
 	const char *error = NULL;
 
-	if(  start[sp_nr] == koord3d::invalid  ) {
+	if(  start == koord3d::invalid  ) {
 		// start dragging.
-		cleanup( sp, true );
+		cleanup( true );
 
 		uint8 value = is_valid_pos( welt, sp, pos, error, koord3d::invalid );
 		if( error || value == 0 ) {
 			return error;
 		}
 		if( value & 2 ) {
-			start_at( welt, sp, pos );
+			start_at( welt, pos );
 		}
 	}
 	else {
 		// continue dragging.
-		cleanup( sp, false );
+		cleanup( false );
 
-		if( start_marker[sp_nr] ) {
-			start[sp_nr] = start_marker[sp_nr]->get_pos(); // if map was rotated.
+		if( start_marker ) {
+			start = start_marker->get_pos(); // if map was rotated.
 		}
-		uint8 value = is_valid_pos( welt, sp, pos, error, start[sp_nr] );
+		uint8 value = is_valid_pos( welt, sp, pos, error, start );
 		if( error || value == 0 ) {
 			return error;
 		}
 		if( value & 2 ) {
 			display_show_load_pointer( true );
-			mark_tiles( welt, sp, start[sp_nr], pos );
+			mark_tiles( welt, sp, start, pos );
 			display_show_load_pointer( false );
 		}
 	}
@@ -1046,44 +950,42 @@ const char *two_click_werkzeug_t::move( karte_t *welt, spieler_t *sp, uint16 but
 }
 
 
-void two_click_werkzeug_t::start_at( karte_t *welt, spieler_t* sp, koord3d &new_start )
+void two_click_werkzeug_t::start_at( karte_t *welt, koord3d &new_start )
 {
-	const uint8 sp_nr = sp->get_player_nr();
-	first_click_var[sp_nr] = false;
-	start[sp_nr] = new_start;
+	first_click_var = false;
+	start = new_start;
 	if (is_local_execution()) {
 		welt->show_distance = new_start;
-		start_marker[sp_nr] = new zeiger_t(welt, start[sp_nr], NULL);
-		start_marker[sp_nr]->set_bild( get_marker_image() );
-		grund_t *gr = welt->lookup( start[sp_nr] );
+		start_marker = new zeiger_t(welt, start, NULL);
+		start_marker->set_bild( get_marker_image() );
+		grund_t *gr = welt->lookup( start );
 		if( gr ) {
-			gr->obj_add(start_marker[sp_nr]);
+			gr->obj_add(start_marker);
 		}
 	}
-	DBG_MESSAGE("two_click_werkzeug_t::start_at", "Setting start to %s", start[sp_nr].get_str());
+	DBG_MESSAGE("two_click_werkzeug_t::start_at", "Setting start to %s", start.get_str());
 }
 
 
-void two_click_werkzeug_t::cleanup( spieler_t *sp, bool delete_start_marker )
+void two_click_werkzeug_t::cleanup( bool delete_start_marker )
 {
-	const uint8 sp_nr = sp->get_player_nr();
 	karte_t *welt = spieler_t::get_welt();
 	// delete marker.
-	if(  start_marker[sp_nr]!=NULL  &&  delete_start_marker) {
-		start_marker[sp_nr]->mark_image_dirty( start_marker[sp_nr]->get_bild(), 0 );
-		delete start_marker[sp_nr];
-		start_marker[sp_nr] = NULL;
+	if(  start_marker!=NULL  &&  delete_start_marker) {
+		start_marker->mark_image_dirty( start_marker->get_bild(), 0 );
+		delete start_marker;
+		start_marker = NULL;
 	}
 	// delete old route.
-	while(!marked[sp_nr].empty()) {
-		zeiger_t *z = marked[sp_nr].remove_first();
+	while(!marked.empty()) {
+		zeiger_t *z = marked.remove_first();
 		z->mark_image_dirty( z->get_bild(), 0 );
 		z->mark_image_dirty( z->get_after_bild(), 0 );
 		koord3d pos = z->get_pos();
 		grund_t *gr = welt->lookup( pos );
 		delete z;
 		// Remove dummy ground (placed by wkz_tunnelbau_t and wkz_wegebau_t):
-		if( (gr->get_typ() == grund_t::tunnelboden  ||  gr->get_typ() == grund_t::monorailboden)  &&  gr->get_weg_nr(0) == NULL ) {
+		if( (gr->get_typ() == grund_t::tunnelboden  ||  gr->get_typ() == grund_t::monorailboden)  &&  gr->get_weg_nr(0) == NULL && !gr->get_leitung() ) {
 			welt->access(pos.get_2d())->boden_entfernen(gr);
 			delete gr;
 			assert( !welt->lookup(pos));
