@@ -169,10 +169,20 @@ public:
 	// for key loockup
 	static vector_tpl<werkzeug_t *>char_to_tool;
 
+	/// cursor image
 	image_id cursor;
-	sint16 ok_sound;
+
+	/// cursor marks this area
+	koord cursor_area;
+
+	/// cursor centered at marked area? default: false
+	bool cursor_centered;
+
+	/// z-offset of cursor, possible values: Z_PLAN and Z_GRID
 	sint8 offset;
 
+	sint16 ok_sound;
+
 	enum {
 		WFL_SHIFT = 1,
 		WFL_CTRL  = 2,
@@ -203,7 +213,7 @@ public:
 
 	static uint16 const dummy_id = 0xFFFFU;
 
-	werkzeug_t(uint16 const id) : id(id) { cursor = icon = IMG_LEER; ok_sound = NO_SOUND; offset = Z_PLAN; default_param = NULL; command_key = 0; }
+	werkzeug_t(uint16 const id) : id(id), cursor_area(1,1) { cursor = icon = IMG_LEER; ok_sound = NO_SOUND; offset = Z_PLAN; default_param = NULL; command_key = 0; cursor_centered = false;}
 	virtual ~werkzeug_t() {}
 
 	virtual image_id get_icon(spieler_t *) const { return icon; }
@@ -222,7 +232,8 @@ public:
 
 	// when true, local execution would do no harm
 	virtual bool is_init_network_save() const { return false; }
-	virtual bool is_move_network_save(spieler_t *) const { return false; }
+	virtual bool is_move_network_save(spieler_t *) const { return true; }
+
 	// if is_work_network_save()==false
 	// and is_work_here_network_save(...)==false
 	// then work-command is sent over network
@@ -237,6 +248,9 @@ public:
 	// returning false on init will automatically invoke previous tool
 	virtual bool init( karte_t *, spieler_t * ) { return true; }
 
+	/// initializes cursor (icon, marked area)
+	void init_cursor( zeiger_t * ) const;
+
 	// returning true on exit will have werkzeug_waehler resets to query-tool on right-click
 	virtual bool exit( karte_t *, spieler_t * ) { return true; }
 
@@ -280,11 +294,16 @@ public:
 	char const* work(karte_t*, spieler_t*, koord3d) OVERRIDE;
 	char const* move(karte_t*, spieler_t*, uint16 /* buttonstate */, koord3d) OVERRIDE;
 
-	bool is_move_network_save(spieler_t*) const OVERRIDE { return true; }
 	bool is_work_here_network_save(karte_t*, spieler_t *, koord3d) OVERRIDE;
 
-	bool is_first_click(spieler_t *sp) const;
-	void cleanup( spieler_t *, bool delete_start_marker );
+	/**
+	 * @returns true if cleanup() needs to be called before another tool can be executed
+	 * necessary for all tools that create dummy tiles for preview
+	 */
+	virtual bool remove_preview_necessary() const { return false; }
+
+	bool is_first_click() const;
+	void cleanup(bool delete_start_marker );
 
 private:
 
@@ -312,14 +331,14 @@ private:
 
 	virtual image_id get_marker_image();
 
-	bool first_click_var[MAX_PLAYER_COUNT];
-	koord3d start[MAX_PLAYER_COUNT];
-	void start_at( karte_t *, spieler_t *, koord3d &new_start );
+	bool first_click_var;
+	koord3d start;
+	void start_at( karte_t *, koord3d &new_start );
 
-	zeiger_t *start_marker[MAX_PLAYER_COUNT];
+	zeiger_t *start_marker;
 
 protected:
-	slist_tpl< zeiger_t* > marked[MAX_PLAYER_COUNT];
+	slist_tpl< zeiger_t* > marked;
 };
 
 /* toolbar are a new overclass */
@@ -345,7 +364,6 @@ public:
 	bool is_selected(karte_t const*) const OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return true; }
 	bool is_work_network_save() const OVERRIDE { return true; }
-	bool is_move_network_save(spieler_t*) const OVERRIDE { return true; }
 	// show this toolbar
 	bool init(karte_t*, spieler_t*) OVERRIDE;
 	// close this toolbar
