@@ -8,7 +8,6 @@
 #define simwerkz2_h
 
 #include "simtypes.h"
-#include "simskin.h"
 #include "simworld.h"
 #include "simmenu.h"
 #include "simdings.h"
@@ -63,36 +62,49 @@ public:
 };
 
 // alter land height tools
-class wkz_raise_t : public werkzeug_t {
-private:
+class wkz_raise_lower_base_t : public werkzeug_t {
+protected:
 	bool is_dragging;
 	sint16 drag_height;
+
+	bool drag(karte_t *welt, koord pos, sint16 h, int &n);
+	virtual sint16 get_drag_height(grund_t *gr) = 0;
+	bool check_dragging();
 public:
-	wkz_raise_t() : werkzeug_t(WKZ_RAISE_LAND | GENERAL_TOOL) { offset = Z_GRID; }
-	char const* get_tooltip(spieler_t const* const sp) const OVERRIDE { return tooltip_with_price("Anheben", sp->get_welt()->get_settings().cst_alter_land); }
+	wkz_raise_lower_base_t(uint16 id) : werkzeug_t(id | GENERAL_TOOL) { offset = Z_GRID; }
 	image_id get_icon(spieler_t*) const OVERRIDE { return grund_t::underground_mode==grund_t::ugm_all ? IMG_LEER : icon; }
 	bool init(karte_t*, spieler_t*) OVERRIDE { is_dragging = false; return true; }
 	bool exit(karte_t*, spieler_t*) OVERRIDE { is_dragging = false; return true; }
-	char const* check_pos(karte_t*, spieler_t*, koord3d) OVERRIDE;
-	char const* work(karte_t*, spieler_t*, koord3d) OVERRIDE;
+	/**
+	 * technically move is not network safe, however its implementation is:
+	 * it sends work commands over network itself
+	 */
 	char const* move(karte_t*, spieler_t*, uint16 /* buttonstate */, koord3d) OVERRIDE;
+
 	bool is_init_network_save() const OVERRIDE { return true; }
+	/**
+	 * work() is only called when not dragging
+	 * if work() is called with is_dragging==true then is_dragging is reseted
+	 */
+	bool is_work_network_save() const OVERRIDE { return is_dragging;}
 };
 
-class wkz_lower_t : public werkzeug_t {
-private:
-	bool is_dragging;
-	sint16 drag_height;
+class wkz_raise_t : public wkz_raise_lower_base_t {
 public:
-	wkz_lower_t() : werkzeug_t(WKZ_LOWER_LAND | GENERAL_TOOL) { offset = Z_GRID; }
-	char const* get_tooltip(spieler_t const* const sp) const OVERRIDE { return tooltip_with_price("Absenken", sp->get_welt()->get_settings().cst_alter_land); }
-	image_id get_icon(spieler_t*) const OVERRIDE { return grund_t::underground_mode==grund_t::ugm_all ? IMG_LEER : icon; }
-	bool init(karte_t*, spieler_t*) OVERRIDE { is_dragging = false; return true; }
-	bool exit(karte_t*, spieler_t*) OVERRIDE { is_dragging = false; return true; }
+	wkz_raise_t() : wkz_raise_lower_base_t(WKZ_RAISE_LAND) {}
+	char const* get_tooltip(spieler_t const* const sp) const OVERRIDE { return tooltip_with_price("Anheben", sp->get_welt()->get_settings().cst_alter_land); }
 	char const* check_pos(karte_t*, spieler_t*, koord3d) OVERRIDE;
 	char const* work(karte_t*, spieler_t*, koord3d) OVERRIDE;
-	char const* move(karte_t*, spieler_t*, uint16 /* buttonstate */, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	sint16 get_drag_height(grund_t *gr) OVERRIDE;
+};
+
+class wkz_lower_t : public wkz_raise_lower_base_t {
+public:
+	wkz_lower_t() : wkz_raise_lower_base_t(WKZ_LOWER_LAND) {}
+	char const* get_tooltip(spieler_t const* const sp) const OVERRIDE { return tooltip_with_price("Absenken", sp->get_welt()->get_settings().cst_alter_land); }
+	char const* check_pos(karte_t*, spieler_t*, koord3d) OVERRIDE;
+	char const* work(karte_t*, spieler_t*, koord3d) OVERRIDE;
+	sint16 get_drag_height(grund_t *gr) OVERRIDE;
 };
 
 /* slope tool definitions */
@@ -141,6 +153,7 @@ public:
 	char const* get_tooltip(spieler_t const*) const OVERRIDE;
 	image_id get_icon(spieler_t*) const OVERRIDE;
 	bool init(karte_t*, spieler_t*) OVERRIDE;
+	char const* check_pos(karte_t*, spieler_t*, koord3d) OVERRIDE;
 	char const* work(karte_t*, spieler_t*, koord3d) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return true; }
 };
@@ -177,7 +190,7 @@ class wkz_plant_tree_t : public kartenboden_werkzeug_t {
 public:
 	wkz_plant_tree_t() : kartenboden_werkzeug_t(WKZ_PLANT_TREE | GENERAL_TOOL) {}
 	char const* get_tooltip(spieler_t const*) const OVERRIDE { return translator::translate( "Plant tree" ); }
-	char const* move(karte_t* const welt, spieler_t* const sp, uint16 const b, koord3d const k) OVERRIDE { return b == 1 ? work(welt, sp, k) : 0; }
+	char const* move(karte_t* const welt, spieler_t* const sp, uint16 const b, koord3d const k) OVERRIDE;
 	char const* work(karte_t*, spieler_t*, koord3d) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return true; }
 };
@@ -223,8 +236,9 @@ public:
 	char const* get_default_param(spieler_t*) const OVERRIDE;
 	bool is_selected(karte_t const*) const OVERRIDE;
 	bool init(karte_t*, spieler_t*) OVERRIDE;
-	bool is_move_network_save(spieler_t* const sp) const OVERRIDE { return two_click_werkzeug_t::is_move_network_save(sp) && (besch && (besch->get_styp() != 1 || besch->get_wtyp() == air_wt)); }
 	bool is_init_network_save() const OVERRIDE { return true; }
+	// remove preview necessary while building elevated ways
+	bool remove_preview_necessary() const OVERRIDE { return !is_first_click()  &&  (besch  &&  (besch->get_styp() == 1  &&  besch->get_wtyp() != air_wt)); }
 };
 
 class wkz_build_cityroad : public wkz_wegebau_t {
@@ -249,8 +263,9 @@ public:
 	wkz_brueckenbau_t() : two_click_werkzeug_t(WKZ_BRUECKENBAU | GENERAL_TOOL) {}
 	image_id get_icon(spieler_t*) const OVERRIDE { return grund_t::underground_mode==grund_t::ugm_all ? IMG_LEER : icon; }
 	char const* get_tooltip(spieler_t const*) const OVERRIDE;
-	bool is_move_network_save(spieler_t*) const OVERRIDE { return false;}
 	bool is_init_network_save() const OVERRIDE { return true; }
+	bool remove_preview_necessary() const OVERRIDE { return !is_first_click(); }
+	void rdwr_custom_data(uint8 player_nr, memory_rw_t*) OVERRIDE;
 };
 
 class wkz_tunnelbau_t : public two_click_werkzeug_t {
@@ -262,9 +277,9 @@ private:
 public:
 	wkz_tunnelbau_t() : two_click_werkzeug_t(WKZ_TUNNELBAU | GENERAL_TOOL) {}
 	char const* get_tooltip(spieler_t const*) const OVERRIDE;
-	bool is_move_network_save(spieler_t*) const OVERRIDE { return false;}
 	char const* check_pos(karte_t*, spieler_t*, koord3d) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return true; }
+	bool remove_preview_necessary() const OVERRIDE { return !is_first_click(); }
 };
 
 class wkz_wayremover_t : public two_click_werkzeug_t {
@@ -354,6 +369,9 @@ private:
 	void mark_tiles(karte_t*, spieler_t*, koord3d const&, koord3d const&) OVERRIDE;
 	uint8 is_valid_pos(karte_t*, spieler_t*, koord3d const&, char const*&, koord3d const&) OVERRIDE;
 
+	/// save direction of new signs
+	vector_tpl< ribi_t::ribi > directions;
+
 public:
 	wkz_roadsign_t() : two_click_werkzeug_t(WKZ_ROADSIGN | GENERAL_TOOL), besch() {}
 
@@ -757,13 +775,7 @@ public:
 	wkz_rotate90_t() : werkzeug_t(WKZ_ROTATE90 | SIMPLE_TOOL) {}
 	image_id get_icon(spieler_t*) const OVERRIDE { return umgebung_t::networkmode ? IMG_LEER : icon; }
 	char const* get_tooltip(spieler_t const*) const OVERRIDE { return umgebung_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("Rotate map"); }
-	bool init( karte_t *welt, spieler_t * ) {
-		if(  !umgebung_t::networkmode  ) {
-			welt->rotate90();
-			welt->update_map();
-		}
-		return false;
-	}
+	bool init( karte_t *welt, spieler_t * ) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return !umgebung_t::networkmode; }
 	bool is_work_network_save() const OVERRIDE { return !umgebung_t::networkmode; }
 };
