@@ -165,7 +165,7 @@ static int display_gadget_box(simwin_gadget_et const  code,
 	display_vline_wh_clip(x+16, y+1, 14, color+1, false);
 
 	if(pushed) {
-		display_fillbox_wh_clip(x+1, y+1, 14, 14, color+1, false);
+		display_fillbox_wh_clip(x+1, y+1, 14, 14, (color & 0xF8) + max(7, (color&0x07)+2), false);
 	}
 
 	image_id img = IMG_LEER;
@@ -206,7 +206,8 @@ static int display_gadget_boxes(
 	int const x, int const y,
 	int const color,
 	bool const close_pushed,
-	bool const sticky_pushed
+	bool const sticky_pushed,
+	bool const goto_pushed
 ) {
     int width = 0;
     const int w=(REVERSE_GADGETS?16:-16);
@@ -233,7 +234,7 @@ static int display_gadget_boxes(
 	    width++;
 	}
 	if(  flags->gotopos  ) {
-	    display_gadget_box( GADGET_GOTOPOS, x + w*width, y, color, false );
+	    display_gadget_box( GADGET_GOTOPOS, x + w*width, y, color, goto_pushed );
 	    width++;
 	}
 	if(  flags->sticky  ) {
@@ -314,6 +315,7 @@ static void win_draw_window_title(const koord pos, const koord gr,
 		const koord3d welt_pos,
 		const bool closing,
 		const bool sticky,
+		const bool goto_pushed,
 		simwin_gadget_flags_t &flags )
 {
 	PUSH_CLIP(pos.x, pos.y, gr.x, gr.y);
@@ -324,7 +326,7 @@ static void win_draw_window_title(const koord pos, const koord gr,
 
 	// Draw the gadgets and then move left and draw text.
 	flags.gotopos = (welt_pos != koord3d::invalid);
-	int width = display_gadget_boxes( &flags, pos.x+(REVERSE_GADGETS?0:gr.x-20), pos.y, titel_farbe, closing, sticky );
+	int width = display_gadget_boxes( &flags, pos.x+(REVERSE_GADGETS?0:gr.x-20), pos.y, titel_farbe, closing, sticky, goto_pushed );
 	int titlewidth = display_proportional_clip( pos.x + (REVERSE_GADGETS?width+4:4), pos.y+(16-LINEASCENT)/2, text, ALIGN_LEFT, text_farbe, false );
 	if(  flags.gotopos  ) {
 		display_proportional_clip( pos.x + (REVERSE_GADGETS?width+4:4)+titlewidth+8, pos.y+(16-LINEASCENT)/2, welt_pos.get_2d().get_fullstr(), ALIGN_LEFT, text_farbe, false );
@@ -548,6 +550,8 @@ int create_win(int x, int y, gui_frame_t* const gui, wintype const wt, long cons
 		wins.append( simwin_t() );
 		simwin_t& win = wins.back();
 
+		sint16 const menu_height = werkzeug_t::toolbar_tool.empty() ? 0: werkzeug_t::toolbar_tool[0]->iconsize.y;
+
 		// (Mathew Hounsell) Make Sure Closes Aren't Forgotten.
 		// Must Reset as the entries and thus flags are reused
 		win.flags.close = true;
@@ -588,7 +592,7 @@ int create_win(int x, int y, gui_frame_t* const gui, wintype const wt, long cons
 
 		if(x == -1) {
 			// try to keep the toolbar below all other toolbars
-			y = 32;
+			y = menu_height;
 			if(wt & w_no_overlap) {
 				for( uint32 i=0;  i<wins.get_count()-1;  i++  ) {
 					if(wins[i].wt & w_no_overlap) {
@@ -614,8 +618,8 @@ int create_win(int x, int y, gui_frame_t* const gui, wintype const wt, long cons
 		if(x<0) {
 			x = 0;
 		}
-		if(y<32) {
-			y = 32;
+		if(y<menu_height) {
+			y = menu_height;
 		}
 		win.pos = koord(x,y);
 		mark_rect_dirty_wc( x, y, x+gr.x, y+gr.y );
@@ -684,17 +688,18 @@ static void destroy_framed_win(simwin_t *wins)
 
 
 
-void destroy_win(const long magic)
+bool destroy_win(const long magic)
 {
 	const gui_frame_t *gui = win_get_magic(magic);
 	if(gui) {
-		destroy_win( gui );
+		return destroy_win( gui );
 	}
+	return false;
 }
 
 
 
-void destroy_win(const gui_frame_t *gui)
+bool destroy_win(const gui_frame_t *gui)
 {
 	for(  uint i=0;  i<wins.get_count();  i++  ) {
 		if(wins[i].gui == gui) {
@@ -706,9 +711,11 @@ void destroy_win(const gui_frame_t *gui)
 				wins.remove_at(i);
 				destroy_framed_win(&win);
 			}
+			return true;
 			break;
 		}
 	}
+	return false;
 }
 
 
@@ -794,9 +801,10 @@ void display_win(int win)
 				title_color,
 				komp->get_name(),
 				text_color,
-				komp->get_weltpos(),
+				komp->get_weltpos(false),
 				wins[win].closing,
 				wins[win].sticky,
+				komp->is_weltpos(),
 				wins[win].flags );
 	}
 	// mark top window, if requested
@@ -906,9 +914,9 @@ void snap_check_win( const int win, koord *r, const koord from_pos, const koord
 		if(  i==wins_count  ) {
 			// Allow snap to screen edge
 			other_pos.x = 0;
-			other_pos.y = 32;
+			other_pos.y = werkzeug_t::toolbar_tool[0]->iconsize.y;
 			other_gr.x = display_get_width();
-			other_gr.y = display_get_height()-16-32;
+			other_gr.y = display_get_height()-16-other_pos.y;
 			if(  show_ticker  ) {
 				other_gr.y -= 16;
 			}
@@ -1009,7 +1017,7 @@ void move_win(int win, event_t *ev)
 
 	// CLIP(wert,min,max)
 	to_pos.x = CLIP( to_pos.x, 8-to_gr.x, display_get_width()-16 );
-	to_pos.y = CLIP( to_pos.y, 32, display_get_height()-24 );
+	to_pos.y = CLIP( to_pos.y, werkzeug_t::toolbar_tool[0]->iconsize.y, display_get_height()-24 );
 
 	// delta is actual window movement.
 	const koord delta = to_pos - from_pos;
@@ -1151,7 +1159,7 @@ bool check_pos_win(event_t *ev)
 
 	// cursor event only go to top window (but not if rolled up)
 	if(  ev->ev_class == EVENT_KEYBOARD  &&  !wins.empty()  ) {
-		simwin_t&               win  = wins.back();
+		simwin_t &win  = wins.back();
 		if(  !win.rollup  )  {
 			inside_event_handling = win.gui;
 			swallowed = win.gui->infowin_event(ev);
@@ -1240,7 +1248,6 @@ bool check_pos_win(event_t *ev)
 					case GADGET_HELP :
 						if (IS_LEFTCLICK(ev)) {
 							help_frame_t::open_help_on( wins[i].gui->get_hilfe_datei() );
-							inside_event_handling = 0;
 						}
 						break;
 					case GADGET_PREV:
@@ -1259,8 +1266,11 @@ bool check_pos_win(event_t *ev)
 						break;
 					case GADGET_GOTOPOS:
 						if (IS_LEFTCLICK(ev)) {
-							// change position on map
-							spieler_t::get_welt()->change_world_position( wins[i].gui->get_weltpos() );
+							// change position on map (or follow)
+							koord3d k = wins[i].gui->get_weltpos(true);
+							if(  k!=koord3d::invalid  ) {
+								spieler_t::get_welt()->change_world_position( k );
+							}
 						}
 						break;
 					case GADGET_STICKY:
@@ -1357,12 +1367,13 @@ void win_display_flush(double konto)
 	// display main menu
 	werkzeug_waehler_t *main_menu = werkzeug_t::toolbar_tool[0]->get_werkzeug_waehler();
 	display_set_clip_wh( 0, 0, disp_width, menu_height+1 );
-	display_fillbox_wh(0, 0, disp_width, menu_height, MN_GREY2, false);
+	display_fillbox_wh( 0, 0, disp_width, menu_height, MN_GREY2, false );
 	// .. extra logic to enable tooltips
 	tooltip_element = menu_height > get_maus_y() ? main_menu : NULL;
+	void *old_inside_event_handling = inside_event_handling;
 	inside_event_handling = main_menu;
-	main_menu->zeichnen(koord(0,-16), koord(disp_width,menu_height) );
-	inside_event_handling = NULL;
+	main_menu->zeichnen( koord(0,-16), koord(disp_width,menu_height) );
+	inside_event_handling = old_inside_event_handling;
 
 	// redraw all?
 	if(windows_dirty) {
@@ -1615,23 +1626,7 @@ void win_set_welt(karte_t *welt)
 
 bool win_change_zoom_factor(bool magnify)
 {
-	bool ok = magnify ? zoom_factor_up() : zoom_factor_down();
-	if(ok) {
-		event_t ev;
-
-		ev.ev_class = WINDOW_REZOOM;
-		ev.ev_code = get_tile_raster_width();
-		ev.mx = 0;
-		ev.my = 0;
-		ev.cx = 0;
-		ev.cy = 0;
-		ev.button_state = 0;
-
-		for(  sint32 i=wins.get_count()-1;  i>=0;  i=min(i,(int)wins.get_count())-1  ) {
-			wins[i].gui->infowin_event(&ev);
-		}
-	}
-	return ok;
+	return magnify ? zoom_factor_up() : zoom_factor_down();
 }
 
 
