@@ -267,7 +267,7 @@ public:
 	 *
 	 * @author Hj. Malthaner
 	 */
-	bool is_contained(const T data) const
+	bool is_contained(const T &data) const
 	{
 		node_t *p = head;
 
@@ -282,7 +282,7 @@ public:
 	 *
 	 * @author Hj. Malthaner
 	 */
-	bool remove(const T data)
+	bool remove(const T &data)
 	{
 		if (empty()) {
 			//MESSAGE("slist_tpl<T>::remove()", "data not in list!");
@@ -365,7 +365,7 @@ public:
 		node_count = 0;
 	}
 
-	uint32  get_count() const
+	uint32 get_count() const
 	{
 		return node_count;
 	}
@@ -423,10 +423,32 @@ public:
 		node_t* tmp = new node_t(x, pos.ptr);
 		if (pos.pred == NULL) {
 			head = tmp;
-		} else {
+		}
+		else {
 			pos.pred->next = tmp;
 		}
-		if (pos.ptr == NULL) tail = tmp;
+		if (pos.ptr == NULL) {
+			tail = tmp;
+		}
+		++node_count;
+		return iterator(tmp, pos.pred);
+	}
+
+	/* Add an empty node
+	 * pos is invalid after this method
+	 * An iterator pointing to the new element is returned */
+	iterator insert(iterator pos)
+	{
+		node_t* tmp = new node_t(pos.ptr);
+		if (pos.pred == NULL) {
+			head = tmp;
+		}
+		else {
+			pos.pred->next = tmp;
+		}
+		if (pos.ptr == NULL) {
+			tail = tmp;
+		}
 		++node_count;
 		return iterator(tmp, pos.pred);
 	}
