@@ -43,21 +43,14 @@ public:
 /*
  * Ready to use class for hashing strings.
  */
-template <class value_t>
-class stringhashtable_tpl : public hashtable_tpl<const char *, value_t, stringhash_t>
-{
-};
-
-
-template<class value_t>
-class stringhashtable_iterator_tpl : public hashtable_iterator_tpl<const char *, value_t, stringhash_t>
+template <class value_t>class stringhashtable_tpl :
+	public hashtable_tpl<const char *, value_t, stringhash_t>
 {
 public:
-	stringhashtable_iterator_tpl(const hashtable_tpl<const char *, value_t, stringhash_t> *hashtable) :
-		hashtable_iterator_tpl<const char *, value_t, stringhash_t>(hashtable) {}
-
-	stringhashtable_iterator_tpl(const hashtable_tpl<const char *, value_t, stringhash_t> &hashtable) :
-		hashtable_iterator_tpl<const char *, value_t, stringhash_t>(hashtable) {}
+	stringhashtable_tpl() : hashtable_tpl<const char *, value_t, stringhash_t>() {}
+private:
+	stringhashtable_tpl(const stringhashtable_tpl&);
+	stringhashtable_tpl& operator=( stringhashtable_tpl const&);
 };
 
 #endif
