@@ -175,14 +175,19 @@ template<class T> class vector_tpl
 		}
 
 		/**
-		 * put the data at a certain position
-		 * BEWARE: using this function will create default objects, depending on
-		 * the type of the vector
+		 * Put the data at a certain position.
+		 * Possibly resizes vector (and hence creates default objects).
+		 * @param pos index
+		 * @param elem this element will be copied
 		 */
 		void store_at(const uint32 pos, const T& elem)
 		{
 			if (pos >= size) {
-				resize((pos & 0xFFFFFFF7) + 8);
+				uint32 new_size = size == 0 ? 1 : size * 2;
+				while (pos >= new_size) {
+					new_size *= 2;
+				}
+				resize(new_size);
 			}
 			data[pos] = elem;
 			if (pos >= count) {
@@ -191,23 +196,25 @@ template<class T> class vector_tpl
 		}
 
 		/** removes element, if contained */
-		void remove(const T& elem)
+		bool remove(const T& elem)
 		{
 			for (uint32 i = 0; i < count; i++) {
 				if (data[i] == elem) {
 					return remove_at(i);
 				}
 			}
+			return false;
 		}
 
 		/** removes element at position */
-		void remove_at(const uint32 pos)
+		bool remove_at(const uint32 pos)
 		{
 			assert(pos<count);
 			for (uint i = pos; i < count - 1; i++) {
 				data[i] = data[i + 1];
 			}
 			count--;
+			return true;
 		}
 
 		void pop_back()
